<?php
/**
 * The template for displaying 404 pages (not found)
 *
 * @link https://codex.wordpress.org/Creating_an_Error_404_Page
 *
 * @package Geeks
 */

geeks_get_header( 'speciality' );

$img_url      = get_template_directory_uri() . '/assets/images/error/404-error-img.svg';
$btn_url      = apply_filters( 'geeks_404_button_url', get_theme_mod( '404_button_url', home_url( '/' ) ) );
$btn_context  = apply_filters( 'geeks_404_button_color', get_theme_mod( '404_button_color', 'primary' ) );
$btn_text     = apply_filters( 'geeks_404_button_text', get_theme_mod( '404_button_text', esc_html__( 'Back to Safety', 'geeks' ) ) );
$contact_link = '<a href="#" class="btn-link">' . esc_html__( 'Contact us', 'geeks' ) . '</a>';
?>
<div class="container d-flex flex-column">
	<div class="row align-items-center justify-content-center g-0 py-lg-22 py-10">
		<!-- Docs -->
		<div class="offset-xl-1 col-xl-4 col-lg-6 col-md-12 col-12 text-center text-lg-start">
			<h1 class="display-1 mb-3 404_title">
				<?php echo esc_html( get_theme_mod( '404_title', esc_html_x( '404', 'front-end', 'geeks' ) ) ); ?>
			</h1>
			<p class="mb-5 lead 404_desc">
				<?php
					echo wp_kses_post(
						get_theme_mod( '404_description', sprintf( esc_html__( 'Oops! Sorry, we couldn’t find the page you were looking for. If you think this is a problem with us, please %s', 'geeks' ), $contact_link ) )
					);
					?>
			</p>
			<a class="404_button_text btn btn-<?php echo esc_attr( $btn_context ); ?> me-2"
				href="<?php echo esc_url( $btn_url ); ?>"><?php echo esc_html( $btn_text ); ?>
			</a>
		</div>
		<!-- img -->
		<div class="offset-xl-1 col-xl-6 col-lg-6 col-md-12 col-12 mt-8 mt-lg-0 404_image">
			<?php
			$image_html = wp_get_attachment_image(
				get_theme_mod( '404_image_option' ),
				'480px',
				false,
				[
					'class' => 'w-100',
					'alt'   => esc_html_x( 'Error 404', 'front-end', 'geeks' ),
				]
			);
			if ( '' !== $image_html ) :
				echo wp_kses_post( apply_filters( 'geeks_404_image_option', $image_html ) );
			else :
				?>
			<img class="w-100" src="<?php echo esc_url( $img_url ); ?>">
			<?php endif; ?>
		</div>
	</div>
</div>
<?php

geeks_get_footer( 'speciality' );
