<?php
/**
 * The template for displaying comments.
 *
 * The area of the page that contains both current comments
 * and the comment form.
 *
 * @package geeks
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

?>
<div id="comments" class="comments-area pt-6 mb-0-last-child" aria-label="<?php esc_attr_e( 'Post Comments', 'geeks' ); ?>">
	<?php if ( have_comments() ) : ?>
		<div class="mb-4">
			<div class="card border shadow-none">
				<div class="card-header">
					<h3 class="mb-0 h4">
						<?php
							// phpcs:disable WordPress.Security.EscapeOutput.OutputNotEscaped
							echo sprintf(
								/* translators: 1: number of comments, 2: post title */
								esc_html( _nx( '%1$s Comment', '%1$s Comments', get_comments_number(), 'comments title', 'geeks' ) ),
								number_format_i18n( get_comments_number() )
							);
							// phpcs:enable
						?>
					</h3>
				</div>

				<div class="comment-list">
					<?php
						wp_list_comments(
							array(
								'style'      => 'div',
								'short_ping' => true,
								'callback'   => 'geeks_comment',
							)
						);
					?>
				</div><!-- .comment-list -->
			</div>
		</div>

		<?php
		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through.
			?>
			<nav id="comment-nav-below" class="comment-navigation mb-4" role="navigation" aria-label="<?php esc_attr_e( 'Comment Navigation Below', 'geeks' ); ?>">
				<span class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'geeks' ); ?></span>
				<div class="d-flex justify-content-between">
					<div class="nav-previous"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'geeks' ) ); ?></div>
					<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'geeks' ) ); ?></div>
				</div>
			</nav><!-- #comment-nav-below -->
			<?php
		endif; // Check for comment navigation.

		if ( ! comments_open() && 0 !== intval( get_comments_number() ) && post_type_supports( get_post_type(), 'comments' ) ) :
			?>
			<p class="no-comments alert alert-warning mb-0"><?php esc_html_e( 'Comments are closed.', 'geeks' ); ?></p>
			<?php
		endif;
	endif;
	?>

	<div class="mb-4">
		<?php
		$args = array(
			'class_container'     => 'comment-respond card border shadow-none m-0',
			'fields'              => array(
				// Author field.
				'author'  => '<div class="mb-3 col-12 col-sm-6"><label for="author" class="form-label">' . esc_html__( 'Name', 'geeks' ) . '<span class="text-danger">*</span></label><input id="author" name="author" aria-required="true" class="form-control"></div>',
				// Email Field.
				'email'   => '<div class="mb-3 col-12 col-sm-6"><label for="email" class="form-label">' . esc_html__( 'Email', 'geeks' ) . '<span class="text-danger">*</span></label><input id="email" name="email" class="form-control"></div>',
				// URL Field.
				'url'     => '<div class="mb-3 col-12"><label for="url" class="form-label">' . esc_html__( 'Website', 'geeks' ) . '</label><input id="url" name="url" class="form-control"></div>',
				// Cookies.
				'cookies' => '<div class="mb-3 col-12"><div class="custom-control custom-checkbox comment-form-cookies-consent"><input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" class="me-2 custom-control-input" type="checkbox" required><label class="custom-control-label" for="wp-comment-cookies-consent">' . esc_html__( 'Save my name and email in this browser for the next time I comment.', 'geeks' ) .'</label></div></div>',

			),
			'class_form'          => 'row p-4',
			'title_reply_before'  => '<div class="card-header"><h3 id="reply-title" class="comment-reply-title mb-0 h4">',
			'title_reply_after'   => '</h3></div>',
			'comment_field'       => '<div class="mb-3 col-12"><label for="comment" class="form-label comment-form-comment">' . esc_html__( 'Comment', 'geeks' ) . '</label><textarea id="comment" name="comment" aria-required="true" class="form-control" rows="4"></textarea></div>',
			'submit_button'       => '<div class="col-12"><input name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" /></div>',
			'submit_field'        => '<div class="form-submit">%1$s %2$s</div>',
			'label_submit'        => esc_html__( 'Submit', 'geeks' ),
			'class_submit'        => 'btn btn-primary',
			'cancel_reply_before' => ' <small class="ms-3">',
			'cancel_reply_after'  => '</small>',
		);

		comment_form( $args );
		?>
	</div>

</div><!-- #comments -->
