<?php

if ( ! class_exists( 'Geeks_Acf_Field_Carousel_Control_Group' ) ) :

	class Geeks_Acf_Field_Carousel_Control_Group extends Geeks_Acf_Field_Group {

		/*
		*  __construct
		*
		*  This function will setup the field type data
		*
		*  @type    function
		*  @date    5/03/2014
		*  @since   5.0.0
		*
		*  @param   n/a
		*  @return  n/a
		*/
		function initialize() {

			// vars
			$this->name      = 'carousel_control_option';
			$this->label     = esc_html__( 'Carousel Control Options', 'geeks' );
			$this->category  = 'layout';
			$this->defaults  = array(
				'sub_fields' => array(),
				'layout'     => 'block',
			);
			$this->have_rows = 'single';

			// field filters
			$this->add_field_filter( 'acf/prepare_field_for_export', array( $this, 'prepare_field_for_export' ) );
			$this->add_field_filter( 'acf/prepare_field_for_import', array( $this, 'prepare_field_for_import' ) );
			add_filter( 'acf/load_field/type=carousel_control_option', array( $this, 'render_subfields' ) );
		}

		/*
		*  render_subfields()
		*
		*  Create the HTML interface for your sub field
		*
		*  @param   $field - an array holding all the sub field's data
		*
		*  @type    action
		*  @since   3.6
		*  @date    23/01/13
		*/
		function render_subfields( $field ) {

			$enable_disable_options = array(
				'is_autoplay_enabled'   => array(
					'label'             => esc_html__( 'Autoplay ?', 'geeks' ),
					'default'           => 0,
					'instructions'      => '',
					'conditional_logic' => 0,
				),
				'is_dots_enabled'       => array(
					'label'             => esc_html__( 'Dots ?', 'geeks' ),
					'default'           => 0,
					'instructions'      => '',
					'conditional_logic' => 0,
				),
				'is_arrows_enabled'     => array(
					'label'             => esc_html__( 'Arrows ?', 'geeks' ),
					'default'           => 0,
					'instructions'      => '',
					'conditional_logic' => 0,
				),
				'is_autowidth_enabled'  => array(
					'label'             => esc_html__( 'Autowidth ?', 'geeks' ),
					'default'           => 0,
					'instructions'      => '',
					'conditional_logic' => 0,
				),
				'is_autoheight_enabled' => array(
					'label'             => esc_html__( 'Autoheight ?', 'geeks' ),
					'default'           => 0,
					'instructions'      => '',
					'conditional_logic' => 0,
				),
				'is_drag_enabled'       => array(
					'label'             => esc_html__( 'Drag ?', 'geeks' ),
					'default'           => 0,
					'instructions'      => '',
					'conditional_logic' => 0,
				),
			);

			foreach ( $enable_disable_options as $key => $enable_disable_option ) {

				$field['sub_fields'][] = array(
					'ID'                => uniqid(),
					'key'               => 'field_' . $key,
					'label'             => $enable_disable_option['label'],
					'name'              => $key,
					'_name'             => $key,
					'type'              => 'true_false',
					'return_format'     => 'value',
					'ui'                => 1,
					'ui_on_text'        => esc_html__( 'Enable', 'geeks' ),
					'ui_off_text'       => esc_html__( 'Disable', 'geeks' ),
					'required'          => 0,
					'conditional_logic' => $enable_disable_option['conditional_logic'],
					'default_value'     => $enable_disable_option['default'],
					'wrapper'           => array(
						'width' => '',
						'class' => '',
						'id'    => '',
					),
					'instructions'      => $enable_disable_option['instructions'],
				);
			}

			$slide_to_show_screen_options = array(
				'slide_to_show_default' => array(
					'label'             => esc_html__( 'Items Default', 'geeks' ),
					'default'           => 5,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'slide_to_show_xs'      => array(
					'label'             => esc_html__( 'Items Xtra Small Screen', 'geeks' ),
					'default'           => 1,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'slide_to_show_sm'      => array(
					'label'             => esc_html__( 'Items Small Screen', 'geeks' ),
					'default'           => 1,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'slide_to_show_md'      => array(
					'label'             => esc_html__( 'Items Medium Screen', 'geeks' ),
					'default'           => 3,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'slide_to_show_lg'      => array(
					'label'             => esc_html__( 'Items Large Screen', 'geeks' ),
					'default'           => 4,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'slide_to_show_xl'      => array(
					'label'             => esc_html__( 'Items Xtra Large Screen', 'geeks' ),
					'default'           => 5,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
			);

			foreach ( $slide_to_show_screen_options as $key => $screen_option ) {
				$field['sub_fields'][] = array(
					'ID'                => uniqid(),
					'key'               => 'field_' . $key,
					'label'             => $screen_option['label'],
					'name'              => $key,
					'_name'             => $key,
					'type'              => 'number',
					'min'               => 1,
					'required'          => 0,
					'default_value'     => $screen_option['default'],
					'conditional_logic' => $screen_option['conditional_logic'],
					'wrapper'           => array(
						'width' => '',
						'class' => '',
						'id'    => '',
					),
					'instructions'      => $screen_option['instructions'],
				);
			}

			$field['sub_fields'][] = array(
				'ID'                => uniqid(),
				'key'               => 'field_slide_mode',
				'label'             => esc_html__( 'Slide Mode', 'geeks' ),
				'name'              => 'slide_mode',
				'_name'             => 'slide_mode',
				'type'              => 'select',
				'choices'           => array(
					'carousel' => esc_html__( 'Carousel', 'geeks' ),
					'gallery'  => esc_html__( 'Gallery', 'geeks' ),
				),
				'multiple'          => 0,
				'return_format'     => 'value',
				'ui'                => 1,
				'required'          => 0,
				'conditional_logic' => 0,
				'default_value'     => 'carousel',
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'instructions'      => '',
			);

			$field['sub_fields'][] = array(
				'ID'                => uniqid(),
				'key'               => 'field_slide_axis',
				'label'             => esc_html__( 'Slide Axis', 'geeks' ),
				'name'              => 'slide_axis',
				'_name'             => 'slide_axis',
				'type'              => 'select',
				'choices'           => array(
					'horizontal' => esc_html__( 'Horizontal', 'geeks' ),
					'vertical'   => esc_html__( 'Vertical', 'geeks' ),
				),
				'multiple'          => 0,
				'return_format'     => 'value',
				'ui'                => 1,
				'required'          => 0,
				'conditional_logic' => 0,
				'default_value'     => 'horizontal',
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'instructions'      => '',
			);

			$field['sub_fields'][] = array(
				'ID'                => uniqid(),
				'key'               => 'field_gutter_space',
				'label'             => esc_html__( 'Space Between Slides', 'geeks' ),
				'name'              => 'gutter_space',
				'_name'             => 'gutter_space',
				'type'              => 'number',
				'min'               => 1,
				'required'          => 0,
				'default_value'     => 30,
				'conditional_logic' => 0,
				'wrapper'           => array(
					'width' => '',
					'class' => '',
					'id'    => '',
				),
				'instructions'      => '',
			);

			$slide_time_options = array(
				'slide_autoplay_time' => array(
					'label'             => esc_html__( 'Slide Autoplay Time', 'geeks' ),
					'default'           => 2000,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
				'slide_speed_time'    => array(
					'label'             => esc_html__( 'Slide Speed', 'geeks' ),
					'default'           => 1000,
					'conditional_logic' => 0,
					'instructions'      => '',
				),
			);

			foreach ( $slide_time_options as $key => $slide_time_option ) {
				$field['sub_fields'][] = array(
					'ID'                => uniqid(),
					'key'               => 'field_' . $key,
					'label'             => $slide_time_option['label'],
					'name'              => $key,
					'_name'             => $key,
					'type'              => 'number',
					'min'               => 1,
					'required'          => 0,
					'default_value'     => $slide_time_option['default'],
					'conditional_logic' => $slide_time_option['conditional_logic'],
					'wrapper'           => array(
						'width' => '',
						'class' => '',
						'id'    => '',
					),
					'instructions'      => $slide_time_option['instructions'],
				);
			}

			return $field;
		}
	}

	// initialize
	acf_register_field_type( 'Geeks_Acf_Field_Carousel_Control_Group' );
endif;
