<?php
/**
 * ACF Functions for Course Category Group
 */

class Geeks_ACF_Course_Category {

	public static $slug = 'course_category';

	/**
	 * Get the post id for Course Category taxonomy
	 */
	public static function get_post_id( $course_cat_id = 0 ) {
		if ( 0 === $course_cat_id ) {
			$course_cat_id = geeks_get_course_cat_id();
		}

		return self::$slug . '_' . $course_cat_id;	
	}

	/**
	 * Should Override course category
	 */
	public static function get_override_desc() {
	    return geeks_get_field( 'override_course_description', static::get_post_id() );
	}

	/**
	 * Get students enrolled in a course category
	 */
	public static function get_students_enrolled() {
	    return geeks_get_field( 'students_enrolled', static::get_post_id() );
	}

	/**
	 * Get tabs enabled status in course category
	 */
	public static function get_enable_tabs() {
		return geeks_get_field( 'enable_tabs', static::get_post_id() );
	}

	/**
	 * Get tab #1
	 */
	public static function get_tab_1() {
		return geeks_get_field( 'tab_1', static::get_post_id() );
	}

	/**
	 * Get tab #2
	 */
	public static function get_tab_2() {
		return geeks_get_field( 'tab_2', static::get_post_id() );
	}

	/**
	 * Get Courses Enable in Course Category
	 */
	public static function get_enable_courses() {
		return geeks_get_field( 'enable_courses', static::get_post_id() );
	}

	/**
	 * Get type of content before Courses in Course Category
	 */
	public static function get_content_before_courses() {
		return geeks_get_field( 'content_before_courses', static::get_post_id() );
	}

	/**
	 * Get courses group info
	 */
	public static function get_section_courses() {
		$courses_group = geeks_get_field( 'courses', static::get_post_id() );
		$courses_group['results'] = geeks_acf_process_courses_field( $courses_group, true );
		return $courses_group;
	}

	/**
	 * Get Instructors Enable in Course Category
	 */
	public static function get_enable_instructors() {
		return geeks_get_field( 'enable_instructors', static::get_post_id() );
	}

	/**
	 * Get instructors group info
	 */
	public static function get_section_instructors() {
		$instructors_group = geeks_get_field( 'instructors', static::get_post_id() );
		$instructors_group['results'] = geeks_acf_process_instructors_field( $instructors_group, true );
		return $instructors_group;
	}

	/**
	 * Get courses header enable
	 */
	public static function is_courses_header_enabled() {
		return geeks_get_field( 'enable_courses_header', static::get_post_id() );
	}

	/**
	 * Get courses header info
	 */
	public static function get_courses_header() {
		return geeks_get_field( 'courses_section_header', static::get_post_id() );
	}
}

class Geeks_Tutor_ACF_Tax extends Geeks_ACF_Course_Category {

	public static $slug = 'course-category';

	/**
	 * Get the post id for Course Category taxonomy
	 */
	public static function get_post_id( $course_cat_id = 0 ) {
		if ( 0 === $course_cat_id ) {
			$course_cat_id = geeks_tutor_get_course_cat_id();
		}

		return self::$slug . '_' . $course_cat_id;	
	}
}