<?php
/**
 * Geeks Customizer Class
 *
 * @package  geeks
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks_Customizer' ) ) :

	/**
	 * The Geeks Customizer class
	 */
	class Geeks_Customizer {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			$this->init_hooks();
		}

		/**
		 * Init Geeks_Customizer when WordPress Initializes
		 */
		public function init_hooks() {
			add_action( 'customize_register', array( $this, 'customize_logos' ), 10 );
			add_action( 'customize_register', array( $this, 'customize_header' ), 20 );
			add_action( 'customize_register', array( $this, 'customize_blog' ), 10 );
			add_action( 'customize_register', array( $this, 'customize_footer' ), 20 );
			add_action( 'customize_register', array( $this, 'customize_404' ), 10 );
			add_action( 'wp_enqueue_scripts', array( $this, 'add_customizer_css' ), 130 );
			add_action( 'init', array( $this, 'default_theme_mod_values' ), 10 );
			add_action( 'customize_register', array( $this, 'customize_customcolor' ), 10 );


		}

		/**
		 * Customize all available site logos
		 *
		 * All logos located in title_tagline (Site Identity) section.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public function customize_logos( $wp_customize ) {
			$this->add_customize_logos( $wp_customize );
		}

		private function add_customize_logos( $wp_customize ) {

			$wp_customize->add_setting(
				'logo_inverse',
				[
					'transport'         => 'postMessage',
					'theme_supports'    => 'custom-logo',
					'sanitize_callback' => 'absint',
				]
			);
			$wp_customize->add_control(
				new WP_Customize_Cropped_Image_Control(
					$wp_customize,
					'logo_inverse',
					[
						'section'       => 'title_tagline',
						'label'         => esc_html__( 'Logo Inverse', 'geeks' ),
						'description'   => esc_html__( 'Upload logo for dark header', 'geeks' ),
						'priority'      => 9,
						'width'         => 60,
						'height'        => 60,
						'flex_width'    => true,
						'flex_height'   => true,
						'button_labels' => [
							'select'       => esc_html__( 'Select logo', 'geeks' ),
							'change'       => esc_html__( 'Change logo', 'geeks' ),
							'remove'       => esc_html__( 'Remove', 'geeks' ),
							'default'      => esc_html__( 'Default', 'geeks' ),
							'placeholder'  => esc_html__( 'No logo selected', 'geeks' ),
							'frame_title'  => esc_html__( 'Select logo', 'geeks' ),
							'frame_button' => esc_html__( 'Choose logo', 'geeks' ),
						],
					]
				)
			);
			$wp_customize->selective_refresh->add_partial(
				'logo_inverse',
				[
					'selector'            => '.navbar-brand',
					'container_inclusive' => true,
					'render_callback'     => 'geeks_site_title_or_logo',
				]
			);

		}

		/**
		 * Customize site header
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public function customize_header( $wp_customize ) {
			$wp_customize->add_section(
				'geeks_header',
				[
					'title'       => esc_html__( 'Header', 'geeks' ),
					'description' => esc_html__( 'Customize the theme header.', 'geeks' ),
					'priority'    => 80,
				]
			);

			$this->add_header_section( $wp_customize );

		}

		/**
		 * Customizer Controls For Header.
		 *
		 *  @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		private function add_header_section( $wp_customize ) {

			$wp_customize->add_setting(
				'header_variant',
				[
					'default'           => 'v1',
					'sanitize_callback' => 'sanitize_key',
				]
			);
			$wp_customize->add_control(
				'header_variant',
				[
					'type'        => 'select',
					'section'     => 'geeks_header',
					'label'       => esc_html__( 'Header Version', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to choose your header type.', 'geeks' ),
					'choices'     => [
						'v1'         => esc_html__( 'Header v1', 'geeks' ),
						'speciality' => esc_html__( 'Header Speciality', 'geeks' ),
					],
				]
			);
			$wp_customize->selective_refresh->add_partial(
				'header_variant',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'header_is_full_width',
				[
					'default'           => true,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);

			$wp_customize->add_control(
				'header_is_full_width',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Make header full-width?', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to control header width. Default is fluid container.', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',

							],
							true
						);
					},

				]
			);

			$wp_customize->selective_refresh->add_partial(
				'header_is_full_width',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_search',
				[
					'default'           => true,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);
			$wp_customize->add_control(
				'enable_search',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Enable Search?', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',

							],
							true
						);
					},
				]
			);
			$wp_customize->selective_refresh->add_partial(
				'enable_search',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_cart',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);
			$wp_customize->add_control(
				'enable_cart',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Enable Cart?', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',

							],
							true
						);
					},
				]
			);
			$wp_customize->selective_refresh->add_partial(
				'enable_cart',
				[
					'fallback_refresh' => true,
				]
			);


			$wp_customize->add_setting(
				'enable_user_profile',
				[
					'default'           => true,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);
			$wp_customize->add_control(
				'enable_user_profile',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Enable User Profile Info?', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',

							],
							true
						);
					},
				]
			);
			$wp_customize->selective_refresh->add_partial(
				'enable_user_profile',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_dark_header',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);

			$wp_customize->add_control(
				'enable_dark_header',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Enable Dark Header?', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',

							],
							true
						);
					},

				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_dark_header',
				[
					'fallback_refresh' => true,
				]
			);


			$wp_customize->add_setting(
				'enable_shadow',
				[
					'default'           => true,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);
			$wp_customize->add_control(
				'enable_shadow',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Enable Shadow?', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',

							],
							true
						);
					},
				]
			);
			$wp_customize->selective_refresh->add_partial(
				'enable_shadow',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_transparent',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);

			$wp_customize->add_control(
				'enable_transparent',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Enable Transparent Header?', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',

							],
							true
						);
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_transparent',
				[
					'fallback_refresh' => true,
				]
			);


			$wp_customize->add_setting(
				'enable_action_button',
				[
					'default'           => false,
					'sanitize_callback' => 'sanitize_key',
				]
			);
			$wp_customize->add_control(
				'enable_action_button',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Enable Button?', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',
							]
						);
					},

				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_action_button',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'button_variant',
				[
					'default'           => 'outline',
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'button_variant',
				[
					'type'            => 'select',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Button Variant', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to choose your button variant', 'geeks' ),
					'choices'         => [
						''        => esc_html__( 'Default', 'geeks' ),
						'outline' => esc_html__( 'Outline', 'geeks' ),
					],
					'active_callback' => function () {
						return filter_var( get_theme_mod( 'enable_action_button' ), FILTER_VALIDATE_BOOLEAN ) && in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',
							]
						);
					},

				]
			);
			$wp_customize->selective_refresh->add_partial(
				'button_variant',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'button_url',
				[
					'default'           => '#',
					'sanitize_callback' => 'esc_url_raw',
				]
			);

			$wp_customize->add_control(
				'button_url',
				[
					'type'            => 'url',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Button Link', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to change the button link', 'geeks' ),
					'active_callback' => function () {
						return filter_var( get_theme_mod( 'enable_action_button' ), FILTER_VALIDATE_BOOLEAN ) && in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',
							]
						);
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'button_url',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'button_text',
				[
					'default'           => esc_html__( 'Buy Now', 'geeks' ),
					'sanitize_callback' => 'wp_kses_post',
					'transport'         => 'postMessage',
				]
			);

			$wp_customize->add_control(
				'button_text',
				[
					'type'            => 'text',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Button Text', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to change the button text', 'geeks' ),
					'active_callback' => function () {
						return filter_var( get_theme_mod( 'enable_action_button' ), FILTER_VALIDATE_BOOLEAN ) && in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',
							]
						);
					},

				]
			);

			$wp_customize->selective_refresh->add_partial(
				'button_text',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'button_size',
				[
					'default'           => '',
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'button_size',
				[
					'type'            => 'select',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Button Size', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to choose your button size', 'geeks' ),
					'choices'         => [
						''       => esc_html__( 'Default', 'geeks' ),
						'btn-xs' => esc_html__( 'Extra Small', 'geeks' ),
						'btn-sm' => esc_html__( 'Small', 'geeks' ),
						'btn-lg' => esc_html__( 'Large ', 'geeks' ),

					],
					'active_callback' => function () {
						return filter_var( get_theme_mod( 'enable_action_button' ), FILTER_VALIDATE_BOOLEAN ) && in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',
							]
						);
					},

				]
			);
			$wp_customize->selective_refresh->add_partial(
				'button_size',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'button_css',
				[
					'default'           => '',
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'button_css',
				[
					'type'            => 'text',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Button CSS Class', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to add  button css', 'geeks' ),
					'active_callback' => function () {
						return filter_var( get_theme_mod( 'enable_action_button' ), FILTER_VALIDATE_BOOLEAN ) && in_array(
							get_theme_mod( 'header_variant' ),
							[
								'v1',
							]
						);
					},

				]
			);
			$wp_customize->selective_refresh->add_partial(
				'button_css',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'button_color',
				[
					'default'           => 'primary',
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'button_color',
				[
					'type'            => 'select',
					'section'         => 'geeks_header',
					'label'           => esc_html__( 'Button Primary Color', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to choose your button color', 'geeks' ),
					'choices'         => [
						'primary' => esc_html__( 'Default', 'geeks' ),
						'custom'  => esc_html__( 'Custom', 'geeks' ),
					],
					'active_callback' => function () {
						return filter_var( get_theme_mod( 'enable_action_button' ), FILTER_VALIDATE_BOOLEAN );
					},

				]
			);

			$wp_customize->add_setting(
				'geeks_navbar_button_background',
				array(
					'default'           => apply_filters( 'geeks_default_button_color', '#754ffe' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'geeks_navbar_button_background',
					array(
						'label'           => esc_html__( 'Button Background', 'geeks' ),
						'section'         => 'geeks_header',
						'settings'        => 'geeks_navbar_button_background',
						'active_callback' => function () {
							return filter_var( get_theme_mod( 'enable_action_button' ), FILTER_VALIDATE_BOOLEAN )
							&& get_theme_mod( 'button_color', 'custom' ) === 'custom';
						},
					)
				)
			);




			$wp_customize->add_setting(
				'enable_sticky',
				[
					'default'           => false,
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'enable_sticky',
				[
					'type'        => 'checkbox',
					'priority'    => 10,
					'label'       => esc_html__( 'Enable Sticky Header ?', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to enable or disable sticky header.', 'geeks' ),
					'section'     => 'geeks_header',
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_sticky',
				[
					'fallback_refresh' => true,
				]
			);


		}


		/**
		 * Customize site 404
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public function customize_404( $wp_customize ) {

			$wp_customize->add_section(
				'geeks_404',
				[
					'title'    => esc_html__( '404', 'geeks' ),
					'priority' => 110,
				]
			);

			$this->add_404_section( $wp_customize );
		}

		/**
		 * Customizer Controls For site 404.
		 *
		 *  @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		private function add_404_section( $wp_customize ) {

			$wp_customize->selective_refresh->add_partial(
				'404_image_option',
				[
					'selector'        => '.404_image',
					'render_callback' => function () {
						return esc_html( get_theme_mod( '404_image_option' ) );
					},
				]
			);

			$wp_customize->add_setting(
				'404_image_option',
				[
					'transport'         => 'postMessage',
					'sanitize_callback' => 'absint',
				]
			);

			$wp_customize->add_control(
				new WP_Customize_Media_Control(
					$wp_customize,
					'404_image_option',
					[
						'section'     => 'geeks_404',
						'label'       => esc_html__( '404 Image Upload', 'geeks' ),
						'description' => esc_html__(
							'This setting allows you to upload an image for 404 page.',
							'geeks'
						),
						'mime_type'   => 'image',
					]
				)
			);

			$wp_customize->add_setting(
				'404_title',
				[
					'default'           => esc_html_x( '404', 'front-end', 'geeks' ),
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				]
			);

			$wp_customize->add_control(
				'404_title',
				[
					'type'    => 'text',
					'section' => 'geeks_404',
					'label'   => esc_html__( '404 Title', 'geeks' ),
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'404_title',
				[
					'selector'        => '.404_title',
					'render_callback' => function () {
						return esc_html( get_theme_mod( '404_title' ) );
					},
				]
			);

			$wp_customize->add_setting(
				'404_description',
				[
					'default'           => esc_html_x( 'Oops! Sorry, we couldn’t find the page you were looking for. If you think this is a problem with us, please Contact us', 'front-end', 'geeks' ),
					'sanitize_callback' => 'wp_kses_post',
					'transport'         => 'postMessage',
				]
			);

			$wp_customize->add_control(
				'404_description',
				[
					'type'    => 'textarea',
					'section' => 'geeks_404',
					'label'   => esc_html__( 'Description', 'geeks' ),
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'404_description',
				[
					'selector'        => '.404_desc',
					'render_callback' => function () {
						return esc_html( get_theme_mod( '404_description' ) );
					},
				]
			);

			$wp_customize->add_setting(
				'404_button_text',
				[
					'default'           => esc_html__( 'Back to Safety', 'geeks' ),
					'sanitize_callback' => 'wp_kses_post',
					'transport'         => 'postMessage',
				]
			);

			$wp_customize->add_control(
				'404_button_text',
				[
					'type'        => 'text',
					'section'     => 'geeks_404',
					'label'       => esc_html__( 'Button Text', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to change the button text', 'geeks' ),

				]
			);

			$wp_customize->selective_refresh->add_partial(
				'404_button_text',
				[
					'selector'         => '.404_button_text',
					'fallback_refresh' => true,

				]
			);

			$wp_customize->add_setting(
				'404_button_color',
				[
					'default'           => 'primary',
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'404_button_color',
				[
					'type'    => 'select',
					'section' => 'geeks_404',
					'label'   => esc_html__( 'Button Color', 'geeks' ),
					'choices' => [
						'primary'  => esc_html_x( 'Primary', 'button', 'geeks' ),
						'success'  => esc_html_x( 'Success', 'button', 'geeks' ),
						'danger'   => esc_html_x( 'Danger', 'button', 'geeks' ),
						'warning'  => esc_html_x( 'Warning', 'button', 'geeks' ),
						'info'     => esc_html_x( 'Info', 'button', 'geeks' ),
						'dark'     => esc_html_x( 'Dark', 'button', 'geeks' ),
						'gradient' => esc_html_x( 'Gradient', 'button', 'geeks' ),
						'link'     => esc_html_x( 'Link', 'button', 'geeks' ),
					],
				]
			);

			$wp_customize->add_setting(
				'404_button_url',
				[
					'default'           => '#',
					'sanitize_callback' => 'esc_url_raw',
				]
			);

			$wp_customize->add_control(
				'404_button_url',
				[
					'type'        => 'url',
					'section'     => 'geeks_404',
					'priority'    => 60,
					'label'       => esc_html__( 'Button Url', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to change button url.', 'geeks' ),
				]
			);
		}

		/**
		 * Customize site footer
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public function customize_footer( $wp_customize ) {
			$wp_customize->add_section(
				'geeks_footer',
				[
					'title'       => esc_html__( 'Footer', 'geeks' ),
					'description' => esc_html__( 'Customize the theme footer.', 'geeks' ),
					'priority'    => 100,
				]
			);

			$this->add_footer_section( $wp_customize );

		}

		/**
		 * Customizer Controls For Footer.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		private function add_footer_section( $wp_customize ) {
			$geeks_footer_copyright_default = sprintf( '&copy; %s %s. %s', gmdate( 'Y' ), get_bloginfo( 'name' ), esc_html__( 'All Rights Reserved', 'geeks' ) );

			$wp_customize->add_setting(
				'footer_variant',
				[
					'default'           => 'v1',
					'sanitize_callback' => 'sanitize_key',
				]
			);
			$wp_customize->add_control(
				'footer_variant',
				[
					'type'        => 'select',
					'section'     => 'geeks_footer',
					'label'       => esc_html__( 'Footer Version', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to choose your footer type.', 'geeks' ),
					'choices'     => [
						'v1'         => esc_html__( 'Footer v1', 'geeks' ),
						'v2'         => esc_html__( 'Footer v2', 'geeks' ),
						'speciality' => esc_html__( 'Footer Speciality', 'geeks' ),

					],
				]
			);
			$wp_customize->selective_refresh->add_partial(
				'footer_variant',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_footer_widgets',
				[
					'default'           => false,
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'enable_footer_widgets',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_footer',
					'label'           => esc_html__( 'Enable Footer Widgets ', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to show or hide footer widgets in Footer.', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'footer_variant' ),
							[
								'v1',

							],
							true
						);
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_footer_widgets',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_footer_white_background',
				[
					'default'           => false,
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'enable_footer_white_background',
				[
					'type'            => 'checkbox',
					'section'         => 'geeks_footer',
					'label'           => esc_html__( 'Enable Footer White Background ', 'geeks' ),
					'description'     => esc_html__( 'This setting allows you to show or hide footer white background in Footer.', 'geeks' ),
					'active_callback' => function () {
						return in_array(
							get_theme_mod( 'footer_variant' ),
							[
								'v1',

							],
							true
						);
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_footer_white_background',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'geeks_copyright',
				[
					'default'           => $geeks_footer_copyright_default,
					'sanitize_callback' => 'wp_kses_post',

				]
			);
			$wp_customize->add_control(
				'geeks_copyright',
				[
					'type'        => 'textarea',
					'section'     => 'geeks_footer',
					/* translators: label field for setting in Customizer */
					'label'       => esc_html__( 'Copyright', 'geeks' ),
					/* translators: description field for "Copyright" setting in Customizer */
					'description' => esc_html__( 'HTML is allowed in this field.', 'geeks' ),
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'geeks_copyright',
				[
					'selector'        => '.geeks-copyright',
					'render_callback' => 'geeks_copyright_text',

				]
			);

		}

		/**
		 * Customize site blog
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public function customize_blog( $wp_customize ) {
			$wp_customize->add_section(
				'geeks_blog',
				[
					/* translators: title of section in Customizer */
					'title'       => esc_html__( 'Blog', 'geeks' ),
					'description' => esc_html__( 'This section contains settings related to posts listing archives and single post.', 'geeks' ),
					'priority'    => 90,
				]
			);

			$this->add_blog_section( $wp_customize );
		}

		/**
		 * Customizer Controls For Blog.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		private function add_blog_section( $wp_customize ) {

			$wp_customize->add_setting(
				'geeks_enable_sidebar_widget_area',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);

			$wp_customize->add_control(
				'geeks_enable_sidebar_widget_area',
				[
					'type'        => 'checkbox',
					'priority'    => 10,
					'label'       => esc_html__( 'Enable Sidebar Widget Area?', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to enable or disable sidebar widget area.', 'geeks' ),
					'section'     => 'geeks_blog',
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'geeks_enable_sidebar_widget_area',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'blog_layout',
				[
					'default'           => 'right-sidebar',
					'sanitize_callback' => 'sanitize_key',
				]
			);
			$wp_customize->add_control(
				'blog_layout',
				[
					'type'            => 'select',
					'section'         => 'geeks_blog',
					/* translators: label field of control in Customizer */
					'label'           => esc_html__( 'Blog Layout', 'geeks' ),
					'description'     => esc_html__( 'Choose the layout of your blog.', 'geeks' ),
					'choices'         => [
						'fullwidth'     => esc_html__( 'Full width', 'geeks' ),
						'left-sidebar'  => esc_html__( 'Left Sidebar', 'geeks' ),
						'right-sidebar' => esc_html__( 'Right Sidebar', 'geeks' ),
					],
					'active_callback' => function () {
						return get_theme_mod( 'geeks_enable_sidebar_widget_area' );
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'blog_layout',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_full_width_sticky_post',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);

			$wp_customize->add_control(
				'enable_full_width_sticky_post',
				[
					'type'        => 'checkbox',
					'priority'    => 10,
					'label'       => esc_html__( 'Enable Full-width Sticky Post ?', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to enable or disable full width sticky post.', 'geeks' ),
					'section'     => 'geeks_blog',
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_full_width_sticky_post',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'blog_related_posts',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);

			$wp_customize->add_control(
				'blog_related_posts',
				[
					'type'        => 'checkbox',
					'section'     => 'geeks_blog',
					'label'       => esc_html__( 'Enable Blog Related Posts', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to enable related posts', 'geeks' ),
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'blog_related_posts',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'geeks_single_post_social_share',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',
				]
			);

			$wp_customize->add_control(
				'geeks_single_post_social_share',
				[
					'type'        => 'checkbox',
					'section'     => 'geeks_blog',
					'label'       => esc_html__( 'Enable Social Share in Single Post', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to enable social share', 'geeks' ),

				]
			);

			$wp_customize->selective_refresh->add_partial(
				'geeks_single_post_social_share',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'enable_newsletter_subscription',
				[
					'default'           => false,
					'sanitize_callback' => 'geeks_sanitize_checkbox',

				]
			);

			$wp_customize->add_control(
				'enable_newsletter_subscription',
				[
					'type'        => 'checkbox',
					'section'     => 'geeks_blog',
					'label'       => esc_html__( 'Enable Newsletter Form', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to enable / disable newsletter form in Single Post', 'geeks' ),
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'enable_newsletter_subscription',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'newsletter_form_title',
				[
					'default'           => esc_html_x( 'Sign up for our Newsletter', 'front-end', 'geeks' ),
					'sanitize_callback' => 'sanitize_text_field',
					'transport'         => 'postMessage',
				]
			);

			$wp_customize->add_control(
				'newsletter_form_title',
				[
					'type'            => 'text',
					'section'         => 'geeks_blog',
					'label'           => esc_html__( 'Newsletter Form Title', 'geeks' ),
					'active_callback' => function () {
						return get_theme_mod( 'enable_newsletter_subscription', false );
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'newsletter_form_title',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'newsletter_form_desc',
				[
					'default'           => esc_html_x( 'Join our newsletter and get resources, curated content, and design inspiration delivered straight to your inbox.', 'front-end', 'geeks' ),
					'sanitize_callback' => 'sanitize_textarea_field',
					'transport'         => 'postMessage',
				]
			);

			$wp_customize->add_control(
				'newsletter_form_desc',
				[
					'type'            => 'textarea',
					'section'         => 'geeks_blog',
					'label'           => esc_html__( 'Newsletter Form Description', 'geeks' ),
					'active_callback' => function () {
						return get_theme_mod( 'enable_newsletter_subscription', false );
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'newsletter_form_desc',
				[
					'fallback_refresh' => true,
				]
			);

			$wp_customize->add_setting(
				'geeks_newsletter_subscription_form',
				[
					'sanitize_callback' => 'geeks_slug_sanitize_html',
				]
			);

			$wp_customize->add_control(
				'geeks_newsletter_subscription_form',
				[
					'type'            => 'textarea',
					'section'         => 'geeks_blog',
					'label'           => esc_html__( 'Enter Newsletter Form Shortcode', 'geeks' ),
					'description'     => esc_html__( 'Paste your newsletter signup form or shortcode', 'geeks' ),
					'active_callback' => function () {
						return get_theme_mod( 'enable_newsletter_subscription', false );
					},
				]
			);

			$wp_customize->selective_refresh->add_partial(
				'geeks_newsletter_subscription_form',
				[
					'fallback_refresh' => true,
				]
			);

		}


		/**
		 * Returns an array of the desired default Landkit Options
		 *
		 * @return array
		 */
		public function get_geeks_default_setting_values() {
			return apply_filters(
				'geeks_setting_default_values',
				$args = array(
					'geeks_navbar_button_background' => '#754ffe',
				)
			);
		}

		/**
		 * Adds a value to each Landkit setting if one isn't already present.
		 *
		 * @uses get_landkit_default_setting_values()
		 */
		public function default_theme_mod_values() {
			foreach ( $this->get_geeks_default_setting_values() as $mod => $val ) {
				add_filter( 'theme_mod_' . $mod, array( $this, 'get_theme_mod_value' ), 10 );
			}
		}

		/**
		 * Get theme mod value.
		 *
		 * @param string $value Theme modification value.
		 * @return string
		 */
		public function get_theme_mod_value( $value ) {
			$key = substr( current_filter(), 10 );

			$set_theme_mods = get_theme_mods();

			if ( isset( $set_theme_mods[ $key ] ) ) {
				return $value;
			}

			$values = $this->get_geeks_default_setting_values();

			return isset( $values[ $key ] ) ? $values[ $key ] : $value;
		}

		/**
		 * Set Customizer setting defaults.
		 * These defaults need to be applied separately as child themes can filter landkit_setting_default_values
		 *
		 * @param  array $wp_customize the Customizer object.
		 * @uses   get_landkit_default_setting_values()
		 */
		public function edit_default_customizer_settings( $wp_customize ) {
			foreach ( $this->get_geeks_default_setting_values() as $mod => $val ) {
				$wp_customize->get_setting( $mod )->default = $val;
			}
		}


		/**
		 * Get all of the Landkit theme mods.
		 *
		 * @return array $landkit_theme_mods The Landkit Theme Mods.
		 */
		public function get_geeks_theme_mods() {
			$geeks_theme_mods = array(
				'header_button_background' => get_theme_mod( 'geeks_navbar_button_background' ),
			);

			return apply_filters( 'geeks_theme_mods', $geeks_theme_mods );
		}

		/**
		 * Get Customizer css.
		 *
		 * @see get_landkit_theme_mods()
		 * @return array $styles the css
		 */
		public function get_css() {
			$geeks_theme_mods        = $this->get_geeks_theme_mods();
			$button_color            = $geeks_theme_mods['header_button_background'];
			$button_color_yiq        = geeks_sass_yiq( $button_color );
			$button_color_darken_10p = geeks_adjust_color_brightness( $button_color, -10 );

			$styles = '
            .btn-primary {
                background-color: ' . $button_color . ';
                color: ' . $button_color_yiq . ';
                border-color: ' . $button_color . ';

            }

            .btn-outline-primary {
            	border-color: ' . $button_color . ';
                color: ' . $button_color . ';
            }

            .btn-outline-primary:hover,
            .btn-outline-primary:focus {
 				border-color: ' . $button_color_darken_10p . ';
 			}

 			.btn-primary:focus,
 			.btn-outline-primary:focus,
 			.btn-outline-primary.active:focus, 
 			.btn-outline-primary:active:focus,
 			.btn-primary.active:focus, 
 			.btn-primary:active:focus {
 				box-shadow: 0 0 0 0.25rem ' . geeks_sass_hex_to_rgba( $button_color, '0.5' ) . ';

 			}

            .btn-primary:hover,
            .btn-primary:focus,
            .btn-outline-primary:hover,
            .btn-outline-primary:focus {
                background-color: ' . $button_color_darken_10p . ';
                color: ' . $button_color_yiq . ';
                border-color: ' . $button_color_darken_10p . ';

            }';

			return apply_filters( 'geeks_customizer_css', $styles );
		}

		/**
		 * Add CSS in <head> for styles handled by the theme customizer
		 *
		 * @since 1.0.0
		 * @return void
		 */
		public function add_customizer_css() {
			if ( get_theme_mod( 'button_color' ) === 'custom' ) {
				wp_add_inline_style( 'geeks-style', $this->get_css() );
			}
		}

		/**
		 * Customize site Custom Theme Color
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		public function customize_customcolor( $wp_customize ) {

			/*
			 * Custom Color Enable / Disble Toggle
			 */
			$wp_customize->add_setting(
				'geeks_enable_custom_color',
				[
					'default'           => 'no',
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'geeks_enable_custom_color',
				[
					'type'        => 'radio',
					'section'     => 'colors',
					'label'       => esc_html__( 'Enable Custom Color?', 'geeks' ),
					'description' => esc_html__(
						'This settings allow you to apply your custom color option.',
						'geeks'
					),
					'choices'     => [
						'yes' => esc_html__( 'Yes', 'geeks' ),
						'no'  => esc_html__( 'No', 'geeks' ),
					],
				]
			);

			/**
			 * Primary Color
			 */
			$wp_customize->add_setting(
				'geeks_primary_color',
				array(
					'default'           => apply_filters( 'geeks_default_primary_color', '#754ffe' ),
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'geeks_primary_color',
					array(
						'label'           => esc_html__( 'Primary color', 'geeks' ),
						'section'         => 'colors',
						'settings'        => 'geeks_primary_color',
						'active_callback' => function () {
							return get_theme_mod( 'geeks_enable_custom_color', 'no' ) === 'yes';
						},
					)
				)
			);

		}

	}
endif;

return new Geeks_Customizer();
