<?php
/**
 * Geeks functions.
 *
 * @package geeks
 */

if ( ! function_exists( 'geeks_custom_excerpt_length' ) ) {
	/**
	 * Excerpt length.
	 *
	 * @param  int $length default excerpt length.
	 * @return int
	 */
	function geeks_custom_excerpt_length( $length ) {
		$show_masonry = geeks_posts_masonry_enabled();

		if ( is_sticky() && ! is_active_sidebar( 'blog-sidebar' ) && ! $show_masonry ) {
			$length = 18;
		} else {
			$length = 12;
		}
		return $length;
	}
}


if ( ! function_exists( 'geeks_new_excerpt_more' ) ) {
	/**
	 * Excerpt more.
	 *
	 * @param  string $more default excerpt text.
	 * @return string
	 */
	function geeks_new_excerpt_more( $more ) {
		return '...';
	}
}

/**
 * Query LearnPress activation
 */
function geeks_is_learnpress_activated() {
	return class_exists( 'LearnPress' ) ? true : false;
}


if ( ! function_exists( 'geeks_is_mas_static_content_activated' ) ) {
	/**
	 * Query MAS Static Content activation
	 */
	function geeks_is_mas_static_content_activated() {
		return class_exists( 'Mas_Static_Content' ) ? true : false;
	}
}

/**
 * Query WP Job Mananger activation
 */
function geeks_is_wp_job_manager_activated() {
	return class_exists( 'WP_Job_Manager' ) ? true : false;
}

/**
 * Query ACF activation
 */
function geeks_is_acf_activated() {
	return function_exists( 'get_field' ) ? true : false;
}

/**
 * Query Tutor LMS activation
 */
function geeks_is_tutor_activated() {
	return function_exists( 'tutor_lms' ) ? true : false;
}

/**
 * Query Course Review activation
 */
function geeks_is_course_review_activated() {
	return class_exists( 'LP_Addon_Course_Review' ) ? true : false;
}

/**
 * Query WooCommerce activation
 */
function geeks_is_woocommerce_activated() {
	return class_exists( 'WooCommerce' ) ? true : false;
}

/**
 * Query Geeks Extensions activation
 */
function geeks_is_gke_activated() {
	return class_exists( 'Geeks_Extensions' ) ? true : false;
}

if ( ! function_exists( 'geeks_is_ocdi_activated' ) ) {
	/**
	 * Check if One Click Demo Import is activated
	 */
	function geeks_is_ocdi_activated() {
		return class_exists( 'OCDI_Plugin' ) ? true : false;
	}
}

if ( ! function_exists( 'geeks_bootstrap_pagination' ) ) {
	/**
	 * Display pagination in Bootstrap format.
	 *
	 * @param WP_Query|null $wp_query WordPress query.
	 * @param bool          $echo     should echo or return.
	 * @param string        $ul_class class for the <ul> wrapper.
	 * @param string        $a_class  class for the anchor.
	 *
	 * @return string
	 * Accepts a WP_Query instance to build pagination (for custom wp_query()),
	 * or nothing to use the current global $wp_query (eg: taxonomy term page)
	 * - Tested on WP 4.9.5
	 * - Tested with Bootstrap 4.1
	 * - Tested on Sage 9
	 *
	 * USAGE:
	 *     <?php echo koach_bootstrap_pagination(); ?> //uses global $wp_query
	 * or with custom WP_Query():
	 *     <?php
	 *      $query = new \WP_Query($args);
	 *       ... while(have_posts()), $query->posts stuff ...
	 *       echo koach_bootstrap_pagination($query);
	 *     ?>
	 */
	function geeks_bootstrap_pagination( \WP_Query $wp_query = null, $echo = true, $ul_class = '', $a_class = '' ) {

		if ( null === $wp_query ) {
			global $wp_query;
		}

		$pages = paginate_links(
			[
				'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
				'format'       => '?paged=%#%',
				'current'      => max( 1, get_query_var( 'paged' ) ),
				'total'        => $wp_query->max_num_pages,
				'type'         => 'array',
				'show_all'     => false,
				'end_size'     => 3,
				'mid_size'     => 1,
				'prev_next'    => true,
				'prev_text'    => esc_html__( '&laquo; Prev', 'geeks' ),
				'next_text'    => esc_html__( 'Next &raquo;', 'geeks' ),
				'add_args'     => false,
				'add_fragment' => '',
			]
		);

		if ( is_array( $pages ) ) {

			if ( ! empty( $ul_class ) ) {
				$ul_class = ' ' . $ul_class;
			}

			$pagination = '<nav aria-label="' . esc_attr__( 'Page navigation', 'geeks' ) . '"><ul class="pagination' . esc_attr( $ul_class ) . '">';

			foreach ( $pages as $page ) {
				$t           = ( strpos( $page, 'current' ) === false ) ? $a_class : '';
				$t          .= ' page-link';
				$pagination .= '<li class="page-item' . ( strpos( $page, 'current' ) !== false ? ' active' : '' ) . '">' . str_replace( 'page-numbers', $t, $page ) . '</li>';
			}

			$pagination .= '</ul></nav>';

			if ( $echo ) {
				echo wp_kses_post( $pagination );
			} else {
				return $pagination;
			}
		}

		return null;
	}
}

if ( ! function_exists( 'geeks_option_enabled_post_types' ) ) {
	function geeks_option_enabled_post_types() {
		$post_types = [ 'post', 'page' ];
		return apply_filters( 'geeks_option_enabled_post_types', $post_types );
	}
}


/**
 * Wrapper for ACF get_field function to make sure ACF is activated
 *
 *  @param  string $field (string) the field name or key.
 *  @param  int    $post_id (mixed) the post_id of which the value is saved against.
 *  @param  int    $format_value (boolean) whether or not to format the value as described above.
 *  @return (mixed)
 */
function geeks_get_field( $field, $post_id = false, $format_value = true ) {

	if ( geeks_is_acf_activated() ) {
		return get_field( $field, $post_id, $format_value );
	}

	return false;
}

if ( ! function_exists( 'cs_gallery_shortcode' ) ) :
	/**
	 * Outputs CS Gallery shortcode
	 *
	 * @param array $attr array of attributes.
	 */
	function cs_gallery_shortcode( $attr ) {
		$post = get_post();

		static $instance = 0;
		$instance++;

		if ( ! empty( $attr['ids'] ) ) {
			if ( empty( $attr['orderby'] ) ) {
				$attr['orderby'] = 'post__in';
			}
			$attr['include'] = $attr['ids'];
		}

		$output = apply_filters( 'post_gallery', '', $attr, $instance );

		if ( ! empty( $output ) ) {
			return $output;
		}

		$html5 = current_theme_supports( 'html5', 'gallery' );
		$atts  = shortcode_atts(
			array(
				'order'      => 'ASC',
				'orderby'    => 'menu_order ID',
				'id'         => $post ? $post->ID : 0,
				'itemtag'    => $html5 ? 'figure' : 'dl',
				'icontag'    => $html5 ? 'div' : 'dt',
				'captiontag' => $html5 ? 'div' : 'dd',
				'columns'    => 3,
				'size'       => 'thumbnail',
				'include'    => '',
				'exclude'    => '',
				'link'       => '',
			),
			$attr,
			'gallery'
		);

		$id = intval( $atts['id'] );

		if ( ! empty( $atts['include'] ) ) {
			$_attachments = get_posts(
				array(
					'include'        => $atts['include'],
					'post_status'    => 'inherit',
					'post_type'      => 'attachment',
					'post_mime_type' => 'image',
					'order'          => $atts['order'],
					'orderby'        => $atts['orderby'],
				)
			);

			$attachments = array();
			foreach ( $_attachments as $key => $val ) {
				$attachments[ $val->ID ] = $_attachments[ $key ];
			}
		} elseif ( ! empty( $atts['exclude'] ) ) {
			$attachments = get_children(
				array(
					'post_parent'    => $id,
					'exclude'        => $atts['exclude'],
					'post_status'    => 'inherit',
					'post_type'      => 'attachment',
					'post_mime_type' => 'image',
					'order'          => $atts['order'],
					'orderby'        => $atts['orderby'],
				)
			);
		} else {
			$attachments = get_children(
				array(
					'post_parent'    => $id,
					'post_status'    => 'inherit',
					'post_type'      => 'attachment',
					'post_mime_type' => 'image',
					'order'          => $atts['order'],
					'orderby'        => $atts['orderby'],
				)
			);
		}

		if ( empty( $attachments ) ) {
			return '';
		}

		if ( is_feed() ) {
			$output = "\n";
			foreach ( $attachments as $att_id => $attachment ) {
				if ( ! empty( $atts['link'] ) ) {
					if ( 'none' === $atts['link'] ) {
						$output .= wp_get_attachment_image( $att_id, $atts['size'], false, $attr );
					} else {
						$output .= wp_get_attachment_link( $att_id, $atts['size'], false );
					}
				} else {
					$output .= wp_get_attachment_link( $att_id, $atts['size'], true );
				}
				$output .= "\n";
			}
			return $output;
		}

		$itemtag    = tag_escape( $atts['itemtag'] );
		$captiontag = tag_escape( $atts['captiontag'] );
		$icontag    = tag_escape( $atts['icontag'] );
		$valid_tags = wp_kses_allowed_html( 'post' );

		if ( ! isset( $valid_tags[ $itemtag ] ) ) {
			$itemtag = 'dl';
		}
		if ( ! isset( $valid_tags[ $captiontag ] ) ) {
			$captiontag = 'dd';
		}
		if ( ! isset( $valid_tags[ $icontag ] ) ) {
			$icontag = 'dt';
		}

		$columns   = intval( $atts['columns'] );
		$itemwidth = $columns > 0 ? floor( 100 / $columns ) : 100;
		$float     = is_rtl() ? 'right' : 'left';

		$selector = "gallery-{$instance}";

		$size_class = sanitize_html_class( $atts['size'] );
		// $gallery_div = "<div id='$selector' class='cs-gallery galleryid-{$id} row row-cols-{$columns} gallery-size-{$size_class}'>";

		// $output = apply_filters( 'gallery_style', $gallery_div );

		$thumbnail_classes = 'gallery__img rounded-lg';

		$i = 0;

		foreach ( $attachments as $id => $attachment ) {

			$attr = ( trim( $attachment->post_excerpt ) ) ? array( 'aria-describedby' => "$selector-$id" ) : '';

			if ( ! empty( $atts['link'] ) && 'file' === $atts['link'] ) {
				$image_output = wp_get_attachment_link( $id, $atts['size'], false, false, false, $attr );
			} elseif ( ! empty( $atts['link'] ) && 'none' === $atts['link'] ) {
				$image_output = wp_get_attachment_link( $id, $atts['size'], false, false, false, $attr );
				// $image_output = wp_get_attachment_image( $id, $atts['size'], false, $attr );
			} else {
				$image_output = wp_get_attachment_link( $id, $atts['size'], true, false, false, $attr );
			}

			$image_output = str_replace( 'class="', 'class="' . $thumbnail_classes . ' ', $image_output );

			$image_meta = wp_get_attachment_metadata( $id );

			$orientation      = '';
			$column_increment = '++$i % $columns';

			if ( isset( $image_meta['height'], $image_meta['width'] ) ) {
				$orientation = ( $image_meta['height'] > $image_meta['width'] ) ? 'portrait' : 'landscape';
			}

			$output .= "<{$itemtag} class='gallery__item gallery__item mb-0'>";
			$output .= "$image_output";

			$output .= "</{$itemtag}>";

			if ( ! $html5 && $columns > 0 && 0 === $column_increment ) {
				$output .= '<br style="clear: both" />';
			}
		}

		if ( ! $html5 && $columns > 0 && 0 !== $i % $columns ) {
			$output .= "
			<br style='clear: both' />";
		}

		$output .= "
		</div>\n";

		return $output;
	}

endif;

/**
 * Renders attributes.
 *
 * @param array $attr array of attributes to be rendered.
 */
function geeks_render_attributes( $attr ) {
	$attributes = geeks_get_render_attribute_string( $attr );
	echo apply_filters( 'geeks_render_attributes', $attributes, $attr ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
}


/**
 * Render html attributes
 *
 * @param array $atts array of attributes.
 *
 * @return string escapped attributes string.
 */
function geeks_get_render_attribute_string( array $atts ) {
	$rendered_atts = [];

	foreach ( $atts as $key => $values ) {
		if ( is_array( $values ) ) {
			$values = implode( ' ', $values );
		}

		if ( 'href' === $key ) {
			$rendered_atts[] = sprintf( '%1$s="%2$s"', $key, esc_url( $values ) );
		} else {
			$rendered_atts[] = sprintf( '%1$s="%2$s"', $key, esc_attr( $values ) );
		}
	}

	return implode( ' ', $rendered_atts );
}

/**
 * Gets Row columns class
 *
 * @param array $cols array of columns.
 */
function get_row_cols( $cols ) {
	$class = 'row';
	foreach ( $cols as $key => $col ) {
		if ( empty( $key ) || 'mobile' === $key ) {
			$class .= ' row-cols-' . $col;
		} else {
			$class .= ' row-cols-' . $key . '-' . $col;
		}
	}
	return $class;
}

if ( ! function_exists( 'array_key_last' ) ) {
	/**
	 * Gets the last key of an array. For PHP <= 7.3.0
	 *
	 * @param array $array array of attributes.
	 */
	function array_key_last( $array ) {
		if ( ! is_array( $array ) || empty( $array ) ) {
			return null;
		}

		return array_keys( $array )[ count( $array ) - 1 ];
	}
}

if ( ! function_exists( 'array_key_first' ) ) {
	/**
	 * Gets the first key of an array. For PHP <= 7.3.0
	 *
	 * @param array $arr array of attributes.
	 */
	function array_key_first( array $arr ) {
		foreach ( $arr as $key => $unused ) {
			return $key;
		}
		return null;
	}
}

if ( ! function_exists( 'pr' ) ) {
	/**
	 * Easy to use function wrapper for print_r
	 *
	 * @param array $var array of attributes.
	 */
	function pr( $var ) {
		?><pre><?php print_r( $var, 1 ); ?></pre>
		<?php
	}
}

/**
 * Get data if set, otherwise return a default value or null. Prevents notices when data is not set.
 *
 * @param  mixed  $var     Variable.
 * @param  string $default Default value.
 * @return mixed
 */
function geeks_get_var( &$var, $default = null ) {
	return isset( $var ) ? $var : $default;
}

/**
 * Clean variables using sanitize_text_field. Arrays are cleaned recursively.
 * Non-scalar values are ignored.
 *
 * @param string|array $var Data to sanitize.
 * @return string|array
 */
function geeks_clean( $var ) {
	if ( is_array( $var ) ) {
		return array_map( 'geeks_clean', $var );
	} else {
		return is_scalar( $var ) ? sanitize_text_field( $var ) : $var;
	}
}

/**
 * Get other templates (e.g. product attributes) passing attributes and including the file.
 *
 * @param string $template_name Template name.
 * @param array  $args          Arguments. (default: array).
 * @param string $template_path Template path. (default: '').
 * @param string $default_path  Default path. (default: '').
 */
function geeks_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
	global $geeks_version;
	$cache_key = sanitize_key( implode( '-', array( 'template', $template_name, $template_path, $default_path, $geeks_version ) ) );
	$template  = (string) wp_cache_get( $cache_key, 'geeks' );

	if ( ! $template ) {
		$template = geeks_locate_template( $template_name, $template_path, $default_path );

		// Don't cache the absolute path so that it can be shared between web servers with different paths.
		$cache_path = geeks_tokenize_path( $template, geeks_get_path_define_tokens() );

		geeks_set_template_cache( $cache_key, $cache_path );
	} else {
		// Make sure that the absolute path to the template is resolved.
		$template = geeks_untokenize_path( $template, geeks_get_path_define_tokens() );
	}

	// Allow 3rd party plugin filter template file from their plugin.
	$filter_template = apply_filters( 'geeks_get_template', $template, $template_name, $args, $template_path, $default_path );

	if ( $filter_template !== $template ) {
		if ( ! file_exists( $filter_template ) ) {
			/* translators: %s template */
			_doing_it_wrong( __FUNCTION__, sprintf( esc_html__( '%s does not exist.', 'geeks' ), '<code>' . esc_html( $filter_template ) . '</code>' ), '2.1' );
			return;
		}
		$template = $filter_template;
	}

	$action_args = array(
		'template_name' => $template_name,
		'template_path' => $template_path,
		'located'       => $template,
		'args'          => $args,
	);

	if ( ! empty( $args ) && is_array( $args ) ) {
		if ( isset( $args['action_args'] ) ) {
			_doing_it_wrong(
				__FUNCTION__,
				esc_html__( 'action_args should not be overwritten when calling geeks_get_template.', 'geeks' ),
				'3.6.0'
			);
			unset( $args['action_args'] );
		}
		extract( $args ); // @codingStandardsIgnoreLine
	}

	do_action( 'woocommerce_before_template_part', $action_args['template_name'], $action_args['template_path'], $action_args['located'], $action_args['args'] );

	include $action_args['located'];

	do_action( 'woocommerce_after_template_part', $action_args['template_name'], $action_args['template_path'], $action_args['located'], $action_args['args'] );
}

/**
 * Locate a template and return the path for inclusion.
 *
 * This is the load order:
 *
 * yourtheme/$template_path/$template_name
 * yourtheme/$template_name
 * $default_path/$template_name
 *
 * @param string $template_name Template name.
 * @param string $template_path Template path. (default: '').
 * @param string $default_path  Default path. (default: '').
 * @return string
 */
function geeks_locate_template( $template_name, $template_path = '', $default_path = '' ) {
	if ( ! $template_path ) {
		$template_path = 'templates/';
	}

	if ( ! $default_path ) {
		$default_path = 'templates/';
	}

	// Look within passed path within the theme - this is priority.
	if ( false !== strpos( $template_name, 'product_cat' ) || false !== strpos( $template_name, 'product_tag' ) ) {
		$cs_template = str_replace( '_', '-', $template_name );
		$template    = locate_template(
			array(
				trailingslashit( $template_path ) . $cs_template,
				$cs_template,
			)
		);
	}

	if ( empty( $template ) ) {
		$template = locate_template(
			array(
				trailingslashit( $template_path ) . $template_name,
				$template_name,
			)
		);
	}

	// Get default template/.
	if ( ! $template ) {
		if ( empty( $cs_template ) ) {
			$template = $default_path . $template_name;
		} else {
			$template = $default_path . $cs_template;
		}
	}

	// Return what we found.
	return apply_filters( 'geeks_locate_template', $template, $template_name, $template_path );
}

/**
 * Given a path, this will convert any of the subpaths into their corresponding tokens.
 *
 * @param string $path The absolute path to tokenize.
 * @param array  $path_tokens An array keyed with the token, containing paths that should be replaced.
 * @return string The tokenized path.
 */
function geeks_tokenize_path( $path, $path_tokens ) {
	// Order most to least specific so that the token can encompass as much of the path as possible.
	uasort(
		$path_tokens,
		function ( $a, $b ) {
			$a = strlen( $a );
			$b = strlen( $b );

			if ( $a > $b ) {
				return -1;
			}

			if ( $b > $a ) {
				return 1;
			}

			return 0;
		}
	);

	foreach ( $path_tokens as $token => $token_path ) {
		if ( 0 !== strpos( $path, $token_path ) ) {
			continue;
		}

		$path = str_replace( $token_path, '{{' . $token . '}}', $path );
	}

	return $path;
}

/**
 * Given a tokenized path, this will expand the tokens to their full path.
 *
 * @param string $path The absolute path to expand.
 * @param array  $path_tokens An array keyed with the token, containing paths that should be expanded.
 * @return string The absolute path.
 */
function geeks_untokenize_path( $path, $path_tokens ) {
	foreach ( $path_tokens as $token => $token_path ) {
		$path = str_replace( '{{' . $token . '}}', $token_path, $path );
	}

	return $path;
}

/**
 * Fetches an array containing all of the configurable path constants to be used in tokenization.
 *
 * @return array The key is the define and the path is the constant.
 */
function geeks_get_path_define_tokens() {
	$defines = array(
		'ABSPATH',
		'WP_CONTENT_DIR',
		'WP_PLUGIN_DIR',
		'WPMU_PLUGIN_DIR',
		'PLUGIN' . 'DIR',
		'WP_THEME_DIR',
	);

	$path_tokens = array();
	foreach ( $defines as $define ) {
		if ( defined( $define ) ) {
			$path_tokens[ $define ] = constant( $define );
		}
	}

	return apply_filters( 'geeks_get_path_define_tokens', $path_tokens );
}

/**
 * Add a template to the template cache.
 *
 * @param string $cache_key Object cache key.
 * @param string $template Located template.
 */
function geeks_set_template_cache( $cache_key, $template ) {
	wp_cache_set( $cache_key, $template, 'geeks' );

	$cached_templates = wp_cache_get( 'cached_templates', 'geeks' );
	if ( is_array( $cached_templates ) ) {
		$cached_templates[] = $cache_key;
	} else {
		$cached_templates = array( $cache_key );
	}

	wp_cache_set( 'cached_templates', $cached_templates, 'geeks' );
}

/**
 * Clear the template cache.
 */
function geeks_clear_template_cache() {
	$cached_templates = wp_cache_get( 'cached_templates', 'geeks' );
	if ( is_array( $cached_templates ) ) {
		foreach ( $cached_templates as $cache_key ) {
			wp_cache_delete( $cache_key, 'geeks' );
		}

		wp_cache_delete( 'cached_templates', 'geeks' );
	}
}

/**
 * Define a constant if it is not already defined.
 *
 * @param string $name  Constant name.
 * @param mixed  $value Value.
 */
function geeks_maybe_define_constant( $name, $value ) {
	if ( ! defined( $name ) ) {
		define( $name, $value );
	}
}

/**
 * Check if the variable isset and not empty
 *
 * @param  mixed $var Variable.
 * @return bool
 */
function geeks_isset_and_not_empty( $var ) {
	return isset( $var ) && ! empty( $var );
}

/**
 * Format rating average
 *
 * @param float $rating_avg Rating average.
 */
function geeks_format_rating_avg( $rating_avg ) {
	return number_format_i18n( $rating_avg, 1 );
}

/**
 * Format courses count
 *
 * @param int $courses_count Number of courses.
 */
function geeks_format_courses_count( $courses_count ) {
	return number_format_i18n( $courses_count );
}

/**
 * Format students count
 *
 * @param int $students_count Number of students.
 */
function geeks_format_students_count( $students_count ) {
	return number_format_i18n( $students_count );
}

/**
 * Get the single post share enable or disable.
 *
 * @return boolean
 */
if ( ! function_exists( 'geeks_single_post_is_share_enabled' ) ) {
	/**
	 * Get the single post share enable or disable.
	 *
	 * @return boolean
	 */
	function geeks_single_post_is_share_enabled() {
		$social_share_enable_disable = get_theme_mod( 'geeks_single_post_social_share', false );

		return (bool) apply_filters( 'blogzine_single_post_enable_share', $social_share_enable_disable );
	}
}

if ( ! function_exists( 'geeks_sanitize_checkbox' ) ) {
	/**
	 * Sanitize checkbox.
	 *
	 * @param bool $input state of the checkbox.
	 */
	function geeks_sanitize_checkbox( $input ) {
		// returns true if checkbox is checked.
		return ( ( isset( $input ) && true === $input ) ? true : false );
	}
}

if ( ! function_exists( 'geeks_slug_sanitize_html' ) ) {
	/**
	 * Sanitize Form HTML.
	 *
	 */
	function geeks_slug_sanitize_html( $input ) {

		$allowed = array(
		    'a' => array(
		        'href'   => array(),
		        'title'  => array(),
		        'target' => array(),
		        'class'  => array()
		    ),
		    'br' => array(),
		    'em' => array(),
		    'strong' => array(),
		    'p' => array(
		        'class' => array()
		    ),
		    'form' => array(
		    	'class'  => array(),
		    	'method' => array(),
		    	'action' => array()
		    ),
		    'input' => array(
		      'type'  => array(),
		      'class' => array(),
		      'placeholder' => array()
		    ),
		    'button' => array(
		    	'class' => array(),
		    	'type'  => array()
		    ),
		    'div' => array(
		    	'class' => array()
		    )
		);

		return wp_kses( $input, $allowed );

	}
}

/**
 * Adjust a hex color brightness
 * Allows us to create hover styles for custom link colors
 *
 * @param  strong  $hex   hex color e.g. #111111.
 * @param  integer $steps factor by which to brighten/darken ranging from -255 (darken) to 255 (brighten).
 * @return string        brightened/darkened hex color
 * @since  1.0.0
 */
function geeks_adjust_color_brightness( $hex, $steps ) {
	// Steps should be between -255 and 255. Negative = darker, positive = lighter.
	$steps = max( -255, min( 255, $steps ) );

	// Format the hex color string.
	$hex = str_replace( '#', '', $hex );

	if ( 3 === strlen( $hex ) ) {
		$hex = str_repeat( substr( $hex, 0, 1 ), 2 ) . str_repeat( substr( $hex, 1, 1 ), 2 ) . str_repeat( substr( $hex, 2, 1 ), 2 );
	}

	// Get decimal values.
	$r = hexdec( substr( $hex, 0, 2 ) );
	$g = hexdec( substr( $hex, 2, 2 ) );
	$b = hexdec( substr( $hex, 4, 2 ) );

	// Adjust number of steps and keep it inside 0 to 255.
	$r = max( 0, min( 255, $r + $steps ) );
	$g = max( 0, min( 255, $g + $steps ) );
	$b = max( 0, min( 255, $b + $steps ) );

	$r_hex = str_pad( dechex( $r ), 2, '0', STR_PAD_LEFT );
	$g_hex = str_pad( dechex( $g ), 2, '0', STR_PAD_LEFT );
	$b_hex = str_pad( dechex( $b ), 2, '0', STR_PAD_LEFT );

	return '#' . $r_hex . $g_hex . $b_hex;
}

if ( ! function_exists( 'geeks_sass_yiq' ) ) {
	function geeks_sass_yiq( $hex ) {
		$hex    = sanitize_hex_color( $hex );
		$length = strlen( $hex );
		if ( $length < 5 ) {
			$hex = ltrim( $hex, '#' );
			$hex = '#' . $hex . $hex;
		}

		preg_match( '/^#?([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i', $hex, $matches );

		for ( $i = 1; $i <= 3; $i++ ) {
			$matches[ $i ] = hexdec( $matches[ $i ] );
		}
		$yiq = ( ( $matches[1] * 299 ) + ( $matches[2] * 587 ) + ( $matches[3] * 114 ) ) / 1000;
		return ( $yiq >= 128 ) ? '#000' : '#fff';
	}
}

if ( ! function_exists( 'geeks_sass_hex_to_rgba' ) ) {
	function geeks_sass_hex_to_rgba( $hex, $alpa = '' ) {
		$hex = sanitize_hex_color( $hex );
		preg_match('/^#?([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})$/i', $hex, $matches);
		for($i = 1; $i <= 3; $i++) {
			$matches[$i] = hexdec($matches[$i]);
		}
		if( !empty( $alpa ) ) {
			$rgb = 'rgba(' . $matches[1] . ', ' . $matches[2] . ', ' . $matches[3] . ', ' . $alpa .')';
		} else {
			$rgb = 'rgba(' . $matches[1] . ', ' . $matches[2] . ', ' . $matches[3] . ')';
		}
		return $rgb;
	}
}


require_once get_template_directory() . '/inc/functions/global.php';
require_once get_template_directory() . '/inc/functions/formatting.php';
