<?php
/**
 * Template functions available for Geeks Extensions plugin
 */

if ( ! function_exists( 'geeks_single_path_header' ) ) {
	/**
	 * Displays single path header.
	 */
	function geeks_single_path_header() {
		?>
		<div class="d-md-flex align-items-center justify-content-between bg-white  pt-3 pb-3 pb-lg-5">
			<div class="d-md-flex align-items-center text-lg-start text-center">
				<?php if ( has_post_thumbnail() ) : ?>
				<div class="me-3 mt-n8">
					<?php the_post_thumbnail( 'post-thumbnail', array( 'class' => 'avatar-xxl rounded border p-4 bg-white' ) ); ?>
				</div>
				<?php endif; ?>
				<div class="mt-3 mt-md-0">
					<h1 class="mb-0 fw-bold me-3"><?php the_title(); ?></h1>
				</div>
				<?php geeks_single_path_header_stats(); ?>
			</div>
			<?php geeks_single_path_share(); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_single_path_share' ) ) {
	/**
	 * Display share for single path.
	 */
	function geeks_single_path_share() {
		?>
		<div class="mt-3 mt-lg-0 text-lg-start text-center">
			<span class="dropdown ">
				<a class="text-decoration-none btn-icon btn-light rounded-circle text-muted" href="#" role="button" id="shareDropdown" data-bs-toggle="dropdown" aria-expanded="false">
					<i class="fe fe-share-2 fs-4 "></i>
				</a>
				<span class="dropdown-menu" aria-labelledby="shareDropdown">
					<span class="dropdown-header"><?php echo esc_html__( 'Share', 'geeks' ); ?></span>
					<?php 
					$services = Geeks_SocialMedia::get_share_services();
					foreach ( $services as $key => $service ) :
						if ( ! isset( $service['share'] ) ) {
							continue;
						}
					?>
					<a class="dropdown-item" href="<?php echo esc_url( $service['share'] ); ?>">
						<?php if ( isset( $service['icon'] ) ) : ?>
						<i class="dropdown-item-icon <?php echo esc_attr(  $service['icon'] ); ?>"></i>
						<?php 
						endif; 

						if ( isset( $service['name'] ) ) {
							echo esc_html( $service['name'] ); 
						}
						?>
					</a>
					<?php endforeach; ?>
				</span>
			</span>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_single_path_header_stats' ) ) {
	/**
	 * Displays stats in single path header
	 */
	function geeks_single_path_header_stats() {
		$stats = apply_filters( 'geeks_single_path_header_stats', [
			'students' => [
				'label' => esc_html__( 'Students', 'geeks' ),
				'value' => geeks_acf_get_path_students_count(),
			],
			'courses'  => [
				'label' => esc_html__( 'Courses', 'geeks' ),
				'value' => geeks_acf_get_path_courses_count(),
			],
			'hours'  => [
				'label' => esc_html__( 'Hours', 'geeks' ),
				'value' => geeks_acf_get_path_hours_count(),
			],
		] );

		if ( ! empty( $stats ) ) :
		?>
		<div>
		<?php foreach ( $stats as $stat ) : ?>
			<?php if ( $stat['value'] && 0 < absint( $stat['value'] ) ) : ?>
			<span class="ms-2 fs-6"><span class="text-dark fw-medium"><?php echo esc_html( $stat['value'] ); ?></span>
			<?php echo esc_html( $stat['label'] ); ?></span>
			<?php endif; ?>
		<?php endforeach; ?>
		</div>
		<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_single_path_get_tabs' ) ) {
	/**
	 * Gets the tabs for the Single Path.
	 */
	function geeks_single_path_get_tabs() {
		$tabs = [
			'courses' => [
				'label'    => esc_html__( 'Courses', 'geeks' ),
				'callback' => 'geeks_single_path_courses_tab'
			],
			'about' => [
				'label'    => esc_html__( 'About', 'geeks' ),
				'callback' => 'geeks_single_path_about_tab'
			],
			'instructors' => [
				'label'    => esc_html__( 'Instructors', 'geeks' ),
				'callback' => 'geeks_single_path_instructors_tab'
			]
		];

		return apply_filters( 'geeks_single_path_tabs', $tabs );
	}
}

if ( ! function_exists( 'geeks_single_path_tabs' ) ) {
	/**
	 * Display single path tabs.
	 */
	function geeks_single_path_tabs() {
		$tabs = geeks_single_path_get_tabs();

		if ( ! empty( $tabs ) ) :
		?>
		<ul class="nav nav-lt-tab" id="pills-tab" role="tablist">
			<?php 
			foreach( $tabs as $key => $tab ) : 
				$cls_item = 'nav-item';
				$cls_link = 'nav-link';
				$selected = 'false';

				if ( ! isset( $first ) ) {
					$cls_item .= ' ms-0';
					$cls_link .= ' active';
					$selected  = 'true';
				}
			?>
			<li class="<?php echo esc_attr( $cls_item ); ?>" role="presentation">
				<a class="<?php echo esc_attr( $cls_link ); ?>" id="pills-<?php echo esc_attr( $key ); ?>-tab" data-bs-toggle="pill" href="#pills-<?php echo esc_attr( $key ); ?>" role="tab" aria-controls="pills-<?php echo esc_attr( $key ); ?>" aria-selected="<?php echo esc_attr( $selected ); ?>"><?php echo esc_html( $tab['label'] ); ?></a>
			</li>
			<?php 
				$first = false;
			endforeach; 
			?>
		</ul>
		<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_single_path_tab_content' ) ) {
	/**
	 * Displays the tab content of single path tabs
	 */
	function geeks_single_path_tab_content() {
		$tabs = geeks_single_path_get_tabs();

		if ( ! empty( $tabs ) ) :
		?>
		<div class="tab-content" id="pills-tabContent">
			<?php
			foreach( $tabs as $key => $tab ) :
				$cls_pane = 'tab-pane fade';

				if ( ! isset( $first ) ) {
					$cls_pane .= ' active show';
				}
			?>
			<div class="<?php echo esc_attr( $cls_pane ); ?>" id="pills-<?php echo esc_attr( $key ); ?>" role="tabpanel" aria-labelledby="pills-<?php echo esc_attr( $key ); ?>-tab">
				<?php call_user_func( $tab['callback'] ); ?>
            </div>
            <?php
            	$first = false;
        	endforeach;
        	?>
		</div>
		<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_single_path_courses_tab' ) ) {
	/**
	 * Displays courses tab in Single Path
	 */
	function geeks_single_path_courses_tab() {
		$display_type = geeks_acf_get_path_display_type();
		switch ( $display_type ) {
			case 'blocks':
			geeks_single_path_courses_display_blocks();
			break;
			case 'all':
			geeks_single_path_courses_display_all();
			break;
			case 'editor':
			the_content();
			break;
		}
	}
}

if ( ! function_exists( 'geeks_single_path_courses_display_blocks' ) ) {
	/**
	 * Display Path courses as blocks.
	 */
	function geeks_single_path_courses_display_blocks() {
		$sections       = [ 1, 2, 3 ];
		$count_sections = count( $sections );
		$i              = 0;

		foreach ( $sections as $section ) {
			$i++;
			$content = geeks_acf_get_path_section( $section );
			if ( isset( $content['title'] ) || isset( $content['description'] ) || isset( $content['select_courses'] ) ) :
			?><section class="section__path-courses">
				<?php if ( geeks_isset_and_not_empty( $content['title'] ) ) : ?>
				<header class="mb-5">
					<h2 class="mb-1"><?php echo esc_html( $content['title'] ); ?></h2>
					<?php if ( geeks_isset_and_not_empty( $content['description'] ) ) : ?>
						<p><?php echo esc_html( $content['description'] ); ?></p>
					<?php endif; ?>
				</header>
				<?php endif; ?>

				<?php if ( 'static' === $content['select_courses'] && geeks_isset_and_not_empty( $content['select_courses_static'] ) ) : ?>

				<ul class="row row-cols-lg-4 row-cols-md-2 row-cols-1 list-unstyled mb-0">
					<?php 
					global $post;
					foreach( $content['select_courses_static'] as $post ) : 
						setup_postdata( $post ); ?>
					<li class="col"><?php tutor_load_template( 'loop.course' ); ?></li>
					<?php endforeach; ?>
				</ul>
				
				<?php wp_reset_postdata(); ?>

				<?php endif; ?>

			</section>
			<?php if ( $count_sections !== $i ) : ?>
			<hr class="my-5">
			<?php endif;
			endif;
		}
	}
}

if ( ! function_exists( 'geeks_single_path_courses_display_all' ) ) {
	/**
	 * Display single path courses in all display type.
	 */
	function geeks_single_path_courses_display_all() {
		$courses = geeks_acf_get_path_courses();
		
		if ( $courses ) :
			?>
			<ul class="row row-cols-lg-4 row-cols-md-2 row-cols-1 list-unstyled mb-0">
			<?php
			global $post;
			
			foreach( $courses as $post ) {
				setup_postdata( $post );

				?>
				<li class="col"><?php tutor_load_template( 'loop.course' ); ?></li>
				<?php
			}

			wp_reset_postdata();

			?>
			</ul>
			<?php
		else :

		?><div class="text-center"><?php esc_html_e( 'No courses in this path.', 'geeks' ); ?></div>
		<?php

		endif;
	}
}

if ( ! function_exists( 'geeks_single_path_about_tab' ) ) {
	/**
	 * Displays about tab in Single Path
	 */
	function geeks_single_path_about_tab() {
		?>
		<div class="card">
			<div class="card-header">
				<h3 class="mb-0"><?php echo esc_html__( 'About Path', 'geeks' ); ?></h3>
			</div>
			<div class="card-body">
			<?php
			$about = geeks_acf_get_path_about();

			if ( $about ) {
				echo wp_kses_post( $about );
			}
			?>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_single_path_instructors_tab' ) ) {
	/**
	 * Display instructors tab in single path.
	 */
	function geeks_single_path_instructors_tab() {
		$display_type = geeks_acf_get_path_display_type();
		switch ( $display_type ) {
			case 'blocks':
			geeks_single_path_instructors_display_blocks();
			break;
			case 'all':
			geeks_single_path_instructors_display_all();
			break;
			case 'editor':
			geeks_single_path_instructors_display_editor();
			break;
		}
	}
}

if ( ! function_exists( 'geeks_single_path_instructors_display_blocks' ) ) {
	/**
	 * Display instructors in tab for display type blocks.
	 */
	function geeks_single_path_instructors_display_blocks() {
		$sections = [ 1, 2, 3 ];
		$courses  = [];

		foreach ( $sections as $section ) {
			$content = geeks_acf_get_path_section( $section );
			if ( 'static' === $content['select_courses'] && geeks_isset_and_not_empty( $content['select_courses_static'] ) ) {
				$courses = array_merge( $courses, $content['select_courses_static'] );
			}
		}
		geeks_output_single_path_instructors( $courses );
	}
}

if ( ! function_exists( 'geeks_single_path_instructors_display_all' ) ) {
	/**
	 * Display instructors in tab for display type all.
	 */
	function geeks_single_path_instructors_display_all() {
		$courses = geeks_acf_get_path_courses();
		geeks_output_single_path_instructors( $courses );
	}
}

if ( ! function_exists( 'geeks_output_single_path_instructors' ) ) {
	/**
	 * Displays single path instructors. This is a general function.
	 *
	 * @param array $courses Array of courses
	 */
	function geeks_output_single_path_instructors( $courses ) {
		$instructors = [];
		
		if ( $courses ) :
			?>
			<ul class="row row-cols-lg-2 row-cols-md-2 row-cols-1 list-unstyled mb-0">
			<?php
			global $post;
			
			foreach( $courses as $post_id ) {
				$post = get_post( $post_id );
				setup_postdata( $post );
				if ( ! in_array( $post->post_author, $instructors, true ) ) :
				?>
				<li class="col"><?php geeks_tutor_display_instructor_list_view( $post->post_author ); ?></li>
				<?php
				endif;
				$instructors[] = $post->post_author;
			}

			wp_reset_postdata();

			?>
			</ul>
			<?php
		else :

		?><div class="text-center"><?php esc_html_e( 'No instructors in this path.', 'geeks' ); ?></div>
		<?php

		endif;
	}
}

if ( ! function_exists( 'geeks_single_path_instructors_display_editor' ) ) {
	/**
	 * Display instructors in tab for display type editor.
	 */
	function geeks_single_path_instructors_display_editor() {
		$instructors = geeks_acf_get_path_instructors();
		if ( $instructors ) :
			?>
			<ul class="row row-cols-lg-2 row-cols-md-2 row-cols-1 list-unstyled mb-0">
			<?php
			foreach( $instructors as $instructor ) {
				?><li class="col"><?php geeks_tutor_display_instructor_list_view( $instructor->ID ); ?></li>
				<?php
			}
			?>
			</ul>
			<?php
		endif;
	}
}