<?php
/**
 * Geeks Learnpress Customizer Class
 *
 * @package  geeks
 * @since    1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks_Learnpress_Customizer' ) ) :

	/**
	 * The Geeks Learnpress Customizer class
	 */
	class Geeks_Learnpress_Customizer extends Geeks_Customizer {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */

		public function __construct() {
			add_action( 'customize_register', array( $this, 'customize_learnpress' ), 10 );
		}


		/**
		 * Add postMessage support for site title and description for the Theme Customizer along with several other settings.
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 * @since 2.4.0
		 */
		public function customize_learnpress( $wp_customize ) {
			/**
			 * Helpcenter
			 */
			$wp_customize->add_section(
				'geeks_learnpress',
				[
					'priority'    => 60,
					'title'       => esc_html__( 'Learnpress', 'geeks' ),
					'description' => esc_html__( 'This section contains settings related to single article', 'geeks' ),
				]
			);

			$this->add_learnpress_section( $wp_customize );
		}


		/**
		 * Learnpress Section
		 *
		 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
		 */
		private function add_learnpress_section( $wp_customize ) {

			$wp_customize->add_setting(
				'single_course_version',
				[
					'default'           => 'v1',
					'sanitize_callback' => 'sanitize_key',
				]
			);

			$wp_customize->add_control(
				'single_course_version',
				[
					'type'        => 'select',
					'section'     => 'geeks_learnpress',
					'label'       => esc_html__( 'Single Course Version', 'geeks' ),
					'description' => esc_html__( 'This setting allows you to choose your single course version.', 'geeks' ),
					'choices'     => [
						'v1' => esc_html__( 'Courses Single v1', 'geeks' ),
						'v2' => esc_html__( 'Courses Single v2', 'geeks' ),
					],
				]
			);
			$wp_customize->selective_refresh->add_partial(
				'single_course_version',
				[
					'fallback_refresh' => true,
				]
			);

		}

	}
endif;

return new Geeks_Learnpress_Customizer();
