<?php
/**
 * Functions used in profile page
 */

/**
 * Returns if a profile page is going to display login/register form.
 * 
 * @return bool $is_it
 */
function geeks_profile_is_login_register() {
	$is_it = false;
	
	if ( learn_press_is_profile() ) {
		$is_login 	 = geeks_profile_is_login();
		$is_register = geeks_profile_is_register();

		if ( $is_login || $is_register ) {
			$is_it = true;
		}
	}

	return $is_it;
}

/**
 * Returns if a profile page is going to display login form.
 * 
 * @return bool $is_login
 */
function geeks_profile_is_login() {
	$is_login = false;
	$profile  = LP_Global::profile();

	if ( $profile->get_user()->is_guest() && 'yes' === LP()->settings()->get( 'enable_login_profile' ) ) {
		$is_login = true;
	}

	return $is_login;
}

/**
 * Returns if its a public profile page or not.
 * 
 * @return bool $is_public_profile
 */
function geeks_is_public_profile() {
	return ! geeks_is_dashboard_profile();
}

/**
 * Returns if its a dashboard profile page or not.
 * 
 * @return bool $is_dashboard_profile
 */
function geeks_is_dashboard_profile() {
	$is_dashboard = false;
	
	$profile = LP_Global::profile();
	
	if ( is_user_logged_in() && $profile->is_current_user() ) {
		$is_dashboard = true;
	}

	return $is_dashboard;
}

/**
 * Returns if a profile page is going to display register form.
 * 
 * @return bool $is_register
 */
function geeks_profile_is_register() {
	$is_register = false;
	$profile     = LP_Global::profile();

	if ( $profile->get_user()->is_guest() && 'yes' === LP()->settings()->get( 'enable_login_profile' ) ) {
		$is_register = true;
	}

	return $is_register;
}

/**
 * Returns profile pic avatar
 * 
 * @param $profile LP_Profile
 * @param $size    int
 * @param $args    array|null
 */
function geeks_get_profile_pic( $profile, $size = 80, $args = null ) {
	$profile     = LP_Global::profile();
	$user = $profile->get_user();
	$type = isset( $args['type'] ) ? $args['type'] : '';

	if ( 'gravatar' === $type && function_exists( 'gke_remove_avatar_callback_filter' ) ) {
		gke_remove_avatar_callback_filter();
	}

	$profile_picture_src = $profile->get_upload_profile_src( $size );

	if ( $profile_picture_src ) {
		$user->set_data( 'profile_picture_src', $profile_picture_src );
	}

	$avatar = get_avatar( $user->get_id(), $size, '', esc_attr__( 'User Avatar', 'geeks' ), $args );

	if ( $type == 'gravatar' ) {
		add_filter( 'pre_get_avatar', 'learn_press_pre_get_avatar_callback', 1, 5 );
	}

	return $avatar;
}

/**
 * Override profile tabs
 */
function geeks_override_profile_tabs( $tabs ) {
	
	$tabs['courses']['icon']       = '<i class="fe fe-book nav-icon"></i>';
	$tabs['quizzes']['icon']       = '<i class="fe fe-box nav-icon"></i>';
	$tabs['orders']['icon']        = '<i class="fe fe-shopping-bag nav-icon"></i>';
	$tabs['order-details']['icon'] = '<i class="fe fe-clipboard nav-icon"></i>';
	$tabs['logout' ]['icon']       = '<i class="fe fe-power nav-icon"></i>';
	$tabs['settings']['title']     = esc_html__( 'Account Settings', 'geeks' );

	$tabs['settings']['sections']['basic-information']['icon'] = '<i class="fe fe-settings nav-icon"></i>';
	$tabs['settings']['sections']['change-password']['icon']   = '<i class="fe fe-shield nav-icon"></i>';
	$tabs['settings']['sections']['avatar']['icon']            = '<i class="fe fe-user nav-icon"></i>';
	$tabs['settings']['sections']['privacy']['icon']	       = '<i class="fe fe-lock nav-icon"></i>';
	$tabs['settings']['sections']['privacy']['title']          = esc_html__( 'Profile Privacy', 'geeks' );

	return $tabs;
}