<?php
/**
 * Functions used in Taxonomy pages
 */

/**
 * Get Current Course Tax ID
 */
function geeks_get_course_cat_id() {
    $term = geeks_get_course_tax();
    
    if ( $term ) {
        $term_id = $term->term_id;
    } else {
        $term_id = $term;
    }

    return $term_id;
}

/**
 * Get Current Course Tax slug
 */
function geeks_get_course_cat_slug() {
    $term = geeks_get_course_tax();
    
    if ( $term ) {
        $term_id = $term->slug;
    } else {
        $term_id = $term;
    }

    return $term_id;
}

/**
 * Gets Course Category tax query
 */
function geeks_get_course_category_tax_query( $slug, $args ) {
    $condition = [
        'taxonomy' => 'course_category',
        'field'    => 'slug'
    ];
    
    if ( 0 === $slug ) {
        $slug = geeks_get_course_cat_slug();
    }

    $condition['terms'] = $slug;

    if ( isset( $args['tax_query'] ) ) {
        $args['tax_query'][]             = $condition;
        $args['tax_query']['relation'] = isset( $args['tax_query']['relation'] ) ? $args['tax_query']['relation'] : 'AND';
    } else {
        $args['tax_query'] = array( $condition );
    }

    return $args;
}

/**
 * Get Featured Courses by course category
 */
function geeks_get_featured_courses_by_course_category( $slug = 0, $args = array() ) {
    $args = geeks_get_course_category_tax_query( $slug, $args );
    return geeks_get_featured_courses( $args );
}

/**
 * Get Free Courses by course category
 */
function geeks_get_free_courses_by_course_category( $slug = 0, $args = array() ) {
    $args = geeks_get_course_category_tax_query( $slug, $args );
    return geeks_get_free_courses( $args );
}

/**
 * Get Popular Courses by course category
 */
function geeks_get_popular_courses_by_course_category( $slug = 0, $args = array() ) {
    $args = geeks_get_course_category_tax_query( $slug, $args );
    return geeks_get_popular_courses( $args );
}

/**
 * Get recent courses by course category
 */
function geeks_get_recent_courses_by_course_category( $slug = 0, $args = array() ) {
    $args = geeks_get_course_category_tax_query( $slug, $args );
    return geeks_get_recent_courses( $args );
}

/**
 * Get instructors by course category
 */
function geeks_get_instructors_by_course_category( $view = 'select' ) {
    $course_cat_id = geeks_get_course_cat_id();
    return geeks_get_instructors_by_term_id( $course_cat_id, $view );    
}