<?php
/**
 * Template functions used in the courses loop
 */
if ( ! function_exists( 'geeks_courses_view_switcher' ) ) {
	/**
	 * Output courses view switcher
	 */
	function geeks_courses_view_switcher() {
		global $wp_query;
		$total   = $wp_query->found_posts;

		if ( 0 === $total ) {
			return;
		}

		$layouts = learn_press_courses_layouts();
		$active  = learn_press_get_courses_layout();

		?>
		<div class="switch-layout nav btn-group flex-nowrap btn-group-toggle" data-toggle="buttons">
		<?php

		foreach ( $layouts as $layout => $value ) :
			$atts = [
				'class'          => 'switch-btn btn btn-outline-white ' . $layout,
				/* translators: %s: layout name */
				'title'          => sprintf( esc_html__( 'Switch to %s', 'geeks' ), $layout ),
				'for'            => 'lp-switch-layout-btn-' . $layout,
				'data-bs-toggle' => 'tab',
				'data-bs-target' => '#tab-pane-' . $layout,
				'role'           => 'tab',
				'aria-controls'  => 'tab-pane-' . $layout,
			];

			$is_active = false;

			if ( $layout === $active ) {
				$is_active             = true;
				$atts['class']        .= ' active';
				$atts['aria-selected'] = 'true';
			} else {
				$atts['aria-selected'] = 'false';
			}

			?>
			<label <?php echo geeks_get_render_attribute_string( $atts ); ?>>
				<span class="fe fe-<?php echo esc_attr( $layout ); ?>"></span>
				<input type="radio" class="btn-check" name="lp-switch-layout-btn" value="<?php echo esc_attr( $layout ); ?>" id="lp-switch-layout-btn-<?php echo esc_attr( $layout ); ?>" <?php checked( $layout, $active ); ?>>
			</label>
		
		<?php endforeach; ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_courses_orderby' ) ) {
	/**
	 * Output courses order by options
	 */
	function geeks_courses_orderby() {

		if ( function_exists( 'geeks_extensions_courses_ordering' ) ) {
			geeks_extensions_courses_ordering();
		}
	}
}

if ( ! function_exists( 'geeks_loop_course_thumbnail' ) ) {
	/**
	 * Outputs Course Thumbnail
	 * 
	 * @param string $view pass the view of the courses loop 'grid' or 'list'
	 */
	function geeks_loop_course_thumbnail( $view = 'grid' ) {
		$course = learn_press_get_course();

		if ( ! $course ) {
			return;
		}

		$thumbnail_size = apply_filters( 'geeks_loop_course_thumbnail_size', 'full' );
		$thumbnail_url  = $course->get_image_url( $thumbnail_size );
		
		if ( 'list' === $view ) : ?>
			<a class="course__thumbnail col-12 col-md-12 col-xl-3 col-lg-3 bg-cover img-left-rounded" style="background-image: url(<?php echo esc_attr( $thumbnail_url ); ?>);" href="<?php the_permalink(); ?>">
				<?php echo wp_kses_post( $course->get_image( $thumbnail_size, array( 'class' => 'img-fluid d-lg-none invisible' ) ) ); ?>
			</a>
		<?php else: ?>
			<a class="course__thumbnail card-img-top" href="<?php the_permalink(); ?>">
				<?php echo wp_kses_post( $course->get_image( $thumbnail_size, array( 'class' => 'card-img-top rounded-top-md' ) ) ); ?>
			</a>
		<?php endif;
	}
}

if ( ! function_exists( 'geeks_loop_course_title' ) ) {
	/**
	 * Outputs Course title
	 * 
	 * @param string $view pass the view of the courses loop 'grid' or 'list'
	 */
	function geeks_loop_course_title( $view = 'grid' ) {
		
		$title_class = 'course__title mb-2 text-truncate-line-2';
		$title_tag   = apply_filters( 'geeks_loop_course_title_tag', 'h3' );

		if ( 'list' === $view ) {
			$title_class .= ' h3';
		} else {
			$title_class .= ' h4';
		}
		
		?><<?php echo esc_html( $title_tag );?> class="<?php echo esc_attr( $title_class ); ?>"><a href="<?php the_permalink(); ?>" class="text-inherit"><?php the_title(); ?></a></<?php echo esc_html( $title_tag );?>><?php
	}
}

if ( ! function_exists( 'geeks_loop_course_meta' ) ) {
	/**
	 * Outputs Course meta info
	 * 
	 * @param string $view pass the view of the courses loop 'grid' or 'list'
	 */
	function geeks_loop_course_meta( $view = 'grid' ) {

		$list_items = apply_filters( 'geeks_loop_course_meta_list_items_' . $view, [
			'duration' => 'geeks_loop_course_duration',
			'level'    => 'geeks_loop_course_level'
		] );

		$list_class = 'list-inline mb-3';

		if ( 'list' === $view ) {
			if ( geeks_is_course_review_activated() ) {
				$list_items[ 'rating' ] = 'geeks_loop_course_rating';	
			}
			
			$list_items[ 'enrolled' ] = 'geeks_loop_course_enrolled';
		}

		if ( ! empty( $list_items ) ) : ?>
		<ul class="<?php echo esc_attr( $list_class ); ?>">
			<?php foreach ( $list_items as $list_item ) : ?>
			<li class="list-inline-item"><?php call_user_func( $list_item, $view ); ?></li>
			<?php endforeach; ?>
		</ul>
		<?php

		endif;

		if ( 'grid' === $view ) {
			geeks_loop_course_rating( $view );
		}
	}
}

if ( ! function_exists( 'geeks_loop_course_price' ) ) {
	/**
	 * Outputs Course Price
	 */
	function geeks_loop_course_price( $view = 'grid' ) {
		$course = learn_press_get_course();

		if ( ! $course ) {
			return;
		}

		$price_html = $course->get_price_html();
		$wrap_class = 'lh-1 mt-3';

		if ( 'list' === $view ) {
			$wrap_class .= ' mb-5';
		}

		if ( $price_html ) : ?>
		<div class="<?php echo esc_attr( $wrap_class ); ?>">
			
			<span class="text-dark fw-medium"><?php echo esc_html( $price_html ); ?></span>
			<?php if ( $course->get_origin_price() != $course->get_price() ) : ?>
			<del class="fs-6 text-muted"><?php echo esc_html( $course->get_origin_price_html() ); ?></del>
			<?php endif; ?>
		</div>
		<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_loop_course_duration' ) ) {
	/**
	 * Outputs Course Duration
	 */
	function geeks_loop_course_duration() {
		$duration = geeks_get_course_duration_humanized();
		geeks_display_course_duration( $duration );
	}
}

if ( ! function_exists( 'geeks_loop_course_level' ) ) {
	/**
	 * Outputs Course Level
	 */
	function geeks_loop_course_level() {
		$level = get_post_meta( get_the_ID(), '_lp_level', true );
		$label = lp_course_level()[ $level ];
		geeks_display_course_level( $level, $label );
	}
}

if ( ! function_exists( 'geeks_loop_course_rating' ) ) {
	/**
	 * Outputs Course Rating
	 */
	function geeks_loop_course_rating( $view = 'grid' ) {

		if ( ! geeks_is_course_review_activated() ) {
			return;
		}
		
		$rating_info = geeks_get_course_rating_info();

		if ( $rating_info ) :
			
			if ( 'grid' === $view ) : 
				?><div class="lh-1"><?php
			endif;
			
			if ( $rating_info['rating'] > 0 ) :
				geeks_course_the_review_stars(); ?>
				<span class="text-warning ms-1">
					<?php echo esc_html( number_format_i18n( $rating_info['rating'], 1 ) ); ?>
				</span>
				<span class="fs-6 text-muted">(<?php echo esc_html( $rating_info['count'] ); ?>)</span>
			<?php else: ?>
				<span class="fs-6 text-muted"><?php echo esc_html__( 'Not yet rated', 'geeks' ); ?></span>
			<?php endif;

			if ( 'grid' === $view ) : 
				?></div><?php
			endif;

		endif;
	}
}

if ( ! function_exists( 'geeks_loop_course_enrolled' ) ) {
	/**
	 * Display total students enrolled
	 */
	function geeks_loop_course_enrolled() {
		$students = absint( get_post_meta( get_the_ID(), '_lp_students', true ) );
		if ( $students ) :
			?><i class="mdi mdi-account-multiple-outline"></i><?php echo esc_html( sprintf( esc_html__( '%s Enrolled', 'geeks' ), $students ) );
		endif;
	}
}

if ( ! function_exists( 'geeks_loop_course_footer' ) ) {
	function geeks_loop_course_footer( $view = 'list' ) {
		if ( 'list' !== $view ) {
			return;
		}

		do_action( 'geeks_courses_loop_item_footer' );
	}
}

if ( ! function_exists( 'geeks_loop_course_footer_wrap_start' ) ) {
	/**
	 * Output Course Footer wrap start
	 */
	function geeks_loop_course_footer_wrap_start() {
		?><div class="row align-items-center g-0"><?php
	}
}

if ( ! function_exists( 'geeks_loop_course_instructor' ) ) {
	function geeks_loop_course_instructor() {
		$course = learn_press_get_course();

		if ( ! $course ) {
			return;
		}

		$instructor   = $course->get_instructor_name();
		$profile_pic  = geeks_get_instructor_avatar( $course->get_instructor(), 24, ['rounded-circle', 'avatar-xs'] );
		$profile_link = geeks_instructor_profile_link( $course );

		if ( ! empty( $profile_pic ) ) :
			?><div class="col-auto">
				<a href="<?php echo esc_url( $profile_link ); ?>"><?php echo wp_kses_post( $profile_pic ); ?></a>
			</div><?php
		endif;

		?><div class="col ms-2">
			<a href="<?php echo esc_url( $profile_link ); ?>" class="text-inherit"><?php echo esc_html( $instructor ); ?></a>
		</div><?php
	}
}

if ( ! function_exists( 'geeks_loop_course_bookmark' ) ) {
	/**
	 * Output course bookmark link
	 */
	function geeks_loop_course_bookmark() {
		?><div class="col-auto">
			<a href="#" class="text-muted bookmark">
				<i class="fe fe-bookmark"></i>
			</a>
		</div><?php
	}
}

if ( ! function_exists( 'geeks_loop_course_footer_wrap_end' ) ) {
	/**
	 * Output Course Footer wrap end
	 */
	function geeks_loop_course_footer_wrap_end() {
		?></div><?php
	}
}