<?php
/**
 * Template functions used in Single Course
 */

if ( ! function_exists( 'geeks_single_course_meta_wrap_start' ) ) {
	/**
	 * Output wrapper start for Courses meta
	 */
	function geeks_single_course_meta_wrap_start() {
		?><div class="single-course__meta d-flex align-items-center text-white"><?php
	}
}	

if ( ! function_exists( 'geeks_single_course_duration' ) ) {
	/**
	 * Output single course duration
	 */
	function geeks_single_course_duration() {
		?><div class="meta-item"><?php geeks_loop_course_duration(); ?></div><?php
	}
}

if ( ! function_exists( 'geeks_single_course_rating' ) ) {
	/**
	 * Output single course rating
	 */
	function geeks_single_course_rating() {

		$single_version = geeks_get_single_course_version();

		if ( 'v2' === $single_version ) {
			$text_color = 'text-body';
			$wrap_class = 'me-4';
		} else {
			$text_color = 'text-white';
			$wrap_class = 'ms-4';

		}

		if ( ! geeks_is_course_review_activated() ) {
			return;
		}
		
		$rating_info = geeks_get_course_rating_info();

		?>
		<div class="meta-item <?php echo esc_attr( $wrap_class );?>">
		<?php 
			if ( $rating_info['count'] > 0 ) :
				geeks_course_the_review_stars();

			?><span class="<?php echo esc_attr( $text_color );?>">(<?php echo esc_html( $rating_info['count'] ); ?>)</span><?php
			
			else :
			
			?><span class="<?php echo esc_attr( $text_color );?>"><?php esc_html_e( 'Not yet rated', 'geeks' ); ?></span><?php

			endif;
		?>					
		</div><?php
	}	
}

if ( ! function_exists( 'geeks_single_course_level' ) ) {
	/**
	 * Output single course level
	 */
	function geeks_single_course_level() {
		$single_version = geeks_get_single_course_version();

		if ( 'v2' === $single_version ) {
			$text_classes = 'me-4 text-body';
		} else {
			$text_classes = 'ms-4 text-white';
		}

		?><div class="meta-item d-none d-md-block <?php echo esc_attr( $text_classes );?>"><?php geeks_loop_course_level(); ?></div><?php
	}
}

if ( ! function_exists( 'geeks_single_course_meta_wrap_end' ) ) {
	/**
	 * Output wrapper end for Courses meta
	 */
	function geeks_single_course_meta_wrap_end() {
		?></div><!-- /.single-course__meta --><?php
	}
}

if ( ! function_exists( 'geeks_single_course_price' ) ) {
	/**
	 * Output single course price
	 */
	function geeks_single_course_price() {
		$course = learn_press_get_course();
		$user   = learn_press_get_current_user();
		$price  = $course->get_price_html();

		if ( $user->has_enrolled_course( get_the_ID() ) || ! $price ) {
			return;
		}

		?>
		<div class="single-course__price mb-3">
			<span class="text-dark fw-bold h2"><?php echo esc_html( $price ); ?></span>
			<?php if ( $course->has_sale_price() ) : ?>
			<del class="fs-4 text-muted"><?php echo esc_html( $course->get_origin_price_html() ); ?></del>
			<?php endif; ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_course_section_status_icon' ) ) {
	/**
	 * Output Course Status Icon
	 */
	function geeks_course_section_status_icon( $item, $section, $course ) {
		$user        = LP_Global::user();
		$course      = LP_Global::course();
		$enrolled    = $user->has_enrolled_course( $course->get_id() );

		if ( $item->is_preview() && ! $user->has_completed_item( $item->get_id(), $course->get_id() ) ) {
			?><span class="icon-shape bg-light text-primary icon-sm rounded-circle me-2">
				<i class="mdi mdi-play fs-4"></i>
			</span><?php
		} else {
			if(  ! $user || ! $enrolled ):
				?><span class="icon-shape bg-light text-muted icon-sm rounded-circle me-2">
					<i class="fe fe-lock fs-4"></i>
				</span><?php
			else:
				?><span class="icon-shape bg-light text-muted icon-sm rounded-circle me-2">
					<i class="fe fe-check text-success fs-4"></i>
				</span><?php
			endif;
		}
	}
}

if ( ! function_exists( 'geeks_single_course_instructor' ) ) {
	/**
	 * Output Single Course Instructor Card
	 */
	function geeks_single_course_instructor() {

		$course      = LP_Global::course();
		$instructor  = $course->get_instructor();
		$user_id     = $instructor->get_id();
		$title       = geeks_acf_get_user_byline( $user_id );
		$is_verified = geeks_acf_user_is_verified( $user_id );
		$about_me    = geeks_acf_user_get_about_me( $user_id );
		$stats       = geeks_get_instructor_stats( $user_id );
		$rating      = $stats['rating'];

		unset( $stats['rating'] );

		?><div class="card">
			<!-- Card body -->
			<div class="card-body">
				<div class="d-flex align-items-center">
					<div class="position-relative">
						<?php echo wp_kses( get_avatar( $user_id, 80, '', '', array( 'class' => 'rounded-circle avatar-xl' ) ), array( 'img' => array( 'src' => [], 'alt' => [], 'class' => [] ) ) ); ?>
						<a href="<?php echo esc_url( geeks_instructor_profile_link( $course ) ); ?>" class="position-absolute mt-2 ms-n3" data-bs-toggle="tooltip" data-placement="top" data-bs-original-title="Verifed">
							<img src="<?php echo esc_url( get_template_directory_uri() . '/assets/images/svg/checked-mark.svg' ); ?>" alt="" height="30" width="30">
						</a>
					</div>
					<div class="ms-4">
						<h4 class="mb-0"><?php echo esc_html( $instructor->get_display_name() ); ?></h4>
						<p class="mb-1 fs-6">Front-end Developer, Designer</p>
						<?php if ( $rating['value'] ) : ?>
						<span class="fs-6"><span class="text-warning"><?php echo esc_html( $rating['value'] ); ?></span><span class="mdi mdi-star text-warning me-2"></span><?php echo esc_html( $rating['label'] ); ?></span>
						<?php endif; ?>
					</div>
				</div>
				<div class="border-top row mt-3 border-bottom mb-3 g-0">
					<?php $i = 0; foreach( $stats as $stat ) : ?>
					<div class="col<?php if ( 0 < $i++ ): ?> border-start<?php endif; ?>">
						<div class="pe-1 ps-2 py-3">
							<h5 class="mb-0"><?php echo esc_html( number_format_i18n( $stat['value'] ) ); ?></h5>
							<span><?php echo esc_html( $stat['label'] ); ?></span>
						</div>
					</div>
					<?php endforeach; ?>
				</div>
				<p>I am an Innovation designer focussing on UX/UI based in Berlin. As a creative resident at Figma explored the city of the future and how new technologies.</p>
				<a href="<?php echo esc_url( geeks_instructor_profile_link( $course ) ); ?>" class="btn btn-outline-white btn-sm"><?php echo esc_html__( 'View Profile', 'geeks' ); ?></a>
			</div>
		</div><?php
	}
}

if ( ! function_exists( 'geeks_course_media_preview_wrap' ) ) {
	/**
	 * Output Single Course v2 media preview wrap 
	 */
	function geeks_course_media_preview_wrap() {
		$course      = learn_press_get_course( get_the_ID() );
		$image_size  = apply_filters( 'geeks_media_preview_size', 'full' );

		?>
		<div class="row">
			<div class="col-lg-12 col-md-12 col-12 mb-5">
				<div class="media-preview rounded-3 position-relative w-100 d-block overflow-hidden p-0" style="height: 600px;">
					<?php echo wp_kses_post( $course->get_image( $image_size, array( 'class' => 'card-img' ) ) ); ?>
				</div>
			</div>
		</div><?php

	}
}


if ( ! function_exists( 'geeks_single_course_entry_content_wrap_start' ) ) {
	/**
	 * Display Single Course v2 entry content wrap start
	 */
	function geeks_single_course_entry_content_wrap_start() {
		?>
		<div class="row">
		<?php
	}
}

if ( ! function_exists( 'geeks_single_course_entry_content_wrap_end' ) ) {
	/**
	 * Display Single Course v2 entry content wrap end
	 */
	function geeks_single_course_entry_content_wrap_end() {
		?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_single_course_entry_content_left_column' ) ) {
	/**
	 * Output Single Course v2 entry content left column
	 */
	function geeks_single_course_entry_content_left_column() {
		?>
		<div class="col-xl-8 col-lg-12 col-md-12 col-12 mb-4 mb-xl-0">
			<?php do_action( 'geeks_single_course_v2_left_content');?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_single_course_entry_content_right_column' ) ) {
	/**
	 * Output Single Course v2 entry content right column
	 */
	function geeks_single_course_entry_content_right_column() {
		?>
		<div class="col-xl-4 col-lg-12 col-md-12 col-12">
			<div class="card">
				<?php do_action( 'geeks_single_course_v2_right_content');?>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_single_course_v2_left_content_inner' ) ) {
	/**
	 * Output Single Course v2 entry content left content inner
	 */
	function geeks_single_course_v2_left_content_inner() {
		$tabs           = learn_press_get_course_tabs();
		if ( !empty ( $tabs ) ) {
			$card_classes = 'rounded-0 rounded-top-md';
		} else {
			$card_classes = 'rounded-3';
		}

		?>
		<div class="card <?php echo esc_attr( $card_classes );?>">
			<div class="card-body">
				<div class="d-flex justify-content-between align-items-center">
					<h1 class="fw-semi-bold mb-2"><?php the_title(); ?></h1>
					<?php geeks_single_course_v2_wishlist_button();?>
				</div>

				<div class="d-flex mb-5">
					<?php
					geeks_single_course_rating();
					geeks_single_course_level();
					geeks_single_course_duration();
					?>
				</div>

				<div class="d-flex justify-content-between">
					<div class="d-flex align-items-center">
						<?php 
							$course      = LP_Global::course();
							$instructor  = $course->get_instructor();
							$user_id     = $instructor->get_id();
							echo wp_kses( get_avatar( $user_id, 80, '', '', array( 'class' => 'rounded-circle avatar-md' ) ), array( 'img' => array( 'src' => [], 'alt' => [], 'class' => [] ) ) ); ?>

						<div class="ms-2 lh-1">
							<h4 class="mb-1"><?php echo esc_html( $instructor->get_display_name() ); ?></h4>
							<p class="fs-6 mb-0">@<?php echo get_the_author_meta( 'user_nicename', $user_id );?></p>
						</div>	
					</div>			
				</div>
			</div>
		</div>
		<?php do_action('geeks_single_course_v2_tabs'); 

	}
}

if ( ! function_exists( 'geeks_course_tabs_customize' ) ) {
	/**
	 * Customize single course tab for version v2
	 */
	function geeks_course_tabs_customize( $tabs ) {
	$single_version = geeks_get_single_course_version();

	if ( isset( $tabs['curriculum'] ) && 'v2' === $single_version ) unset( $tabs['curriculum'] );

	return $tabs;
		
	}
}

if ( ! function_exists( 'geeks_single_course_v2_wishlist_button' ) ) {
	function geeks_single_course_v2_wishlist_button( $course_id = null ) {
		if ( ! class_exists( 'LP_Addon_Wishlist' ) ) {
			return;
		}

		LP_Addon_Wishlist::instance()->wishlist_button( $course_id );
	}
}


/**
 * Display related courses
 */
if ( ! function_exists( 'geeks_related_courses' ) ) {
	function geeks_related_courses() {
		$related_courses = geeks_get_related_courses( apply_filters( 'geeks_related_courses_limit', 4 ) );

		if ( $related_courses && ( 'yes' === get_theme_mod( 'enable_geeks_related_courses', 'yes' ) ) ) {
			$section_title = apply_filters( 'geeks_related_course_title', esc_html__( 'Related Courses', 'geeks' ) );
			
			?>
			<div class="related-course pt-12 pb-3">

				<?php if ( ! empty( $section_title ) ) : ?>
				<div class="row d-md-flex align-items-center mb-4">
					<div class="col-12">
						<h2 class="mb-0"><?php echo esc_html( $section_title ); ?></h2>
					</div>
				</div>
				<?php endif; ?>

				<div class="row">
					<?php

					foreach ( $related_courses as $course_item ) :

						$course                     = learn_press_get_course( $course_item->ID );
						$is_required                = $course->is_required_enroll();
						$course_item_excerpt_length = get_theme_mod( 'geeks_learnpress_excerpt_length', 25 );
						$instructor                 = $course->get_instructor();

						$list_items = apply_filters( 'geeks_loop_course_meta_list_items', [
							'duration' => 'geeks_loop_course_duration',
							'level'    => 'geeks_loop_course_level'
						] );

						?>
						<div class="col-lg-3 col-md-6 col-12">
							<div class="card mb-4 card-hover">
								<a href="<?php the_permalink(); ?>" class="card-img-top">
									<?php echo wp_kses_post( $course->get_image( 'full', array( 'class' => 'card-img-top rounded-top-md' ) ) ); ?>								
								</a>

								<div class="card-body">
									<h4 class="mb-2 text-truncate-line-2"><a href="<?php echo esc_url( get_the_permalink( $course_item->ID ) ); ?>" class="text-inherit"><?php echo esc_html( $course_item->post_title ); ?></a></h4>

									<?php if ( ! empty( $list_items ) ) : ?>
										<ul class="list-inline mb-3">
											<?php foreach ( $list_items as $list_item ) : ?>
											<li class="list-inline-item"><?php call_user_func( $list_item ); ?></li>
											<?php endforeach; ?>
										</ul>
									<?php
									endif;

									if ( function_exists( 'learn_press_get_course_rate' ) ) : ?>
										<div class="lh-1">
										<?php

											$course_rate_res = learn_press_get_course_rate( $course_item->ID, false );

											$course_rate = $course_rate_res['rated'];
											$total       = $course_rate_res['total'];
											
											if ( $course_rate > 0 ) :
												learn_press_course_review_template( 'rating-stars.php', array( 'rated' => $course_rate_res['rated'] ) );
											else :
											?>
												<div class="fs-6 text-muted"><?php echo esc_html__( 'Not yet rated', 'geeks' ); ?></div>
											<?php
											endif;
											?>

										</div>
									<?php endif; ?>							
								</div>

								<div class="card-footer">
									<div class="row align-items-center g-0">
										<?php geeks_loop_course_instructor();
										geeks_loop_course_bookmark(); ?>
									</div>
								</div>
							</div>	
							
						</div>
					<?php endforeach; ?>
					
				</div>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'geeks_get_related_courses' ) ) {
	function geeks_get_related_courses( $limit ) {
		if ( ! $limit ) {
			$limit = 3;
		}
		$course_id = get_the_ID();

		$tag_ids = array();
		$tags    = get_the_terms( $course_id, 'course_tag' );

		if ( $tags ) {
			foreach ( $tags as $individual_tag ) {
				$tag_ids[] = $individual_tag->term_id;
			}
		}

		$args = array(
			'posts_per_page'      => $limit,
			'paged'               => 1,
			'ignore_sticky_posts' => 1,
			'post__not_in'        => array( $course_id ),
			'post_type'           => 'lp_course',
		);

		if ( $tag_ids ) {
			$args['tax_query'] = array(
				array(
					'taxonomy' => 'course_tag',
					'field'    => 'term_id',
					'terms'    => $tag_ids,
				),
			);
		}

		$related = array();
		$posts   = new WP_Query( $args );

		if ( $posts ) {
			global $post;
			while ( $posts->have_posts() ) {
				$posts->the_post();
				$related[] = $post;
			}
		}
		wp_reset_postdata();

		return $related;
	}
}
