<?php
/**
 * Template functions related to LMS features of Geeks
 */

/**
 * Get duration of the course in a humanized form
 */
function geeks_get_duration_humanized( $duration ) {
	
	if ( $duration && class_exists( 'Geeks_Duration' ) ) {
		$duration = new Geeks_Duration( $duration );
		return $duration->humanize();
	}

	return $duration;
}

if ( ! function_exists( 'geeks_display_courses_results' ) ) {
	/**
	 * Display Courses results count
	 */
	function geeks_display_courses_results() {
		geeks_posts_results_count( esc_html__( 'Course', 'geeks' ), esc_html__( 'Courses', 'geeks' ) );
	}
}

/**
 * Get courses results count
 *
 * @return null|string
 */
function geeks_get_courses_results_count() {
	return geeks_get_posts_results_count( esc_html__( 'Course', 'geeks' ), esc_html__( 'Courses', 'geeks' ) );
}

if ( ! function_exists( 'geeks_display_course_enrolled' ) ) {
	/**
	 * Displays students enrolled in the course
	 * 
	 * @param int $students
	 */
	function geeks_display_course_enrolled( $students ) {
		?><i class="fe fe-user text-white-50"></i> <?php echo esc_html( sprintf( esc_html__( '%s Enrolled', 'geeks' ), $students ) );
	}
}

if ( ! function_exists( 'geeks_display_course_duration' ) ) {
	/**
	 * Displays the course duration info
	 * 
	 * @param string $duration
	 */
	function geeks_display_course_duration( $duration ) {
		if ( ! empty( $duration ) ) :
		?><i class="far fa-clock me-1"></i><?php echo wp_kses_post( $duration );
		endif;
	}
}

if ( ! function_exists( 'geeks_display_course_level' ) ) {
	/**
	 * Displays the course duration info
	 * 
	 * @param string $duration
	 */
	function geeks_display_course_level( $level = '', $label = '', $current = '#DBD8E9', $next = '#754FFE' ) {
		$level = ( 'all_levels' ===  $level ) ? 'all' : $level;
		$level = empty( $level ) ? 'all' : $level;
		$label = empty( $label ) ? esc_html__( 'All Levels', 'geeks' ) : $label;
		geeks_the_course_level_icon( $level, $current, $next );
		?><span class="align-middle"><?php echo esc_html( ' ' . $label ); ?></span><?php
	}
}

if ( ! function_exists( 'geeks_display_review_stars' ) ) {
	/**
	 * Displays review stars
	 * 
	 * @param float $average_rating
	 */
	function geeks_display_review_stars( $rating ) {
		for ( $i = 0; $i < 5; $i ++ ) {
			$diff = $rating - $i;

			$i_class = 'mdi';

			if ( 1 <= $diff ) {
				$i_class .= ' mdi-star text-warning';
			} elseif ( 0 < $diff && 0.95 > $diff ) {
				$i_class .= ' mdi-star-half-full text-warning';
			} else {
				$i_class .= ' mdi-star text-gray';
			}

			if ( $i == 4 ) {
				$i_class .= ' me-n1-half';
			} else {
				$i_class .= ' me-n1';
			}

			$i_class .= ' ' . $diff;
		
			?>
			<i class="<?php echo esc_attr( $i_class ); ?>"></i>
			<?php
		}
	}
}

if ( ! function_exists( 'geeks_display_course_rating' ) ) {
	/**
	 * Displays course rating
	 */
	function geeks_display_course_rating( $rating_avg, $rating_count, $text_class = 'fs-6 text-muted' ) {
		if ( 0 < floatval( $rating_avg ) ): ?>
			<span>
				<?php geeks_display_review_stars( $rating_avg ); ?>
			</span>
			<span class="text-warning"><?php echo esc_html( number_format_i18n( $rating_avg, 1 ) ); ?></span>
			<?php if ( isset( $rating_count ) ) : ?>
			<span class="<?php echo esc_attr( $text_class ); ?>">(<?php echo esc_html( number_format_i18n( $rating_count ) ); ?>)</span>
			<?php endif; ?>
		<?php else: ?>
			<span class="<?php echo esc_attr( $text_class ); ?>"><?php esc_html_e( 'No ratings yet', 'geeks' ); ?></span>
		<?php endif;
	}
}

if ( ! function_exists( 'geeks_the_course_level_icon' ) ) {
	/**
	 * Outputs the skill level icon
	 * 
	 * @param string $skill   The skill level. Defaults to 'beginner'.
	 * @param string $current Hex color for current fill.
	 * @param string $next    Hex color for next file.
	 */
	function geeks_the_course_level_icon( $skill = 'beginner', $current = '#DBD8E9', $next = '#754FFE' ) {

		$skills = [ 'all' => 0, 'beginner' => 1, 'intermediate' => 2, 'expert' => 3 ];

		$levels = [
			[ 
				'x'      => 3, 
				'y'      => 8, 
				'width'  => 2, 
				'height' => 6, 
				'rx'     => 1,
			],
			[ 
				'x'      => 7, 
				'y'      => 5, 
				'width'  => 2, 
				'height' => 9, 
				'rx'     => 1,
			],
			[ 
				'x'      => 11, 
				'y'      => 2, 
				'width'  => 2, 
				'height' => 12, 
				'rx'     => 1, 
			],
		];

		?><svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg"><?php
			foreach( $levels as $index => $level ) :
				$fill = $skills[ $skill ] > $index ? $next : $current;
			?><rect x="<?php echo esc_attr( $level['x'] ); ?>" 
					y="<?php echo esc_attr( $level['y'] ); ?>" 
					width="<?php echo esc_attr( $level['width'] ); ?>" 
					height="<?php echo esc_attr( $level['height'] ); ?>" 
					rx="<?php echo esc_attr( $level['rx'] ); ?>" 
					fill="<?php echo esc_attr( $fill ); ?>"></rect><?php
			endforeach
		?></svg><?php
	}
}

if ( ! function_exists( 'geeks_profile_form_branding' ) ) {
	/**
	 * Login/Register form logo
	 */
	function geeks_profile_form_branding() {
		$site_icon_url = get_site_icon_url( 600 );
		
		if ( apply_filters( 'geeks_profile_form_branding_use_site_icon', true ) && ! empty( $site_icon_url ) ) {
			?><a href="<?php echo esc_url( home_url( '/' ) ); ?>">
				<img src="<?php echo esc_url( $site_icon_url ); ?>" class="mb-4" alt="<?php esc_attr( get_bloginfo( 'name' ) ); ?>">
			</a><?php
		} else {
			geeks_site_title_or_logo( true, 'd-block mb-4', 'd-block mb-4' );
		}
	}
}

if ( ! function_exists( 'geeks_display_courses_loop_author' ) ) {
	/**
	 * Display author info in loop
	 */
	function geeks_display_courses_loop_author( $user_id = '', $display_name = '' ) {
		if ( ! empty( $user_id ) ) : ?>
		<div class="col-auto">
			<?php echo get_avatar( $user_id, 24, '', $display_name, array( 'class' => 'rounded-circle avatar-xs' ) ); ?>
		</div>
		<?php 
		endif;
		
		if ( ! empty( $display_name ) ) : ?>
		<div class="col ms-2">
			<span><?php echo esc_html( $display_name ); ?></span>
		</div>
		<?php 
		endif;
	}
}

if ( ! function_exists( 'geeks_display_instructors_grid' ) ) {
	/**
	 * Display users in a grid
	 */
	function geeks_display_instructors_grid( $user_id, $stats ) {
		geeks_get_template( 'instructors/grid.php', array( 'user_id' => $user_id, 'stats' => $stats ) );
	}
}

if ( ! function_exists( 'geeks_display_general_section' ) ) {
	/**
	 * Display general section
	 */
	function geeks_display_general_section( $section_title = '', $section_description = '', $section_content = '' ) {
		?>
		<section class="mb-6">
			<?php if ( isset( $section_title ) ) : ?>
			<header class="mb-5">
				<h2 class="mb-1"><?php echo esc_html( $section_title ); ?></h2>
				<?php if ( isset( $section_description ) ) : ?>
				<p class="mb-0"><?php echo esc_html( $section_description ); ?></p>
				<?php endif; ?>
			</header>
			<?php 

			endif;

			if ( isset( $section_content ) ) {
				echo wp_kses_post( $section_content );
			}

			?>
		</section>
		<?php
	}
}