<?php
/**
 * Template functions used in Single Post
 *
 */

if ( ! function_exists( 'geeks_single_post_header' ) ) {
	function geeks_single_post_header() {
		?><div class="single-post__header text-center mb-4">
			<div class="single-post__header--cats mb-4"><?php 
				geeks_loop_post_category( 'mb-0 font-size-sm font-weight-semi-bold text-primary' );
			?></div><?php
				the_title( '<h2 class="h1 display-3 fw-bold mb-4">', '</h2>' ); 
				if ( 'sfwd-courses' !== get_post_type() ): ?>
					<span class="mb-3 d-inline-block"><?php geeks_single_post_reading_time();?></span>
				<?php endif; ?>
		</div><?php
	}
}

if ( ! function_exists( 'geeks_single_post_reading_time' ) ) {
	/**
	 * Display single post reading_time.
	 */
	function geeks_single_post_reading_time() {
		$post_content = get_post_field( 'post_content' );
		$minutes      = geeks_get_read_time( $post_content );
		if ( 1 <= $minutes ) :
			echo esc_html( sprintf( esc_html__( '%s min read', 'geeks' ), $minutes ) ); 
		else :
			echo esc_html__( 'Less than a minute to read', 'geeks' );
		endif;
	}
}

if ( ! function_exists( 'geeks_comment_form_default_fields' ) ) {
	function geeks_comment_form_default_fields( $fields ) {
		$commenter = wp_get_current_commenter();
		$is_req    = (bool) get_option( 'require_name_email', 1 );

		// Remove url field.
		unset( $fields['url'] );

		// Update other fields.
		$fields['author'] = sprintf(
			'<div class="col-12 col-sm-6 form-group comment-form-author mb-3">
				<label for="author" class="form-label p-0">%1$s%4$s</label>
				<input type="text" name="author" id="author" class="form-control" value="%2$s" maxlength="245" %3$s>
			</div>',
			/* translators: comment author name */
			esc_html_x( 'Name', 'front-end', 'geeks' ),
			esc_attr( $commenter['comment_author'] ),
			$is_req ? 'required' : '',
			$is_req ? '<span class="text-danger">*</span>' : ''
		);

		$fields['email'] = sprintf(
			'<div class="col-12 col-sm-6 form-group comment-form-email mb-3">
				<label for="email" class="form-label p-0">%1$s%4$s</label>
				<input type="email" name="email" id="email" class="form-control" value="%2$s" maxlength="100" aria-describedby="email-notes" %3$s>
			</div>',
			/* translators: comment author e-mail */
			esc_html_x( 'Email', 'front-end', 'geeks' ),
			esc_attr( $commenter['comment_author_email'] ),
			$is_req ? 'required' : '',
			$is_req ? '<span class="text-danger">*</span>' : ''
		);

		if ( isset( $fields['cookies'] ) ) {
			$consent           = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';
			$fields['cookies'] = sprintf(
				'<div class="col-12 mb-4"><div class="custom-control custom-checkbox comment-form-cookies-consent d-flex align-items-center">
					<input type="checkbox" id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" class="custom-control-input" value="yes"' . $consent . '>
					<label class="custom-control-label ms-2" for="wp-comment-cookies-consent">%s</label>
				</div></div>',
				esc_html_x( 'Save my name and email in this browser for the next time I comment.', 'front-end', 'geeks' )
			);
		}

		return $fields;
	}
}

if ( ! function_exists( 'geeks_single_post_info_bar_top' ) ) {
	/**
	 * Single Post Info Bar top
	 */
	function geeks_single_post_info_bar_top() {
		if ( geeks_is_gke_activated() ) {
			geeks_single_post_info_bar();
		} else {
			?><div class="mb-5"></div><?php
		}
	}
}

if ( ! function_exists( 'geeks_single_post_info_bar' ) ) {
	/**
	 * Single post info bar
	 */
	function geeks_single_post_info_bar() {
		if ( 'sfwd-courses' == get_post_type() ): 
			return;
		endif;
		?>
		<div class="d-md-flex justify-content-between align-items-center mb-5">
			<div class="d-flex align-items-center position-relative">
				<?php echo get_avatar( get_the_author_meta( 'ID' ), 35, '', 'avatar', array( 'class' => 'rounded-circle avatar-md' ) ); ?>
				<div class="ms-2 lh-1">
					<h5 class="mb-1"><?php echo esc_html( get_the_author() ); ?></h5>
					<span class="text-muted"><?php geeks_the_post_time_string( array( 'link_css' => 'text-reset stretched-link', 'link' => get_author_posts_url( get_the_author_meta( 'ID' ) ) ) ); ?></span>
				</div>

			</div>

			<?php if ( geeks_single_post_is_share_enabled() ) : ?>
			<div class="mt-3 mt-md-0 d-flex align-items-center">
				<span class="ms-2 text-muted"><?php echo esc_html__( 'Share', 'geeks' ); ?></span>
				<?php geeks_single_post_share(); ?>
			</div>
			<?php endif; ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_single_post_tags' ) ) {
	/**
	 * Geeks Single Post Tags
	 */
	function geeks_single_post_tags() {
		if ( apply_filters( 'geeks_single_post_tags_enable', false ) ) {
			the_tags( '<div class="my-5"><span class="btn btn-light btn-xs me-2">', '</span><span class="btn btn-light btn-xs me-2">', '</span></div>' );
		}
	}
}

if ( ! function_exists( 'geeks_single_post_share' ) ) {
	/**
	 * Geeks Single Post Share
	 *
	 * @param string $context Context for the blog post share.
	 * @param array  $args Additional arguments beyond the context.
	 */
	function geeks_single_post_share() {

		?>
		<ul class="list-unstyled d-flex align-items-center mb-0">
			<?php
			$services = Geeks_SocialMedia::get_share_services();
			foreach ( $services as $key => $service ) :
				if ( ! isset( $service['share'] ) ) {
					continue;
				}

			?>
			<li class="ms-2">
				<a href="<?php echo esc_url( $service['share'] ); ?>" class="ms-1 text-muted" target="_blank" rel="noopener noreferrer">
					 <?php if ( isset( $service['icon'] ) ) : ?>
						<i class="<?php echo esc_attr(  $service['icon'] ); ?>"></i>
					<?php endif; 
					
					if ( isset( $service['name'] ) ) : ?>
						<span class="sr-only"><?php echo esc_html( sprintf( esc_html__( 'Share : ', 'geeks' ), $service['name'] ) ); ?></span>
					<?php endif; ?>
				</a>
			</li>
				<?php
			endforeach;

			?>
		</ul>
		<?php
	}
}


// Single post featured image.
if ( ! function_exists( 'geeks_single_post_featured_image' ) ) {
	/**
	 * Display single post featured image.
	 */
	function geeks_single_post_featured_image() {
		if ( has_post_thumbnail() ) :

			if ( empty( $attr ) ) {
				$attr = array( 'class' => 'img-fluid rounded-3 d-block mx-auto' );
			}

			if ( geeks_is_gke_activated() ) {
				$attr['class'] .= ' w-100';
			}

			?>
			<div class="col-xl-10 col-lg-10 col-md-12 col-12 mb-6">
				<?php the_post_thumbnail( 'full',  $attr ); ?>
			</div>
		<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_single_post_content' ) ) {
	/**
	 * Display single post content.
	 */
	function geeks_single_post_content() {
		$is_rounded = geeks_is_img_rounded_enabled();
		$wrap_class = 'article__content';
		if ( $is_rounded ) {
			$wrap_class .= ' img-rounded-enabled';
		}
		?>
		<div class="<?php echo esc_attr( $wrap_class ); ?>">
			<div class="article__content--inner">
				<?php the_content(); ?>
			</div>
			<?php
				$link_pages = wp_link_pages(
					array(
						'before'      => '<div class="page-links"><span class="d-block text-dark mb-3">' . esc_html__( 'Pages:', 'geeks' ) . '</span><nav class="pagination mb-0">',
						'after'       => '</nav></div>',
						'link_before' => '<span class="page-link">',
						'link_after'  => '</span>',
						'echo'        => 0,
					)
				);
				$link_pages = str_replace( 'post-page-numbers', 'post-page-numbers page-item', $link_pages );
				$link_pages = str_replace( 'current', 'current active', $link_pages );
				echo wp_kses_post( $link_pages );
			?>
		</div>
		<?php
	}
}

// Single post content divider.
if ( ! function_exists( 'geeks_single_post_content_divider' ) ) {
	/**
	 *  Display post content divider.
	 */
	function geeks_single_post_content_divider() {
		?>
		<hr class="mt-8 mb-5">
		<?php
	}
}

if ( ! function_exists( 'geeks_display_comments' ) ) :
	/**
	 * Display comments
	 *
	 * @since  1.0.0
	 */
	function geeks_display_comments() {
		// If comments are open or we have at least one comment, load up the comment template.
		if ( comments_open() || 0 !== intval( get_comments_number() ) ) :
			comments_template();
		endif;
	}

endif;


if ( ! function_exists( 'geeks_comment' ) ) {
	/**
	 * Comment Template.
	 *
	 * @param WP_Comment $comment The comment object.
	 * @param array      $args Array of arguments.
	 * @param int        $depth Depth of the comment.
	 */
	function geeks_comment( $comment, $args, $depth ) {
		if ( 'div' === $args['style'] ) {
			$tag       = 'div';
			$add_below = 'comment-reply-target';
		} else {
			$tag       = 'li';
			$add_below = 'div-comment';
		}

		static $count = 1;

		$comment_class = [];

		if ( empty( $args['has_children'] ) ) {
			$comment_class[] = 'parent';
		}

		if ( 1 === $depth ) {
			$comment_class[] = 'card-body';
		}

		if ( 1 !== $count && 1 === $depth ) {
			$comment_class[] = 'border-top';
		}

		if ( $depth > 1 ) {
			$comment_class[] = 'pt-3 mt-4 ps-3 ps-md-6';
		}

		$comment_class = implode( ' ', $comment_class );

		?>

		<<?php echo esc_attr( $tag ); ?> <?php comment_class( $comment_class ); ?> id="comment-<?php comment_ID(); ?>">

			<div class="d-md-flex">
				<?php
					echo get_avatar( $comment, 50, '', esc_html__( 'author', 'geeks' ), [ 'class' => 'avatar-lg rounded-circle me-md-3' ] )
				?>
				<div class="flex-body mt-3 mt-md-0 w-100">
					<div class="mb-3 lh-1">
						<h5 class="mb-1"><?php echo get_comment_author_link(); ?></h5>
						<!-- <small>December 31, 2020 12:47 PM</small> -->
						<small class="text-muted"><?php echo esc_html( get_comment_date() ); ?></small>
					</div>
					<?php
						comment_text();

						comment_reply_link(
							array_merge(
								$args,
								array(
									'add_below' => $add_below,
									'depth'     => $depth,
									'max_depth' => $args['max_depth'],
									'before'    => '<span class="comment-reply">',
									'after'     => '</span>',
								)
							)
						);

						edit_comment_link( esc_html__( 'Edit', 'geeks' ), '<span class="separator px-1 d-inline-block fw-medium text-muted">|</span>', '' );
					?>
				</div>
			</div>
		<div id="comment-reply-target-<?php comment_ID(); ?>" class="comment-reply-target"></div>


		<?php if ( 'div' !== $args['style'] ) : ?>
		</div>
			<?php
		endif;

		$count++;
	}
}

if ( ! function_exists( 'geeks_add_comment_link_class' ) ) {
	/**
	 * Returns the comment link class.
	 *
	 * @param string $link Link to the comment.
	 * @return string
	 */
	function geeks_add_comment_link_class( $link ) {
		global $comment;

		$link = sprintf(
			'<a href="%s" rel="external nofollow" class="url text-inherit">%s</a>',
			get_comment_author_url( $comment ),
			wp_strip_all_tags( $link )
		);

		return $link;
	}
}

// Single post related articles.
if ( ! function_exists( 'geeks_single_related_post' ) ) {
	/**
	 * Related posts - single post.
	 */
	function geeks_single_related_post() {
		if ( apply_filters( 'geeks_enable_related_posts', filter_var( get_theme_mod( 'blog_related_posts', false ), FILTER_VALIDATE_BOOLEAN ) ) ) {
			global $post;

			if ( empty( $post_id ) ) {
				$post_id = get_the_ID();
			}

			$tags = wp_get_post_terms( $post_id, 'post_tag', [ 'fields' => 'ids' ] );

			if ( empty( $tags ) ) {
				return;
			}

			$related_post = new WP_Query(
				array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => 1,
					'orderby'             => 'date',
					'order'               => 'desc',
					'posts_per_page'      => 3,
					'post__not_in'        => array( get_the_ID() ),
					'tax_query' => array(
						array(
							'taxonomy' => 'post_tag',
							'terms'    => $tags
						),
					),
				)
			);

			if ( $related_post->have_posts() ) :
				?>
				<div class="container">
					<div class="row">
						<div class="col-xl-12 col-lg-12 col-md-12 col-12">
							<div class="my-5">
								<h2>
									<?php echo esc_html( apply_filters( 'geeks_related_posts_title', esc_html__( 'Related Posts', 'geeks' ) ) ); ?>
								</h2>
							</div>
						</div>

						<?php while ( $related_post->have_posts() ) :
							$related_post->the_post();
							?>
							<article id="post-<?php the_ID(); ?>" <?php post_class( array( 'col-xl-4', 'col-lg-4', 'col-md-6', 'col-12' ) ); ?>>
								<?php get_template_part( 'content', get_post_format() ); ?>
							</article>
							<?php
							endwhile;
							wp_reset_postdata();
						?>
					</div>
				</div>
				<?php
			endif;
		}
	}
}

if ( ! function_exists( 'geeks_post_protected_password_form' ) ) :
	/**
	 * Display Post password protected form.
	 */
	function geeks_post_protected_password_form() {
		global $post;

		$label = 'pwbox-' . ( empty( $post->ID ) ? wp_rand() : $post->ID );
		?>

		<form class="protected-post-form input-group geeks-protected-post-form flex-column" action="<?php echo esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ); ?>" method="post">
			<p><?php echo esc_html__( 'This content is password protected. To view it please enter your password below:', 'geeks' ); ?></p>
			<div class="d-flex align-items-center w-md-85">
				<label class="mb-0 me-3 d-none d-md-block" for="<?php echo esc_attr( $label ); ?>"><?php echo esc_html__( 'Password:', 'geeks' ); ?></label>
				<div class="d-flex flex-grow-1">
					<input class="input-text form-control form-control-sm" name="post_password" id="<?php echo esc_attr( $label ); ?>" type="password" style="border-top-right-radius: 0; border-bottom-right-radius: 0;"/>
					<input type="submit" name="submit" class="btn btn-primary btn-sm" value="<?php echo esc_attr( 'Submit' ); ?>" style="border-top-left-radius: 0; border-bottom-left-radius: 0; transform: none;"/>
				</div>
			</div>
		</form>
		<?php
	}
endif;

if ( ! function_exists( 'geeks_single_post_newsletter' ) ) {
	/**
	 * Display Single Post Newsletter
	 */
	function geeks_single_post_newsletter() {
		if( apply_filters( 'geeks_single_post_newsletter', filter_var( get_theme_mod( 'enable_newsletter_subscription', false ), FILTER_VALIDATE_BOOLEAN )  ) ) {

			$title = apply_filters( 'geeks_newsletter_form_title', get_theme_mod( 'newsletter_form_title', esc_html__( 'Sign up for our Newsletter', 'geeks' ) ) );
			$lead  = apply_filters( 'geeks_newsletter_form_desc', get_theme_mod( 'newsletter_form_desc', esc_html__( 'Join our newsletter and get resources, curated content, and design inspiration delivered straight to your inbox.', 'geeks' ) ) );
			$form  = '<form class="row px-md-20"><div class="mb-3 col ps-0 ms-2 ms-md-0"><input type="email" class="form-control" placeholder="Email Address" required=""></div><div class="mb-3 col-auto ps-0"><button class="btn btn-primary" type="submit">Submit</button></div></form>';
			$form = apply_filters( 'geeks_newsletter_form', get_theme_mod( 'geeks_newsletter_subscription_form', $form ) );
			?>
			<div class="py-12">
				<?php if ( isset( $title ) && ! empty( $title ) ) : ?>
				<div class="text-center mb-6">
					<h2 class="display-4 fw-bold"><?php echo esc_html( $title ); ?></h2>
					<?php if ( isset( $lead ) && ! empty( $lead ) ) : ?>
					<p class="mb-0 lead"><?php echo esc_html( $lead ); ?></p>
					<?php endif; ?>
				</div>
				<?php endif; ?>
				<?php
	            if ( ! empty( $form ) ) {
	                echo do_shortcode( $form );
	            } 
	            ?>  
	        </div>
        	<?php
        }
	}
}
