<?php
/**
 * Functions used related to Instructor
 */

/**
 * Get instructor stats for list view
 *
 * @param  int   $instructor_id ID of the instructor.
 * @return array                stats for the instructor in an array.
 */
function geeks_tutor_get_list_view_instructor_stats( $instructor_id ) {
	$courses_count  = absint( tutor_utils()->get_course_count_by_instructor( $instructor_id ) );
	$students_count = absint( tutor_utils()->get_total_students_by_instructor( $instructor_id ) );
	$courses_label  = _nx( 'Course', 'Courses', $courses_count, 'number of courses', 'geeks' );
	$students_label = _nx( 'Student', 'Students', $students_count, 'number of students', 'geeks' );

	$stats = [];

	if ( 0 < $courses_count ) {
		$stats[] = [
			'label' => $courses_label,
			'value' => geeks_format_courses_count( $courses_count ),
		];
	}

	if ( 0 < $students_count ) {
		$stats[] = [
			'label' => $students_label,
			'value' => geeks_format_students_count( $students_count ),
		];
	}
	
	return $stats;
}

/**
 * Get instructor bio
 *
 * @param int $user_id Instructor user ID.
 * @return string
 */
function geeks_tutor_get_instructor_bio( $user_id ) {
	return get_user_meta( $user_id, '_tutor_profile_bio', true );
}

/**
 * Get instructor byline
 *
 * @param int $user_id Instructor user ID.
 * @return string
 */
function geeks_tutor_get_instructor_byline( $user_id ) {
	return get_user_meta( $user_id, '_tutor_profile_job_title', true );
}