<?php
/**
 * Geeks WooCommerce Class
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Geeks_WooCommerce' ) ) :

	/**
	 * The Geeks WooCommerce Integration class
	 */
	class Geeks_WooCommerce {

		/**
		 * Setup class.
		 *
		 */

		public function __construct() {
            $this->includes();
            $this->init_hooks();
        }

        public function includes() {
            require_once get_template_directory() . '/inc/woocommerce/classes/class-geeks-product-cat-list-walker.php';
        }

		public function init_hooks() {
			add_action( 'after_setup_theme', [ $this, 'woocommerce_support' ] );
			add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );
			add_filter( 'woocommerce_form_field_args', [ $this, 'form_field_args' ] );
			add_filter( 'woocommerce_default_address_fields', [ $this, 'address_fields' ] );
			add_action( 'wp_enqueue_scripts', array( $this, 'woocommerce_integrations_scripts' ), 99 );
			add_action( 'widgets_init', array( $this, 'widgets_init' ), 10 );
			add_filter( 'geeks_disable_page_header', [ $this, 'page_header' ], 10 );
			add_filter( 'geeks_navbar_disabled', [ $this, 'page_navbar' ], 10 );
			add_filter( 'geeks_footer_disabled', [ $this, 'page_footer' ], 10 );
			add_filter( 'body_class', [ $this, 'body_classes' ] );
			add_filter( 'geeks_setup_prose', [ $this, 'disable_prose' ], 10 );
			add_filter( 'geeks_page_header_version', [ $this, 'header_version' ], 10 );
		}

		/**
		 * Header version for all WooCommerce pages.
		 */
		public function header_version( $version ) {
			if ( is_woocommerce() || is_cart() || is_checkout() ) {
				$version = 'v1';
			}
			return $version;
		}
		/**
		 * Disable prose for all WooCommerce pages.
		 */
		public function disable_prose( $is_prose_enabled ) {
			if ( is_cart() || is_checkout() || is_account_page() ) {
				$is_prose_enabled = false;
			}
			return $is_prose_enabled;
		}

		/**
		 * Set address fields
		 */
		public function address_fields( $fields ) {
			$fields['city']['class'][] = 'col-md-4';
			$fields['state']['class'][] = 'col-md-4';
			$fields['postcode']['class'][] = 'col-md-4';
			return $fields;
		}

		/**
		 * Set Form field arguments
		 */
		public function form_field_args( $args ) {   
			$args['label_class'][] = 'form-label';
			$args['input_class'][] = 'form-control';
			$args['class'][]       = 'col-12';

			if ( in_array( 'form-row-first', $args['class'], true ) ) {
				$args['class'][] = 'col-md-6';
			}

			if ( in_array( 'form-row-last', $args['class'], true ) ) {
				$args['class'][] = 'col-md-6';
			}

			return $args;
		}

		/**
		 * Define WooCommerce Support
		 */
		public function woocommerce_support() {
			add_theme_support( 'woocommerce', array(
				'product_grid'          => array(
					'default_rows'    => 3,
					'min_rows'        => 2,
					'max_rows'        => 8,
					'default_columns' => 3,
					'min_columns'     => 2,
					'max_columns'     => 5,
				),
			) );


			//add_theme_support( 'wc-product-gallery-slider' );

		}

		/**
         * Query WooCommerce Extension Activation.
         *
         * @param string $extension Extension class name.
         * @return boolean
         */
        public function is_woocommerce_extension_activated( $extension = 'WC_Bookings' ) {
            return class_exists( $extension ) ? true : false;
        }

		/**
         * Integration Styles & Scripts
         *
         * @return void
         */
        public function woocommerce_integrations_scripts() {
            /**
             * YITH WooCommerce Wishlist
             */
            if ( $this->is_woocommerce_extension_activated( 'YITH_WCWL_Frontend' ) ) {
                global $yith_wcwl;

                wp_dequeue_style( 'yith-wcwl-main' );
                //wp_dequeue_style( 'yith-wcwl-font-awesome' );
                add_action( 'geeks_products_loop_item_footer', 'geeks_add_to_wishlist_button', 30 );
                add_action( 'woocommerce_after_shop_loop_item', 'geeks_add_to_wishlist_button',  150 );
                remove_action( 'woocommerce_product_thumbnails', array( YITH_WCWL_Frontend(), 'print_button' ), 21 );
                remove_action( 'woocommerce_single_product_summary', array( YITH_WCWL_Frontend(), 'print_button' ), 31 );
                remove_action( 'woocommerce_after_single_product_summary', array( YITH_WCWL_Frontend(), 'print_button' ), 11 );

                add_action( 'geeks_wc_product_summary', array( YITH_WCWL_Frontend(), 'print_button' ), 30 );
                add_filter( 'yith_wcwl_wishlist_params', 'coach_yith_wcwl_update_fa_classes' );


                /**
				 * Update Fontawesome classes.
				 *
				 * @param array $params Paramaters for Wishlist.
				 * @return array
				 */
				function coach_yith_wcwl_update_fa_classes( $params ) {
					if ( isset( $params['share_atts'] ) ) {
						foreach ( $params['share_atts'] as $key => $value ) {
							if ( 'share_email_icon' === $key ) {
								$params['share_atts'][ $key ] = str_replace( 'fa ', 'far fa-envelope ', $value );
							} else {
								$params['share_atts'][ $key ] = str_replace( 'fa ', 'fab ', $value );
							}
						}
					}
					return $params;
				}


            }
        }

        public function get_wc_shop_sidebar_args() {
            $sidebar_args['shop_sidebar'] = array(
                'name'        => esc_html__( 'Shop Sidebar', 'geeks' ),
                'id'          => 'sidebar-shop',
                'description' => '',
            );

            return apply_filters( 'geeks_wc_shop_sidebar_args', $sidebar_args );
        }

        public function get_wc_shop_product_filter_args() {
            $sidebar_args['product_filters'] = array(
                'name'        => esc_html__( 'Product Filters', 'geeks' ),
                'id'          => 'product-filters-widgets',
                'description' => '',
            );

            return apply_filters( 'get_wc_shop_product_filter_args', $sidebar_args );
        }

        public function widgets_init() {

            $sidebar_args        = $this->get_wc_shop_sidebar_args();
            $product_filter_args = $this->get_wc_shop_product_filter_args();

            foreach ( $sidebar_args as $sidebar => $args ) {
                $widget_tags = array(
                    'before_widget' => '<div id="%1$s" class="widget card mb-4 p-4 %2$s">',
                    'after_widget'  => '</div>',
                    'before_title'  => '<h4 class="widget-title mb-3">',
                    'after_title'   => '</h4>',
                );

                $filter_hook = sprintf( 'geeks_%s_widget_tags', $sidebar );
                $widget_tags = apply_filters( $filter_hook, $widget_tags );

                if ( is_array( $widget_tags ) ) {
                    register_sidebar( $args + $widget_tags );
                }
            }

            foreach ( $product_filter_args as $sidebar => $args ) {
           
                $widget_tags = array(
                    'before_widget' => '<div id="%1$s" class="widget %2$s card-body border-top">',
                    'after_widget'  => '</div>',
                    'before_title'  => '<h4 class="widget-title dropdown-header px-0 mb-2 lh-2">',
                    'after_title'   => '</h4>',
                );

                $filter_hook = sprintf( 'geeks_%s_widget_tags', $sidebar );
                $widget_tags = apply_filters( $filter_hook, $widget_tags );

                if ( is_array( $widget_tags ) ) {
                    register_sidebar( $args + $widget_tags );

                }

            }

        }

        /**
		 * Disable page header on certain conditions
		 */
		public function page_header( $disabled ) {

			// Disable on account pages and order received page.
			if ( is_account_page() || is_wc_endpoint_url( 'order-received' ) ) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Disable page navbar
		 */
		public function page_navbar( $disabled ) {

			// Disable if login or register form is displayed and order received page.
			if ( ( is_account_page() && !is_user_logged_in() ) || is_wc_endpoint_url( 'order-received' ) ) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Disable page footer
		 */
		public function page_footer( $disabled ) {
			
			// Disable if login or register form is displayed and order received page.
			if ( ( is_account_page() && !is_user_logged_in() ) || is_wc_endpoint_url( 'order-received' ) ) {
				$disabled = true;
			}

			return $disabled;
		}

		/**
		 * Adds custom classes to the array of body classes.
		 *
		 * @param array $classes Classes for the body element.
		 * @return array
		 */
		public function body_classes( $classes ) {

			if ( is_cart() || is_checkout() || is_account_page() ) {
				if ( ( $key = array_search('bg-white', $classes) ) !== false ) {
	    			unset( $classes[$key] );
				}
			}

			return $classes;


		}

	}

endif;

return new Geeks_WooCommerce();