<?php
/**
 * Integrate plugin "Tutor" into the theme. 
 */

if ( geeks_is_tutor_activated() && apply_filters( 'geeks_enable_tutor_dashboard_menu_items', true ) ) {

    function geeks_tutor_dashboard_nav_items( $items ) { 
        $logout = $items['customer-logout'];
        unset( $items['customer-logout'] );

        $dashboard_nav_items = array(
            'separator-1'       => array( 'title' => esc_html__( 'Dashboard', 'geeks'), 'type' => 'separator' ),
            'index'             => esc_html__( 'Dashboard', 'geeks' ),
            'my-profile'        => esc_html__( 'My Profile', 'geeks' ),
            'enrolled-courses'  => esc_html__( 'Enrolled Courses', 'geeks' ),
            'wishlist'          => esc_html__( 'Wishlist', 'geeks' ),
            'reviews'           => esc_html__( 'Reviews', 'geeks' ),
            'my-quiz-attempts'  => esc_html__( 'My Quiz Attempts', 'geeks' ),
            'purchase_history'  => esc_html__( 'Purchase History', 'geeks' ),

        );

        $instructor_nav_items = [];

        if (current_user_can(tutor()->instructor_role)){

            $instructor_nav_items = array(
                'separator-2'       => array( 'title' => esc_html__( 'Instructor', 'geeks'), 'type' => 'separator' ),
                'my-courses'        =>  esc_html__( 'My Courses', 'geeks'),
                'announcements'     =>  esc_html__( 'Announcements', 'geeks'), 
                'withdraw'          =>  esc_html__( 'Withdrawals', 'geeks'),
                'quiz-attempts'     =>  esc_html__( 'Quiz Attempts', 'geeks'),
                'question-answer'   =>  esc_html__( 'Question & Answer', 'geeks'),
            );
        }

        $disable = ! get_tutor_option( 'enable_course_review' );
        if ( $disable && isset( $dashboard_nav_items['reviews'] ) ) {
            unset( $dashboard_nav_items['reviews'] );
        }

        $my_items = array_merge( $dashboard_nav_items, $instructor_nav_items );

        $setting_nav_items = array(
            'separator-3'                => array( 'title' => 'Account Settings', 'type' => 'separator' ),
            'settings'                   => esc_html__( 'Edit Profile', 'geeks' ),
            'settings/reset-password'    => esc_html__( 'Security', 'geeks' ),
            'settings/withdraw-settings' => esc_html__( 'Withdraw', 'geeks' ),
            'customer-logout'            => esc_html__( 'Log Out', 'geeks' ),


        );
        $all_my_items = array_merge( $my_items, $setting_nav_items );

        $all_my_items = $my_items + array_slice( $items, 0, 1, true )  +
            array_slice( $items, 1, count( $items ), true ) + $all_my_items;

        return $all_my_items;

    }


    function geeks_tutor_dashboard_nav_icons( $default_icons ) { 
        $my_icons = array (
            'index'            => 'fe fe-home',
            'my-profile'       => 'fe fe-shopping-bag',
            'enrolled-courses' => 'fe fe-book',
            'my-courses'       => 'fe fe-book',
            'wishlist'         => 'fe fe-bookmark',
            'reviews'          => 'fe fe-star',
            'my-quiz-attempts' => 'fe fe-box',
            'quiz-attempts'    => 'fe fe-box',
            'purchase_history' => 'fe fe-shopping-bag',
            'create-course'    => 'fe fe-plus',
            'announcements'    => 'fe fe-bell',
            'withdraw'         => 'fe fe-dollar-sign',
            'question-answer'  => 'fe fe-help-circle',
            'settings'         => 'fe fe-settings',
            'calendar'         => 'fe fe-calendar',
            'settings/reset-password'  => 'fe fe-user',
            'settings/withdraw-settings'  => 'fe fe-dollar-sign',

        ); 

        $my_icons = array_slice( $default_icons, 0, 1, true ) +
        $my_icons +
        array_slice( $default_icons, 1, count( $default_icons ), true );

        return $my_icons;

    }
    function geeks_custom_tutor_endpoints() {
        add_rewrite_endpoint( 'index', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'my-profile', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'enrolled-courses', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'wishlist', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'reviews', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'my-quiz-attempts', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'purchase_history', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'my-courses', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'announcements', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'withdraw', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'quiz-attempts', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'question-answer', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'settings', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'settings/reset-password', EP_ROOT | EP_PAGES );
        add_rewrite_endpoint( 'settings/withdraw-settings', EP_ROOT | EP_PAGES );

    }


    function geeks_tutor_index_endpoint_content() {
        tutor_load_template( 'dashboard.dashboard' );
    }

    function geeks_tutor_my_profile_endpoint_content() {
        tutor_load_template( 'dashboard.my-profile' );
    }

    function geeks_tutor_enrolled_courses_endpoint_content() {
        tutor_load_template( 'dashboard.enrolled-courses' );
    }

    function geeks_tutor_wishlist_endpoint_content() {
        tutor_load_template( 'dashboard.wishlist' );
    }

    function geeks_tutor_reviews_endpoint_content() {
        tutor_load_template( 'dashboard.reviews' );
    }

    function geeks_tutor_my_quiz_attempts_endpoint_content() {
        tutor_load_template( 'dashboard.my-quiz-attempts' );
    }

    function geeks_tutor_purchase_history_endpoint_content() {
        tutor_load_template( 'dashboard.purchase_history' );
    }

    function geeks_tutor_create_course_endpoint_content() {
        tutor_load_template( 'dashboard.create-course' );
    }

    function geeks_tutor_my_courses_endpoint_content() {
        tutor_load_template( 'dashboard.my-courses' );
    }

    function geeks_tutor_announcements_endpoint_content() {
        tutor_load_template( 'dashboard.announcements' );
    }

   
    function geeks_tutor_withdraw_endpoint_content() {
        tutor_load_template( 'dashboard.withdraw' );
    }

    function geeks_tutor_quiz_attempts_endpoint_content() {
        tutor_load_template( 'dashboard.quiz-attempts' );
    }

    function geeks_tutor_question_answer_endpoint_content() {
        tutor_load_template( 'dashboard.question-answer' );
    }

    function geeks_tutor_settings_endpoint_content() {
        tutor_load_template( 'dashboard.settings' );
    }

    function geeks_tutor_settings_reset_password_endpoint_content() {
        tutor_load_template( 'dashboard.settings.reset-password' );
    }

    function geeks_tutor_settings_withdraw_settings_endpoint_content() {
        tutor_load_template( 'dashboard.settings.withdraw-settings' );
    }

    function my_custom_query_vars( $vars ) {
        $vars[] = 'index';
        $vars[] = 'my-profile';
        $vars[] = 'enrolled-courses';
        $vars[] = 'wishlist';
        $vars[] = 'reviews';
        $vars[] = 'my-quiz-attempts';
        $vars[] = 'purchase_history';
        $vars[] = 'create-course';
        $vars[] = 'my-courses';
        $vars[] = 'announcements';
        $vars[] = 'withdraw';
        $vars[] = 'quiz-attempts';
        $vars[] = 'question-answer';
        $vars[] = 'settings';
        $vars[] = 'settings/reset-password';
        $vars[] = 'settings/withdraw-settings';

        return $vars;
    }

    add_filter( 'query_vars', 'my_custom_query_vars', 0 );

    function my_custom_flush_rewrite_rules() {
        flush_rewrite_rules();
    }

    add_action( 'wp_loaded', 'my_custom_flush_rewrite_rules' );

    add_filter( 'woocommerce_account_menu_items',                         'geeks_tutor_dashboard_nav_items', 99, 1 );
    add_filter( 'geeks_wc_account_endpoint_icons',                        'geeks_tutor_dashboard_nav_icons' );
    add_action( 'init',                                                   'geeks_custom_tutor_endpoints' );

    add_action( 'woocommerce_account_index_endpoint',                      'geeks_tutor_index_endpoint_content' );
    add_action( 'woocommerce_account_my-profile_endpoint',                 'geeks_tutor_my_profile_endpoint_content' );
    add_action( 'woocommerce_account_enrolled-courses_endpoint',           'geeks_tutor_enrolled_courses_endpoint_content' );
    add_action( 'woocommerce_account_wishlist_endpoint',                   'geeks_tutor_wishlist_endpoint_content' );
    add_action( 'woocommerce_account_reviews_endpoint',                    'geeks_tutor_reviews_endpoint_content' );
    add_action( 'woocommerce_account_my-quiz-attempts_endpoint',           'geeks_tutor_my_quiz_attempts_endpoint_content' );
    add_action( 'woocommerce_account_purchase_history_endpoint',           'geeks_tutor_purchase_history_endpoint_content' );
    add_action( 'woocommerce_account_create-course_endpoint',              'geeks_tutor_create_course_endpoint_content' );
    add_action( 'woocommerce_account_my-courses_endpoint',                 'geeks_tutor_my_courses_endpoint_content' );
    add_action( 'woocommerce_account_announcements_endpoint',              'geeks_tutor_announcements_endpoint_content' );
    add_action( 'woocommerce_account_withdraw_endpoint',                   'geeks_tutor_withdraw_endpoint_content' );
    add_action( 'woocommerce_account_quiz-attempts_endpoint',              'geeks_tutor_quiz_attempts_endpoint_content' );
    add_action( 'woocommerce_account_question-answer_endpoint',            'geeks_tutor_question_answer_endpoint_content' );
    add_action( 'woocommerce_account_settings_endpoint',                   'geeks_tutor_settings_endpoint_content' );
    add_action( 'woocommerce_account_settings/reset-password_endpoint',    'geeks_tutor_settings_reset_password_endpoint_content' );
    add_action( 'woocommerce_account_settings/withdraw-settings_endpoint', 'geeks_tutor_settings_withdraw_settings_endpoint_content' );

}