<?php 
if ( ! function_exists( 'geeks_wc_my_account_endpoint_dropdown' ) ) {
    function geeks_wc_my_account_endpoint_dropdown() {
        $endpoints = wc_get_account_menu_items();
        if( array_filter( $endpoints ) ) {
            $default_icons = [
            'dashboard'       => 'fe fe-home',
            'orders'          => 'fe fe-shopping-bag',
            'downloads'       => 'fe fe-download',
            'edit-address'    => 'fe fe-map-pin',
            'edit-account'    => 'fe fe-user',
            'payment-methods' => 'fe fe-credit-card',
            'customer-logout' => 'fe fe-power',
            ];
            ?><ul class="list-unstyled">
                <?php foreach( $endpoints as $endpoint => $label ) :
                    $default_icon = isset( $default_icons[$endpoint] ) ? $default_icons[$endpoint] : '';
                    ?>
                    <?php if ( $endpoint === 'customer-logout' ) : ?>
                        <li class="dropdown-divider"></li>
                    <?php endif; ?>
                    <li class="<?php echo wc_get_account_menu_item_classes( $endpoint ); ?>">
                        <a class="dropdown-item" href="<?php echo esc_url( wc_get_account_endpoint_url( $endpoint ) ); ?>">
                            <?php if( ! empty( $default_icon ) ) : ?>
                                <i class="<?php echo esc_attr( $default_icon ); ?> nav-icon me-2"></i>
                            <?php endif; ?>
                            <?php echo esc_html( $label ); ?>
                        </a>
                    </li>
                <?php endforeach; ?>
            </ul><?php
        }
    }
}

if ( ! function_exists( 'geeks_navbar_wc_account_modal' ) ) {
    function geeks_navbar_wc_account_modal() {
        if ( ! is_user_logged_in()  &&  ( ! apply_filters( 'geeks_navbar_disabled', false ) ) && ! geeks_is_tutor_activated() ) {
            $has_registration_form = get_option( 'woocommerce_enable_myaccount_registration' ) === 'yes';
            $login_modal_title  = get_theme_mod( 'account_login_modal_title', esc_html__( 'Sign In', 'geeks' ) );
            $signup_modal_title = get_theme_mod( 'account_signup_modal_title', esc_html__( 'Sign Up ', 'geeks' ) );
            ?>
            <div class="modal fade" id="wcAccountModal" tabindex="-1" role="dialog" aria-labelledby="wcAccountModalTitle" aria-hidden="true">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="view" id="modal-signin-view" data-view-default>

                            <!-- Signin -->
                            <div class="modal-header">
                                <?php if ( ! empty( $login_modal_title ) ) : ?>
                                    <h5 class="modal-title" id="wcAccountModalTitle"><?php echo esc_html( apply_filters( 'geeks_login_modal_title', $login_modal_title ) ); ?></h5>
                                <?php endif; ?>
                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close">
                                    <span aria-hidden="true">&times;</span>
                                </button>

                            </div>

                            <div class="modal-body">
                                <?php
                                woocommerce_login_form(
                                    [
                                        'redirect' => get_permalink( wc_get_page_id( 'myaccount' ) ),
                                    ]
                                );
                                ?>

                            </div>
                        </div>

                        <?php if ( $has_registration_form ) : ?> 
                            <div class="view" id="modal-signup-view">
                                <div class="modal-header">
                                    <?php if ( ! empty( $signup_modal_title ) ) : ?>
                                        <h5 class="modal-title"><?php echo esc_html( apply_filters( 'geeks_signup_modal_title', $signup_modal_title ) ); ?></h5>
                                    <?php endif; ?>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close">
                                        <span aria-hidden="true">&times;</span>
                                    </button>
                                </div>

                                <div class="modal-body">
                                    <?php geeks_wc_registration_form(); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                        
                    </div>
                </div>
            </div>
            <?php
        }
    }
}


if ( ! function_exists( 'geeks_navbar_cart' ) ) {
    /**
     * Display Header Cart
     *
     * @since  1.0.0
     * @uses  geeks_is_woocommerce_activated() check if WooCommerce is activated
     * @return void
     */
    function geeks_navbar_cart() {
        if ( geeks_navbar_is_enable_cart() ) :
        ?>
            <div class="header__cart position-relative dropdown ms-auto">
                <a class="d-inline-block cart-contents position-relative" href="<?php echo esc_url( wc_get_cart_url() ); ?>" role="button" id="dropdownCart" data-bs-toggle="dropdown" data-bs-display="static" aria-expanded="false">
                    <i class="fe fs-3 text-dark fe-shopping-cart"></i>
                    <span class="badge bg-primary rounded-circle position-absolute right-end"><?php geeks_cart_link_count(); ?></span>
                </a>
                <?php geeks_wc_mini_cart_content(); ?>
                
            </div>
            <?php
        endif;
        
    }
}

if ( ! function_exists( 'geeks_cart_link_count' ) ) {
    /**
     * Cart link count
     */
    function geeks_cart_link_count() {
        ?>
        <span class="cart-contents-count">
            <?php echo absint( is_a( WC()->cart, 'WC_Cart' ) ? WC()->cart->get_cart_contents_count() : 0 ); ?>
        </span>

        <?php
    }
}

if ( ! function_exists( 'geeks_wc_mini_cart_content' ) ) {
    /**
     * Offcanvas Mini cart content
     */
    function geeks_wc_mini_cart_content() {
        ?>
       <div class="geeks-minicart dropdown-menu dropdown-menu-end" aria-labelledby="dropdownCart">
            <div class="widget_shopping_cart_content dropdown-item bg-transparent">
                <?php woocommerce_mini_cart(); ?>
            </div>
        </div>
        <?php
    }
}