<?php
/**
 * Template functions used in My Account
 */

if ( ! function_exists( 'geeks_wc_account_title' ) ) {
	/**
	 * Output Woocommerce Account Title
	 */
	function geeks_wc_account_title() {
		global $wp;

		$endpoints = wc_get_account_menu_items();
		$title     = esc_html_x( 'My Account', 'front-end', 'geeks' );
		foreach ( $endpoints as $endpoint => $label ) {
			if ( isset( $wp->query_vars[ $endpoint ] ) ) {
				$title = $label;
			} elseif ( isset( $wp->query_vars['orders'] ) ) {
				$title = esc_html_x( 'Orders', 'front-end', 'geeks' );
				break;
			}
		}

		echo esc_html( apply_filters( 'geeks_wc_account_title', $title ) );
	}
}

if ( ! function_exists( 'geeks_wc_login_register_wrap_start' ) ) {
	/**
	 * Output Wrapper Start for Login/Register
	 */
	function geeks_wc_login_register_wrap_start() {
		if ( is_account_page() ) : ?>
		<div class="d-flex flex-column container">
			<div class="row align-items-center justify-content-center g-0 min-vh-100">
				<div class="col-lg-5 col-md-8 py-8 py-xl-0">
				<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_wc_login_register_wrap_end' ) ) {
	/**
	 * Output Wrapper End for Login/Register
	 */
	function geeks_wc_login_register_wrap_end() {
		if ( is_account_page() ) :
			?>

				</div><!-- /.col -->
			</div><!-- /.row -->
		</div><!-- /.container -->
			<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_lost_password_form' ) ) {
	/**
	 * Display Lost Password Form
	 */
	function geeks_lost_password_form() {
		wc_get_template( '/woocommerce/myaccount/form-lost-password.php' );
	}
}


if ( ! function_exists( 'geeks_account_page_header' ) ) {
	/**
	 * Output of Account Page Header
	 */
	function geeks_account_page_header() {
		if ( is_user_logged_in() ) {
			$current_user_id = get_current_user_id();
			?>

			<div class="row align-items-center">
				<div class="col-xl-12 col-lg-12 col-md-12 col-12">
					<!-- Bg -->
					<div class="pt-16 rounded-top-md" style="background: url(<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/background/profile-bg.jpg) no-repeat; background-size: cover;"></div>
					<div class="d-flex align-items-end justify-content-between bg-white px-4 pt-2 pb-4 rounded-none rounded-bottom-md shadow-sm">
						<div class="d-flex align-items-center">
							<div class="me-2 position-relative d-flex justify-content-end align-items-end mt-n5">
								<?php echo wp_kses_post( get_avatar( get_the_author_meta( 'ID', $current_user_id ), 80, '', '', array( 'class' => 'avatar-xl rounded-circle border border-4 border-white position-relative avatar' ) ) ); ?>
							</div>
							<div class="lh-1">
								<h2 class="mb-0"><?php echo esc_html( get_the_author_meta( 'display_name', $current_user_id ) ); ?></h2>
								<p class="mb-0 d-block">@<?php echo esc_html( get_the_author_meta( 'user_nicename', $current_user_id ) ); ?></p>
							</div>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'geeks_wc_registration_form' ) ) {
	/**
	 * Account Registration Form
	 */
	function geeks_wc_registration_form() {
		?>

		<div class="mb-4">
			<?php geeks_profile_form_branding(); ?>
			<h3 class="h1 mb-1 fw-bold"><?php echo esc_html_x( 'Register', 'register-heading', 'geeks' ); ?></h3>
			<span><?php esc_html_e( 'Already have an account?', 'geeks' ); ?><a id="login-tab" href="#" data-view="#modal-signin-view" class="ms-1"><?php esc_html_e( 'Sign in', 'geeks' ); ?></a></span>   
		</div>

		<form method="post" class="woocommerce-form woocommerce-form-register register" <?php do_action( 'woocommerce_register_form_tag' ); ?> >

			<?php do_action( 'woocommerce_register_form_start' ); ?>

			<?php if ( 'no' === get_option( 'woocommerce_registration_generate_username' ) ) : ?>

				<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
					<label class="form-label" for="reg_username"><?php esc_html_e( 'Username', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
                    <input type="text" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="username" id="reg_username" placeholder="<?php esc_attr_e( 'Username', 'geeks' ); ?>" autocomplete="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
				</p>

			<?php endif; ?>

			<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
				<label class="form-label" for="reg_email"><?php esc_html_e( 'Email address', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
                <input type="email" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="email" id="reg_email" placeholder="<?php esc_attr_e( 'Email', 'geeks' ); ?>" autocomplete="email" value="<?php echo ( ! empty( $_POST['email'] ) ) ? esc_attr( wp_unslash( $_POST['email'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
			</p>

			<?php if ( 'no' === get_option( 'woocommerce_registration_generate_password' ) ) : ?>

				<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
					<label class="form-label" for="reg_password"><?php esc_html_e( 'Password', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
					<input type="password" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="password" id="reg_password" placeholder="<?php esc_attr_e( 'Password', 'geeks' ); ?>" autocomplete="new-password" />
				</p>

			<?php else : ?>

				<p><?php esc_html_e( 'A password will be sent to your email address.', 'geeks' ); ?></p>

			<?php endif; ?>

			<?php do_action( 'woocommerce_register_form' ); ?>
			<div>
				<div class="woocommerce-form-row form-row d-grid">
					<?php wp_nonce_field( 'woocommerce-register', 'woocommerce-register-nonce' ); ?>
					<button type="submit" class="btn btn-primary woocommerce-Button woocommerce-button button woocommerce-form-register__submit" name="register" value="<?php esc_attr_e( 'Register', 'geeks' ); ?>"><?php esc_html_e( 'Register', 'geeks' ); ?></button>
				</div>
			</div>
			<?php do_action( 'woocommerce_register_form_end' ); ?>

		</form>
		<?php
	}
}


if ( ! function_exists( 'geeks_wc_account_menu_item_classes' ) ) {
	/**
	 * Override dashboard menu item classes
	 *
	 * @param array  $classes default classes for menu item.
	 * @param string $endpoint WooCommerce endpoint.
	 * @return string
	 */
	function geeks_wc_account_menu_item_classes( $classes, $endpoint ) {
		global $wp;

		$current = isset( $wp->query_vars[ $endpoint ] );

		if ( 'dashboard' === $endpoint && ( isset( $wp->query_vars['page'] ) || empty( $wp->query_vars ) ) ) {
			$current = true; // Dashboard is not an endpoint, so needs a custom check.
		} elseif ( 'orders' === $endpoint && isset( $wp->query_vars['view-order'] ) ) {
			$current = true; // When looking at individual order, highlight Orders list item (to signify where in the menu the user currently is).
		} elseif ( 'payment-methods' === $endpoint && isset( $wp->query_vars['add-payment-method'] ) ) {
			$current = true;
		}

		if ( $current ) {
			$classes[] = 'active';
		}

		return $classes;
	}
}
