<?php
/**
 * Template functions used in Product Archive
 */

if ( ! function_exists( 'geeks_product_loop_start' ) ) {
	/**
	 * Output of Product Loop Start
	 *
	 * @param string $loop_start HTML of the loop.
	 */
	function geeks_product_loop_start( $loop_start ) {
		$columns         = apply_filters( 'geeks_loop_shop_columns', wc_get_loop_prop( 'columns' ) );
		$loop_start_html = '<div class="geeks-products products row row-cols-md-2 row-cols-lg-' . esc_attr( $columns ) . '">';
		return $loop_start_html;
	}
}


if ( ! function_exists( 'geeks_get_shop_layout' ) ) {
	/**
	 * Shop Layout
	 */
	function geeks_get_shop_layout() {
		$layouts = geeks_wc_views();
		$layout  = 'grid';

		return $layout;
	}
}

if ( ! function_exists( 'geeks_shop_control_bar' ) ) {
	/**
	 * Output of Shop Control Bar
	 */
	function geeks_shop_control_bar() { ?>
		<div class="col-lg-12 col-md-12 col-sm-12 col-12 mb-4 mb-4">
			<div class="row d-lg-flex justify-content-between align-items-center">
				<div class="shop__top-bar--left col-md-6 col-lg-8 col-xl-9">
					<?php woocommerce_result_count(); ?>
				</div>

				<div class="shop__top-bar--right d-inline-flex col-md-6 col-lg-4 col-xl-3">
					<div class="shop__view-switcher me-2">
						<?php geeks_wc_products_view_switcher(); ?>
					</div>

					<div class="shop__orderby w-100">
						<?php woocommerce_catalog_ordering(); ?>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_wc_views' ) ) {
	/**
	 * Output Shop View
	 */
	function geeks_wc_views() {
		return apply_filters( 'geeks_wc_views', array( 'grid', 'list' ) );
	}
}

if ( ! function_exists( 'geeks_wc_products_view_switcher' ) ) {
	/**
	 * Shop View Switcher
	 */
	function geeks_wc_products_view_switcher() {

		global $wp_query;

		if ( ! woocommerce_products_will_display() ) {
			return;
		}

		if ( 'subcategories' !== woocommerce_get_loop_display_mode() ) {

			$layouts = geeks_wc_views();
			$active  = geeks_get_shop_layout();

			?>
			<div class="switch-layout nav btn-group flex-nowrap btn-group-toggle" data-toggle="buttons">
				<?php

				foreach ( $layouts as $layout ) :

					$atts = [
						'class'          => 'switch-btn btn btn-outline-white ' . $layout,
						/* translators: %s: layout name */
						'title'          => sprintf( esc_html__( 'Switch to %s', 'geeks' ), $layout ),
						'for'            => 'lp-switch-layout-btn-' . $layout,
						'data-bs-toggle' => 'tab',
						'data-bs-target' => '#tab-pane-' . $layout,
						'role'           => 'tab',
						'aria-controls'  => 'tab-pane-' . $layout,
					];

					$is_active = false;

					if ( $layout === $active ) {
						$is_active             = true;
						$atts['class']        .= ' active';
						$atts['aria-selected'] = 'true';
					} else {
						$atts['aria-selected'] = 'false';
					}

					?>
				<label <?php geeks_render_attributes( $atts ); ?>>
					<span class="fe fe-<?php echo esc_attr( $layout ); ?>"></span>
					<input type="radio" class="btn-check" name="lp-switch-layout-btn" value="<?php echo esc_attr( $layout ); ?>" id="lp-switch-layout-btn-<?php echo esc_attr( $layout ); ?>" <?php checked( $layout, $active ); ?>>
				</label>
			
					<?php
				endforeach;
				?>
			</div>
			<?php

		}
	}
}

if ( ! function_exists( 'geeks_wc_catalog_orderby' ) ) {
	/**
	 * Catalog Orderby Options
	 *
	 * @param string $options HTML of the loop.
	 */
	function geeks_wc_catalog_orderby( $options ) {
		$options = array(
			'menu_order' => esc_html__( 'Sort by', 'geeks' ),
			'date'       => esc_html__( 'Newest', 'geeks' ),
			'popularity' => esc_html__( 'Most Popular', 'geeks' ),
			'rating'     => esc_html__( 'Highest Rated', 'geeks' ),
			'price'      => esc_html__( 'Low Price', 'geeks' ),
			'price-desc' => esc_html__( 'High Price', 'geeks' ),

		);
		return $options;
	}
}

if ( ! function_exists( 'geeks_wc_format_sale_price' ) ) {
	/**
	 * Override sale price HTML
	 *
	 * @param string $price         Price HTML.
	 * @param mixed  $regular_price Regular Price.
	 * @param mixed  $sale_price    Sale Price.
	 */
	function geeks_wc_format_sale_price( $price, $regular_price, $sale_price ) {
		if ( is_single() ) {
			$price_classes = 'fs-4';
		} else {
			$price_classes = 'fs-6';
		}

		$price = '<ins class="text-decoration-none">' . ( is_numeric( $sale_price ) ? wc_price( $sale_price ) : $sale_price ) . '</ins> <del class="' . $price_classes . ' fw-normal text-muted">' . ( is_numeric( $regular_price ) ? wc_price( $regular_price ) : $regular_price ) . '</del>';
		return $price;
	}
}

if ( ! function_exists( 'geeks_template_loop_categories' ) ) {
	/**
	 * Output Product Loop Categories.
	 */
	function geeks_template_loop_categories() {
		global $product;

		$taxonomy = 'product_cat';
		$terms    = get_the_terms( $product->get_id(), $taxonomy );
		if ( empty( $terms ) || is_wp_error( $terms ) ) {
			return;
		}

		$links = [];
		foreach ( $terms as $term ) {
			$link = get_term_link( $term, $taxonomy );
			if ( is_wp_error( $link ) ) {
				continue;
			}

			$links[] = sprintf(
				'<a href="%s" class="mb-1 text-body" rel="tag">%s</a>',
				esc_url( $link ),
				esc_html( $term->name )
			);
		}

		echo wp_kses_post( apply_filters( 'geeks_template_loop_categories_html', sprintf( '%s', implode( ', ', $links ) ) ) );
	}
}


if ( ! function_exists( 'geeks_loop_product_meta' ) ) {
	/**
	 * Outputs Product meta info
	 *
	 * @param string $view pass the view of the Products loop 'grid' or 'list'.
	 */
	function geeks_loop_product_meta( $view = 'grid' ) {
		?>

		<ul class="list-inline mb-3">
			<li class="list-inline-item woocommerce-loop-product__categories text-body">
				<?php geeks_template_loop_categories(); ?>                 
			</li>

			<?php if ( 'list' === $view && wc_review_ratings_enabled() ) { ?>
				<li class="list-inline-item">
					<?php woocommerce_template_loop_rating( $view ); ?>
				</li>
			<?php } ?>

		</ul>


		<?php if ( 'grid' === $view && wc_review_ratings_enabled() ) { ?>
			<div class="lh-1">
				<?php woocommerce_template_loop_rating( $view ); ?>
			</div>
			<?php
		}
	}
}


if ( ! function_exists( 'geeks_wc_loop_add_to_cart_link' ) ) {
	/**
	 * Add to cart class
	 *
	 * @param  array $cart_link Arguments for add to cart.
	 * @param  array $product Arguments for add to cart.
	 * @param  array $args Arguments for add to cart.
	 * @return array
	 */
	function geeks_wc_loop_add_to_cart_link( $cart_link, $product, $args ) {
		$add_to_cart = '</span><span class="product__add-to-cart-icon"><i class="fe fe-shopping-cart"></i></span><span class="product__add-to-cart ms-2">' . $product->add_to_cart_text() . '';

		return sprintf(
			'<a href="%s" data-quantity="%s" class="%s text-body col" %s title="%s">%s</a>',
			esc_url( $product->add_to_cart_url() ),
			esc_attr( isset( $args['quantity'] ) ? $args['quantity'] : 1 ),
			esc_attr( isset( $args['class'] ) ? $args['class'] : 'button' ),
			isset( $args['attributes'] ) ? wc_implode_html_attributes( $args['attributes'] ) : '',
			esc_attr( $product->add_to_cart_text() ),
			wp_kses_post( $add_to_cart )
		);
	}
}

if ( ! function_exists( 'geeks_loop_product_thumbnail' ) ) {
	/**
	 * Outputs Product Thumbnail
	 *
	 * @param string $view pass the view of the products loop 'grid' or 'list'.
	 */
	function geeks_loop_product_thumbnail( $view = 'grid' ) {
		global $product;

		$link               = apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );
		$product_image_id   = $product->get_image_id();
		$placholder_img_url = get_template_directory_uri() . '/assets/images/placeholder/4by3.jpg';

		if ( 'list' === $view ) :
			?>
			<a href="<?php echo esc_url( $link ); ?>" class="product__thumbnail woocommerce-LoopProduct-link woocommerce-loop-product__link col-12 col-md-12 col-xl-3 col-lg-3 bg-cover img-left-rounded" style="background-image: url( <?php echo esc_url( wp_get_attachment_url( $product_image_id ) ); ?> );" >
				<?php echo wp_get_attachment_image( $product_image_id, 'full', '', array( 'class' => 'img-fluid d-lg-none invisible' ) ); ?>
			</a>
		<?php else : ?>
			<a class="product__thumbnail card-img-top" href="<?php echo esc_url( $link ); ?>">
				<?php echo wp_get_attachment_image( $product_image_id, 'full', '', array( 'class' => 'card-img-top rounded-top' ) ); ?>
			</a>
			<?php
		endif;
	}
}

if ( ! function_exists( 'geeks_loop_product_footer' ) ) {
	/**
	 * Outputs Product Footer
	 *
	 * @param string $view pass the view of the products loop 'grid' or 'list'.
	 */
	function geeks_loop_product_footer( $view = 'list' ) {
		if ( 'list' !== $view ) {
			return;
		}
		?>

		<div class="mt-5">
			<?php do_action( 'geeks_products_loop_item_footer' ); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_loop_product_footer_wrap_start' ) ) {
	/**
	 * Outputs Product Footer Wrap Start
	 *
	 * @param string $view pass the view of the products loop 'grid' or 'list'.
	 */
	function geeks_loop_product_footer_wrap_start( $view = 'grid' ) {
		?>
		<div class="row align-items-center g-0">
		<?php
	}
}

if ( ! function_exists( 'geeks_loop_product_footer_wrap_end' ) ) {
	/**
	 * Output Product Footer wrap end
	 */
	function geeks_loop_product_footer_wrap_end() {
		?>
		</div>
		<?php
	}
}

/**
 * Outputs the "Add to wishlist" button in product tile
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'geeks_wc_loop_product_add_to_wishlist' ) ) {
	/**
	 * Outputs the "Add to wishlist" button
	 */
	function geeks_wc_loop_product_add_to_wishlist() {
		// check if Add to wishlist button is enabled for loop.
		$enabled_on_loop = 'yes' == get_option( 'yith_wcwl_show_on_loop', 'no' );
		// Add the link "Add to wishlist".
		$position = get_option( 'yith_wcwl_loop_position', 'after_add_to_cart' );

		if ( 'shortcode' === $enabled_on_loop && $position ) {
			echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
		}
	}
}

/**
 * Integrate plugin "YITH WooCommerce Wishlist" into the theme.
 */

if ( ! function_exists( 'geeks_add_to_wishlist_button' ) ) {
	/**
	 * Shortcode of "Add to wishlist" button
	 */
	function geeks_add_to_wishlist_button() {
		echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
	}
}

if ( ! function_exists( 'geeks_wc_paging_nav' ) ) {
	/**
	 * Product Pagination.
	 *
	 * @param string $ul_class Product.
	 */
	function geeks_wc_paging_nav( $ul_class ) {
		global $wp_query;

		if ( $wp_query->max_num_pages <= 1 ) {
			return;
		}

		$ul_class = empty( $ul_class ) ? 'text-center mb-0 justify-content-center' : $ul_class;
		?>
		<div class="text-center">
			<?php geeks_bootstrap_pagination( $wp_query, true, $ul_class ); ?>
		</div>
		<?php
	}
}


if ( ! function_exists( 'geeks_display_product_rating' ) ) {
		/**
		 * Override WooCommerce star rating HTML
		 *
		 * @param  string $html default HTML of star rating.
		 * @param  float  $rating           average rating of the product.
		 * @param  int    $count            total reviews.
		 */
	function geeks_display_product_rating( $html, $rating, $count ) {
		global $product;

		if ( empty( $count ) && $product ) {
			$count = $product->get_rating_count();
		}

		if ( 0 < floatval( $rating ) ) :
			?>
			<span>
				<?php geeks_display_review_stars( $rating ); ?>
			</span>

			<span class="text-warning"><?php echo esc_html( number_format_i18n( $rating, 1 ) ); ?></span>

			<?php if ( isset( $count ) ) : ?>
				<span class="fs-6 text-muted">(<?php echo esc_html( number_format_i18n( $count ) ); ?>)</span>
			<?php endif; ?>
		<?php else : ?>
			<span class="fs-6 text-muted"><?php esc_html_e( 'No ratings yet', 'geeks' ); ?></span>
			<?php
		endif;

	}
}

if ( ! function_exists( 'geeks_wc_get_star_rating_html' ) ) {
	/**
	 * Override WooCommerce star rating HTML
	 *
	 * @param  string $star_rating_html default HTML of star rating.
	 * @param  float  $rating           average rating of the product.
	 * @param  int    $count            total reviews.
	 * @return string
	 */
	function geeks_wc_get_star_rating_html( $star_rating_html, $rating, $count ) {
		global $product;

		if ( empty( $count ) && $product ) {
			$count = $product->get_rating_count();
		}

		$star_rating_html = '';

		if ( 0 === intval( $rating ) ) {
			$star_rating_html = '<span>' . esc_html__( 'No ratings yet.', 'geeks' ) . '</span>';
		} else {
			for ( $i = 0; $i < 5; $i++ ) {

				$diff = $rating - $i;

				$i_class = 'mdi';

				if ( $diff > 0.5 ) {
					$i_class .= ' mdi-star text-warning';
				} elseif ( 0.5 === $diff ) {
					$i_class .= ' mdi-star-half-full text-warning';
				} else {
					$i_class .= ' mdi-star text-gray';
				}

				$star_rating_html .= '<i class="' . esc_attr( $i_class ) . '"></i>';
			}
		}

		return $star_rating_html;
	}
}

if ( ! function_exists( 'geeks_wc_rating_filter_count_html' ) ) {
	/**
	 * Wrap rating filter count HTML
	 *
	 * @param string $count_html filter count html.
	 * @param string $count count value.
	 * @return string
	 */
	function geeks_wc_rating_filter_count_html( $count_html, $count ) {
		$count_html = '<span class="fs-6 ms-1">(' . $count . ')</span>';

		return $count_html;
	}
}


if ( ! function_exists( 'geeks_wc_layered_nav_term_html' ) ) {
	/**
	 * Override WooCommerce Nav Term HTML
	 *
	 * @param  string $term_html default HTML of star rating.
	 * @param  string $term default HTML of star rating.
	 * @param  string $link   average rating of the product.
	 * @param  int    $count            total reviews.
	 * @return string
	 */
	function geeks_wc_layered_nav_term_html( $term_html, $term, $link, $count ) {
		$count_html = '';
		if ( $count > 0 ) {
			$count_html = '<span class="fs-6 text-muted ms-1">' . absint( $count ) . '</span>';
		}

		if ( $link ) {
			$term_html = '<input type="checkbox" class="form-check-input"><a class="woocommerce-widget-layered-nav-list__item__link form-check-label text-body" rel="nofollow" href="' . $link . '">' . esc_html( $term->name ) . '</a>' . $count_html;
		} else {
			$term_html = '<span>' . esc_html( $term->name ) . '</span>';
		}
		return '<div class="woocommerce-widget-layered-nav-list__item__inner form-check mb-1">' . $term_html . '</div>';
	}
}

