<?php
/**
 * Template tags used in single product page
 */

if ( ! function_exists( 'geeks_wc_product_remove_sidebar' ) ) {
	/**
	 * Remove Shop Sidebar
	 */
	function geeks_wc_product_remove_sidebar() {
		if ( is_product() ) {
			remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar' );
		}
	}
}

if ( ! function_exists( 'geeks_single_product_page_header' ) ) {
	/**
	 * Single Product Header
	 */
	function geeks_single_product_page_header() { ?>

	<div class="pt-lg-8 pb-lg-16 pt-8 pb-12 bg-primary">
		<div class="container">
			<?php
			do_action( 'geeks_single_product_header_top' );
			?>

			<div class="row align-items-center">
				<div class="col-xl-7 col-lg-7 col-md-12">
					<div>
						<h1 class="text-white display-4 fw-semi-bold"><?php single_post_title(); ?></h1>

						<?php if ( has_excerpt() ) : ?>
							<div class="text-white mb-6 lead mb-0-last-child"><?php the_excerpt(); ?></div>
						<?php endif; ?>

						<div class="d-flex align-items-center">
							<?php
							global $product;

							$rating_count = $product->get_rating_count();

							if ( $rating_count > 0 ) :
								?>
								<span class="me-4">
									<?php woocommerce_template_single_rating(); ?>
								</span>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>

			<?php
			do_action( 'geeks_single_product_header_bottom' );
			?>
		</div>
	</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_wc_product_content_wrap_start' ) ) {
	/**
	 * Output wrapper start for single product summary
	 */
	function geeks_wc_product_content_wrap_start() {
		?>
		<div class="pb-10">
			<div class="container">
				<div class="row">
				<?php
	}
}

if ( ! function_exists( 'geeks_wc_product_content_wrap_end' ) ) {
	/**
	 * Output wrapper end for single product summary
	 */
	function geeks_wc_product_content_wrap_end() {
		?>
				</div>
			</div>
		</div>
		<?php

	}
}

if ( ! function_exists( 'geeks_wc_product_left_column_content' ) ) {
	/**
	 * Display WC product left content
	 */
	function geeks_wc_product_left_column_content() {
		?>
		<div class="col-lg-8 col-md-12 col-12 mt-n8 mb-4 mb-lg-0">
			<?php do_action( 'geeks_single_product_output_notice' ); ?>
			<?php woocommerce_output_product_data_tabs(); ?>
		</div>
		<?php

	}
}

if ( ! function_exists( 'geeks_wc_product_right_column_wrap_start' ) ) {
	/**
	 * Output wrapper start for right column product summary
	 */
	function geeks_wc_product_right_column_wrap_start() {
		?>
		<div class="col-lg-4 col-md-12 col-12 mt-lg-n22">
		<?php
	}
}

if ( ! function_exists( 'geeks_wc_product_right_column_wrap_end' ) ) {
	/**
	 * Output wrapper end for right column product summary
	 */
	function geeks_wc_product_right_column_wrap_end() {
		?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'geeks_wc_product_right_column_content' ) ) {
	/**
	 * Output wrapper start for right column top card
	 */
	function geeks_wc_product_right_column_content() {
		do_action( 'geeks_wc_product_before_summary' );
		?>
		<div class="card mb-3 mb-4">
			<div class="p-1">
				<?php do_action( 'geeks_wc_product_images' ); ?>
			</div>
			
			<div class="card-body summary entry-summary">
				<?php do_action( 'geeks_wc_product_summary' ); ?>
			</div>
		</div>
		<?php
		do_action( 'geeks_wc_product_after_summary' );

	}
}

if ( ! function_exists( 'geeks_wc_product_right_column_bottom_card' ) ) {
	/**
	 * Output wrapper start for right column bottom card
	 */
	function geeks_wc_product_right_column_bottom_card() {
		?>
		<div class="card mb-4">
			<div>
				<div class="card-header">
					<h4 class="mb-0">What’s included</h4>
				</div>
			</div>
		</div>
		<?php
	}
}


if ( ! function_exists( 'geeks_wc_reviews_overall' ) ) {
	/**
	 * Output reviews before content
	 */
	function geeks_wc_reviews_overall() {
		global $product;

		// Count the total number of stars per each rating value (e.g. total number of fives, fours, etc).
		$comments = get_comments(
			[
				'fields'  => 'ids',
				'post_id' => $product->get_id(),
				'status'  => 'approve',
			]
		);

		if ( empty( $comments ) ) {
			return;
		}

		// Count per rating.
		// Create an array with keys from 0 to 5 where each key is rating provided by user.
		// A key 0 will be used for invalid meta and will not be taken into account.
		$cpr = array_fill( 0, 6, 0 );
		foreach ( array_map( 'intval', $comments ) as $comment_id ) {
			// TODO: may we get rid of get_comment_meta and make this query a little bit more performant?
			$comment_rating = (int) get_comment_meta( $comment_id, 'rating', true );
			$cpr[ $comment_rating ] ++;
		}
		unset( $comment_id );

		// Total recommended is a sum of fives and fours.
		$total_recommended = $cpr[4] + $cpr[5];

		// A total number of reviews and an average product rating.
		$total_reviews = $product->get_review_count();
		$avg_rating    = $product->get_average_rating();
		$rating_count  = $product->get_rating_count();

		// With per rating.
		// Count the width of each progress bar for total number of fives, fours, etc.
		$wpr = array_fill( 0, 6, 0 );
		foreach ( $cpr as $k => $v ) {
			$wpr[ $k ] = round( ( $v * 100 ) / $total_reviews );
		}

		?>
		<div class="mb-3">
			<h3 class="mb-4"><?php echo esc_html__( 'How customers rated this product', 'geeks' ); ?></h3>
			<div class="row align-items-center">
				<div class="col-auto text-center">
					<h3 class="display-2 fw-bold"><?php echo esc_html( number_format( $avg_rating, 1 ) ); ?></h3>
					<?php geeks_display_review_stars( $avg_rating ); ?>

					<p class="mb-0 fs-6">(
					<?php
					echo esc_html(
						sprintf(
						/* translators: %s number of articles to read. */
							_nx( 'Based on %s review', 'Based on %s reviews', $total_reviews, 'number of reviews', 'geeks' ),
							number_format_i18n( $total_reviews, 1 )
						)
					);
					?>
						)
					</p>
				</div>

				<div class="col pt-3 order-3 order-md-2">
					<div class="progress mb-3" style="height: 6px;">
						<div class="progress-bar bg-warning" role="progressbar" style="width: <?php echo absint( $wpr[5] ); ?>%;" aria-valuenow="<?php echo absint( $wpr[5] ); ?>" aria-valuemin="0" aria-valuemax="100"></div>
					</div>

					<div class="progress mb-3" style="height: 6px;">
						<div class="progress-bar bg-warning" role="progressbar" style="width: <?php echo absint( $wpr[4] ); ?>%;" aria-valuenow="<?php echo absint( $wpr[4] ); ?>" aria-valuemin="0" aria-valuemax="100"></div>
					</div>

					<div class="progress mb-3" style="height: 6px;">
						<div class="progress-bar bg-warning" role="progressbar" style="width: <?php echo absint( $wpr[3] ); ?>%;" aria-valuenow="<?php echo absint( $wpr[3] ); ?>" aria-valuemin="0" aria-valuemax="100"></div>
					</div>

					<div class="progress mb-3" style="height: 6px;">
						<div class="progress-bar bg-warning" role="progressbar" style="width: <?php echo absint( $wpr[2] ); ?>%;" aria-valuenow="<?php echo absint( $wpr[2] ); ?>" aria-valuemin="0" aria-valuemax="100"></div>
					</div>

					<div class="progress mb-0" style="height: 6px;">
						<div class="progress-bar bg-warning" role="progressbar" style="width: <?php echo absint( $wpr[1] ); ?>%;" aria-valuenow="<?php echo absint( $wpr[1] ); ?>" aria-valuemin="0" aria-valuemax="100"></div>
					</div>

				</div>

				<div class="col-md-auto col-6 order-2 order-md-3">
					<div>
						<?php
						for ( $i = 0; $i < 5; $i++ ) :
							;
							?>
						<i class="mdi mdi-star me-n1 
							<?php
							if ( $i < 5 ) :
								?>
							text-warning
								<?php
else :
	?>
								text-light<?php endif; ?>"></i>
						<?php endfor; ?>
						<span class="ms-1"><?php echo absint( $cpr[5] ); ?>%</span>

					</div>

					<div>
						<?php
						for ( $i = 0; $i < 5; $i++ ) :
							;
							?>
						<i class="mdi mdi-star me-n1 
							<?php
							if ( $i < 4 ) :
								?>
							text-warning
								<?php
else :
	?>
								text-light<?php endif; ?>"></i>
						<?php endfor; ?>
						<span class="ms-1"><?php echo absint( $cpr[4] ); ?>%</span>

					</div>

					<div>
						<?php
						for ( $i = 0; $i < 5; $i++ ) :
							;
							?>
						<i class="mdi mdi-star me-n1 
							<?php
							if ( $i < 3 ) :
								?>
							text-warning
								<?php
else :
	?>
								text-light<?php endif; ?>"></i>
						<?php endfor; ?>
						<span class="ms-1"><?php echo absint( $cpr[3] ); ?>%</span>

					</div>

					<div>
						<?php
						for ( $i = 0; $i < 5; $i++ ) :
							;
							?>
						<i class="mdi mdi-star me-n1 
							<?php
							if ( $i < 2 ) :
								?>
							text-warning
								<?php
else :
	?>
								text-light<?php endif; ?>"></i>
						<?php endfor; ?>
						<span class="ms-1"><?php echo absint( $cpr[2] ); ?>%</span>

					</div>

					<div>
						<?php
						for ( $i = 0; $i < 5; $i++ ) :
							;
							?>
						<i class="mdi mdi-star me-n1 
							<?php
							if ( $i < 1 ) :
								?>
							text-warning
								<?php
else :
	?>
								text-light<?php endif; ?>"></i>
						<?php endfor; ?>
						<span class="ms-1"><?php echo absint( $cpr[1] ); ?>%</span>

					</div>
				</div>
			</div>

		</div>
		<hr class="my-5">


		<?php
	}
}

if ( ! function_exists( 'geeks_wc_review_before' ) ) {
	/**
	 * Output reviews before content
	 *
	 * @param WP_Comment $comment Comment to display.
	 */
	function geeks_wc_review_before( $comment ) {
		$verified = wc_review_is_from_verified_owner( $comment->comment_ID );
		$rating   = intval( get_comment_meta( $comment->comment_ID, 'rating', true ) );

		?>

		<div class="d-flex">
			<?php
			echo get_avatar(
				$comment,
				apply_filters( 'woocommerce_review_gravatar_size', 56 ),
				'',
				get_comment_author( $comment ),
				[
					'class' => 'rounded-circle avatar-lg',
				]
			);
			?>

			<div class="ms-3">
				<h4 class="mb-1"><?php comment_author( $comment ); ?>
					<?php if ( 'yes' === get_option( 'woocommerce_review_rating_verification_label' ) && $verified ) : ?>
						<i class="fe fe-check-circle ms-1 mt-n1 fs-6 align-items-center text-success" data-toggle="tooltip" data-original-title="<?php echo esc_attr__( 'verified owner', 'geeks' ); ?>"></i>
					<?php endif; ?>

					<span class="ms-1 fs-6 text-muted">
						<?php
						echo esc_html(
							sprintf(
							/* translators: %s is comment date */
								esc_html__( '%s ago', 'geeks' ),
								human_time_diff( strtotime( $comment->comment_date ) )
							)
						);
						?>
					</span> 
					
				</h4>
				<div class="fs-6 mb-2">
					<?php
					if ( $rating && wc_review_ratings_enabled() ) :
						geeks_display_review_stars( $rating );
					endif;
					?>
				</div>

				<div class="mb-2 mb-0-last-child">
					<?php if ( '0' === $comment->comment_approved ) : ?>
						<em class="woocommerce-review__awaiting-approval">
							<?php esc_html_e( 'Your review is awaiting approval', 'geeks' ); ?>
						</em>
					<?php else : ?>
						<?php comment_text( $comment ); ?>
					<?php endif; ?>
				</div>

			</div>

		</div>

		<?php
	}
}

/**
 * Displays navigation to next/previous set of comments, when applicable.
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'geeks_wc_comments_navigation' ) ) {
	/**
	 * Displays navigation to next/previous set of comments, when applicable.
	 */
	function geeks_wc_comments_navigation() {
		if ( absint( get_comment_pages_count() ) === 1 ) {
			return;
		}

		/* translators: label for link to the previous comments page */
		$prev_text = esc_html_x( 'Older comments', 'front-end', 'geeks' );
		$prev_link = get_previous_comments_link( '<i class="fe fe-arrow-left me-2"></i>' . $prev_text );

		/* translators: label for link to the next comments page */
		$next_text = esc_html_x( 'Newer comments', 'front-end', 'geeks' );
		$next_link = get_next_comments_link( $next_text . '<i class="fe fe-arrow-right ms-2"></i>' );

		?>
		<nav class="navigation comment-navigation d-flex justify-content-between" role="navigation">
			<h3 class="screen-reader-text sr-only">
			<?php
				/* translators: navigation through comments */
				echo esc_html_x( 'Comment navigation', 'front-end', 'geeks' );
			?>
				</h3>
			<?php if ( $prev_link ) : ?>
				<ul class="pagination">
					<li class="page-item">
						<?php echo wp_kses_post( str_replace( '<a ', '<a class="page-link" ', $prev_link ) ); ?>
					</li>
				</ul>
			<?php endif; ?>
			<?php if ( $next_link ) : ?>
				<ul class="pagination">
					<li class="page-item">
						<?php echo wp_kses_post( str_replace( '<a ', '<a class="page-link" ', $next_link ) ); ?>
					</li>
				</ul>
			<?php endif; ?>
		</nav>
		<?php
	}
}

if ( ! function_exists( 'geeks_output_related_products_args' ) ) {
	/**
	 * Output Related Product Args
	 *
	 * @param  array $args Arguments for related products.
	 */
	function geeks_output_related_products_args( $args ) {

		$args = array(
			'posts_per_page' => 4,
			'columns'        => apply_filters( 'geeksrelated_products_columns', 4 ),
		);
		return $args;
	}
}

if ( ! function_exists( 'geeks_wc_single_product_add_to_wishlist' ) ) {
	/**
	 * Single Product Add to Wishlist Shortcode
	 */
	function geeks_wc_single_product_add_to_wishlist() {
		$position = get_option( 'yith_wcwl_button_position', 'after_add_to_cart' );

		if ( 'add-to-cart' === $position ) {
			echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
		}
	}
}



if ( ! function_exists( 'geeks_wc_show_product_images' ) ) {
	/**
	 * Single Product Images
	 */
	function geeks_wc_show_product_images() {
		global $product;

		$columns           = apply_filters( 'woocommerce_product_thumbnails_columns', 4 );
		$post_thumbnail_id = $product->get_image_id();
		$attachment_ids    = $product->get_gallery_image_ids();
		$wrapper_id        = 'bookworm-single-product-gallery-' . uniqid();
		$wrapper_classes   = apply_filters(
			'woocommerce_single_product_image_gallery_classes',
			array(
				'woocommerce-product-gallery',
				'woocommerce-product-gallery--' . ( has_post_thumbnail() ? 'with-images' : 'without-images' ),
				'woocommerce-product-gallery--columns-' . absint( $columns ),
				'woocommerce-thumb-count-' . count( $attachment_ids ),
				'images',
			)
		);
		$image_ids         = $attachment_ids;
		array_unshift( $image_ids, $post_thumbnail_id );

		?>
		<div class="<?php echo esc_attr( implode( ' ', array_map( 'sanitize_html_class', $wrapper_classes ) ) ); ?>" data-columns="<?php echo esc_attr( $columns ); ?>">

			<!-- Main Slider -->
			 <div id="carouselExampleControls" class="carousel slide" data-bs-ride="carousel">

				  <div class="carousel-inner">
					<?php
					$index = 0;
					foreach ( $image_ids as $image_id ) :

						if ( $image_id ) {
							?>
							<div class="carousel-item 
							<?php
							if ( 0 === $index ) :
								?>
								active<?php endif; ?>">
								<?php echo wp_kses_post( wc_get_gallery_image_html( $image_id, true ) ); ?>
							</div>
							<?php
						} else {
							echo '<div class="front-wc-product-gallery__image--placeholder">';
							echo sprintf( '<img src="%s" alt="%s" class="wp-post-image d-block w-100 rounded" />', esc_url( wc_placeholder_img_src( 'woocommerce_single' ) ), esc_attr__( 'Awaiting product image', 'geeks' ) );
							echo '</div>';
						}

						$index++;

					endforeach;
					?>
				</div>
				<?php if ( count( $attachment_ids ) > 0 ) : ?>

					<a class="carousel-control-prev opacity-1" href="#carouselExampleControls" role="button" data-bs-slide="prev">
						<span class="icon-shape icon-md bg-white border text-muted icon-sm rounded-circle" aria-hidden="true">
						<?php if(is_rtl()) {
							echo '<i class="fe fe-chevron-right fs-4"></i>';
						} else {
							echo '<i class="fe fe-chevron-left fs-4"></i>';
						}
						?>
						</span>
						<span class="sr-only"><?php echo esc_html__( 'Previous', 'geeks' ); ?></span>
					  </a>

					  <a class="carousel-control-next" href="#carouselExampleControls" role="button" data-bs-slide="next">
						<span class="icon-shape icon-md bg-white border text-muted icon-sm rounded-circle" aria-hidden="true">
						<?php if(is_rtl()) {
							echo '<i class="fe fe-chevron-left fs-4"></i>';
						} else {
							echo '<i class="fe fe-chevron-right fs-4"></i>';
						}
						?>						</span>
						<span class="sr-only"><?php echo esc_html__( 'Next', 'geeks' ); ?></span>
					  </a>
				<?php endif; ?>
			</div> 

		 </div>

		
		<?php
	}
}

if ( ! function_exists( 'geeks_wc_get_availability_class' ) ) {
	/**
	 * Get availability class
	 *
	 * @param  string     $class availability class.
	 * @param  WC_Product $product WooCommerce product.
	 * @return string
	 */
	function geeks_wc_get_availability_class( $class, $product ) {

		if ( 'out-of-stock' === $class ) {
			$class = 'text-danger';
		} elseif ( 'available-on-backorder' === $class ) {
			$class = 'text-success';
		} elseif ( 'in-stock' === $class ) {
			$class = 'text-success';
		}

		return $class;
	}
}


