<?php
/**
 * Geeks Job Manager Customizer Class
 *
 * @package  geeks
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! class_exists( 'Geeks_WPJM_Customizer' ) ) :


    class Geeks_WPJM_Customizer extends Geeks_Customizer {
        /**
         * Setup class.
         *
         * @since 1.0.0
         * @return void
         */
        public function __construct() {
            add_action( 'customize_register', array( $this, 'customize_job' ), 10 );
            add_action( 'customize_controls_print_scripts', array( $this, 'add_scripts' ), 30 );
        }
       
        /**
         * Add postMessage support for site title and description for the Theme Customizer along with several other settings.
         *
         * @param WP_Customize_Manager $wp_customize Theme Customizer object.
         * @since 2.4.0
         */
        public function customize_job( $wp_customize ) {
            /**
             * job
             */
            $wp_customize->add_section( 'geeks_job', [
                'priority' => 50,
                'title'    => esc_html__( 'Jobs', 'geeks' ),
            ] );

            $this->add_job_section( $wp_customize );
        }

        /**
         * Scripts to improve our form.
         */
        public function add_scripts() { 
            $jobs_page_id = get_option( 'job_manager_jobs_page_id' );
            ?>
            <script type="text/javascript">
            jQuery( document ).ready( function( $ ) {
                
                wp.customize.section( 'geeks_job', function( section ) {
                    section.expanded.bind( function( isExpanded ) {
                        if ( isExpanded ) {
                            wp.customize.previewer.previewUrl.set( '<?php echo esc_js( get_permalink( $jobs_page_id ) ); ?>' );
                        }
                    } );
                } );
            });
            </script><?php
        }

        /**
         * Job Section
         *
         * @param WP_Customize_Manager $wp_customize Theme Customizer object.
         */
        private function add_job_section( $wp_customize ) {
            $this->static_contents = static_content_options();
            
            $wp_customize->add_setting( 'enable_application_form', [
                'default'           => 'no',
                'sanitize_callback' => 'sanitize_key',
            ] );

            $wp_customize->add_control( 'enable_application_form', [
                'type'        => 'radio',
                'section'     => 'geeks_job',
                'label'       => esc_html__( 'Do you want to use a custom application form for the jobs?', 'geeks' ),
                'description' => esc_html__( 'This setting allows you to show or hide application form.', 'geeks' ),
                'choices'     => [
                    'yes' => esc_html__( 'Yes', 'geeks' ),
                    'no'  => esc_html__( 'No', 'geeks' ),
                ],
            ] );

            $wp_customize->selective_refresh->add_partial( 'enable_application_form', [
                'fallback_refresh'    => true
            ] );

            $wp_customize->add_setting( 'geeks_application_form', [
                'sanitize_callback' => 'geeks_slug_sanitize_html',
            ] );

            $wp_customize->add_control( 'geeks_application_form', [
                'type'            => 'textarea',
                'section'         => 'geeks_job',
                'label'           => esc_html__( 'Application Form', 'geeks' ),
                'description'     => esc_html__( 'Paste your application form HTML or shortcode here', 'geeks' ),
                'active_callback' => function () {
                    return 'yes' === get_theme_mod( 'enable_application_form', 'no' );
                },
            ] );

            $wp_customize->selective_refresh->add_partial( 'geeks_application_form', [
                'fallback_refresh'    => true
            ] );
        }
    }

endif;

return new Geeks_WPJM_Customizer();