<?php
/**
* Geeks Job Manager Class
*
* @package  front
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( ! class_exists( 'Geeks_WPJM' ) ) :

/**
* The Geeks WP Job Manager Integration class
*/
class Geeks_WPJM {

    public function __construct() {
        add_action( 'widgets_init', array( $this, 'widgets_init' ) );
        add_filter( 'body_class', array( $this, 'set_bg_light' ), 10, 2 );
        add_filter( 'job_manager_enqueue_frontend_style', '__return_false', 30 );
        add_action( 'init', array( $this, 'init' ) );
        add_filter( 'job_manager_page_ids', array( $this, 'check_empty_wpjm_pages' ) );
        add_filter( 'job_manager_job_listings_output', array( $this, 'update_load_more_listings' ) );
        add_action( 'job_manager_job_filters_end', [ $this, 'job_filter_results' ], 29 );
    }

    /**
     * Shows results div.
     */
    public function job_filter_results() {
        remove_action( 'job_manager_job_filters_end', array( WP_Job_Manager_Shortcodes::instance(), 'job_filter_results' ), 30 );
        echo '<div class="mb-5 showing_jobs"></div>';
    }

    public function update_load_more_listings( $content ) {
        return str_replace( '<a class="load_more_jobs', '<a class="mx-auto load_more_jobs btn btn-primary', $content );
    }

    public function init() {
        if ( apply_filters( 'geeks_wpjm_use_custom_form_application', filter_var( get_theme_mod( 'enable_application_form' ), FILTER_VALIDATE_BOOLEAN ) ) ) {

            global $job_manager;

            if ( ! is_admin() ) {
                if ( get_option( 'job_application_form_for_email_method', '1' ) ) {
                    add_action( 'job_manager_application_details_email', [ $this, 'application_form' ], 20 );

                    // Unhook job manager apply details
                    remove_action( 'job_manager_application_details_email', [ $job_manager->post_types, 'application_details_email' ] );
                }
                if ( get_option( 'job_application_form_for_url_method', '1' ) ) {
                    add_action( 'job_manager_application_details_url', [ $this, 'application_form' ], 20 );

                    // Unhook job manager apply details
                    remove_action( 'job_manager_application_details_url', [ $job_manager->post_types, 'application_details_url' ] );
                }
            }
        }
    }

    public function check_empty_wpjm_pages( $wpjm_page_ids ) {
        if ( empty( $wpjm_page_ids ) ) {
            $wpjm_page_ids = array( false );
        }

        return $wpjm_page_ids;
    }

    public function application_form() {
        $application_form = apply_filters( 'geeks_wpjm_application_form_shortcode', get_theme_mod( 'geeks_application_form' ) );

        if ( ! empty( $application_form ) ) {
            echo do_shortcode( $application_form );
        }
    }

    public function set_bg_light( $classes, $class ) {
        if ( is_wpjm() ) {
            $classes[] = 'bg-light';    
        }

        return $classes;
    }

    public function widgets_init() {
        register_sidebar( array(
            'name'          => esc_html__( 'Single Job Listing Sidebar', 'geeks' ),
            'id'            => 'sidebar-single-job-listing',
            'description'   => esc_html__( 'Widgets in this area will be shown under your single job listing, before comments.', 'geeks' ),
            'before_widget' => '<div class="card shadow-light-lg mb-5"><div class="card-body">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>',
        ) );
    }
}

endif;

new geeks_WPJM();