<?php
/**
 * Template for displaying payment form for checkout page.
 *
 * Edit by Nhamdv
 *
 * This template can be overridden by copying it to yourtheme/learnpress/checkout/payment.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();
?>
<div id="checkout-payment" class="lp-checkout-block left card">
	<?php
	do_action( 'learn-press/before-payment-methods' );

	// Show payments if cart total > 0 and have at least one payment method.
	if ( LP()->cart->needs_payment() && $available_gateways ) {
		?>
		<div class="card-header d-flex justify-content-between align-items-center">
			<h3 class="mb-0">
				<?php esc_html_e( 'Payment', 'geeks' ); ?>
			</h3>
			<span class="secure-connection">
				<i class="fas fa-lock"></i>
				<?php echo esc_html_x( 'Secure Connection', 'payment method', 'geeks' ); ?>
			</span>
		</div>

		<div class="card-body pb-0">

			<div class="d-inline-flex mb-4">
				<?php foreach( $available_gateways as $gateway ) : ?>
				<div class="me-3 form-check">
					<label data-bs-toggle="collapse" data-bs-target="#learn-press-payment-method-<?php echo esc_attr( $gateway->id ); ?>" for="payment_method_<?php echo esc_attr( $gateway->id ); ?>" class="form-check-label">
						<input class="form-check-input" type="radio">
						<?php echo esc_html( $gateway->get_title() ); ?>
					</label>
				</div>
				<?php endforeach; ?>
			</div>

			<ul class="payment-methods list-unstyled mb-0" id="geeks__payment-methods">
				<?php
				foreach ( $available_gateways as $gateway ) {
					learn_press_get_template(
						'checkout/payment-method.php',
						array(
							'gateway'  => $gateway,
						)
					);
				}
				?>
			</ul>
		</div>

		<?php
	}

	do_action( 'learn-press/payment-form' );
	?>

	<div id="checkout-order-action" class="place-order-action card-body mt-5 pt-0">

		<div class="row">

			<div class="col-md-4 col-12">

				<?php do_action( 'learn-press/before-checkout-submit-button' ); ?>

				<button type="submit" class="lp-button button alt btn btn-primary mb-3 mb-lg-0 me-4" name="learn_press_checkout_place_order" id="learn-press-checkout-place-order">
					<?php echo apply_filters( 'learn-press/checkout-proceed-button-text', esc_html__( 'Place order', 'geeks' ) ); ?>
				</button>

				<?php
				if ( is_user_logged_in() ) {
					wp_nonce_field( 'learn-press-user-logged', 'learn-press-checkout-nonce' );
				}
				
				?>
			</div>

			<div class="col-md-8 col-12 d-flex align-items-center justify-content-end">
				<?php do_action( 'learn-press/after-checkout-submit-button' ); ?>
			</div>
		</div>
	</div>

	<?php do_action( 'learn-press/after-payment-form' ); ?>
</div>