<?php
/**
 * Template for displaying reviewing before placing order.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/checkout/review-order.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$cart = learn_press_get_checkout_cart();
?>

<div id="checkout-order" class="lp-checkout-block right card border-0 mb-3">

	<h4 class="sr-only"><?php esc_html_e( 'Your order', 'geeks' ); ?></h4>

	<div class="lp-checkout-order__inner">
		<table class="d-block">
			<tbody class="d-block">

			<?php
			do_action( 'learn_press_review_order_before_cart_contents' );
			do_action( 'learn-press/review-order/before-cart-contents' );

			$items = $cart->get_items();

			if ( $items ) {
				foreach ( $items as $cart_item_key => $cart_item ) {
					$cart_item = apply_filters( 'learn-press/review-order/cart-item', $cart_item );
					$item_id   = $cart_item['item_id'];
					$_course   = apply_filters( 'learn-press/review-order/cart-item-product', learn_press_get_course( $item_id ), $cart_item );

					if ( $_course && 0 < $cart_item['quantity'] ) {
						?>
						<tr class="<?php echo esc_attr( apply_filters( 'learn-press/review-order/cart-item-class', 'cart-item d-block text-center pb-5 border-bottom', $cart_item, $cart_item_key ) ); ?>">
							<?php
							do_action( 'learn_press_review_order_before_cart_item', $cart_item );
							do_action( 'learn-press/review-order/before-cart-item', $cart_item, $cart_item_key );
							?>

							<td class="course-thumbnail d-block">
								<?php echo wp_kses_post( $_course->get_image( 'full', array( 'class' => 'card-img-top' ) ) ); ?>
							</td>
							<td class="course-name d-block px-5 pt-5">
								<div class="d-flex justify-content-center">
									<a href="<?php the_permalink( $item_id ); ?>" class="h3 fw-semi-bold">
										<?php echo apply_filters( 'learn-press/review-order/cart-item-name', $_course->get_title(), $cart_item, $cart_item_key ); ?>
									</a>

									<?php
									if ( $cart_item['quantity'] > 1 ) {
										echo apply_filters( 'learn-press/review-order/cart-item-quantity', ' <strong class="course-quantity align-self-end mb-1 fw-normal">' . sprintf( '&times; %s', $cart_item['quantity'] ) . '</strong>', $cart_item, $cart_item_key );
									}
									?>
								</div>
							</td>
							<td class="course-total col-number d-block">
								<div class="display-4 fw-semi-bold text-primary">
									<?php echo apply_filters( 'learn-press/review-order/cart-item-subtotal', $cart->get_item_subtotal( $_course, $cart_item['quantity'] ), $cart_item, $cart_item_key ); ?>
								</div>
							</td>

							<?php
							do_action( 'learn-press/review-order/after-cart-item', $cart_item, $cart_item_key );
							do_action( 'learn_press_review_order_after_cart_item', $cart_item );
							?>
						</tr>

						<?php
					}
				}
			}

			do_action( 'learn-press/review-order/after-cart-contents' );
			do_action( 'learn_press_review_order_after_cart_contents' );
			?>

			</tbody>

			<tfoot class="d-block p-5 fs-4">
				<tr class="cart-subtotal d-flex justify-content-between align-items-center mb-2">

					<?php do_action( 'learn-press/review-order/before-subtotal-row' ); ?>

					<th colspan="2" class="fw-medium text-dark d-block m-0"><?php esc_html_e( 'Subtotal', 'geeks' ); ?></th>
					<td class="col-number d-block"><?php echo wp_kses_post( $cart->get_subtotal() ); ?></td>

					<?php do_action( 'learn-press/review-order/after-subtotal-row' ); ?>
				</tr>

				<?php
				do_action( 'learn_press_review_order_before_order_total' );
				do_action( 'learn-press/review-order/before-order-total' );
				?>

				<tr class="order-total d-flex justify-content-between align-items-center">
					<?php do_action( 'learn-press/review-order/before-total-row' ); ?>

					<th colspan="2" class="fw-medium text-dark d-block m-0"><?php esc_html_e( 'Total', 'geeks' ); ?></th>
					<td class="col-number d-block"><?php echo wp_kses_post( $cart->get_total() ); ?></td>

					<?php do_action( 'learn-press/review-order/after-total-row' ); ?>
				</tr>

				<?php
				do_action( 'learn-press/review-order/after-order-total' );
				do_action( 'learn_press_review_order_after_order_total' );
				?>

			</tfoot>
		</table>
	</div>
</div>
