<?php
/**
 * Template for displaying user profile tabs.
 *
 * This template can be overridden by copying it to yourtheme/learnpress/profile/tabs.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$profile = LP_Profile::instance();
?>

<div id="profile-nav" class="navbar-nav flex-column">

	<?php do_action( 'learn-press/before-profile-nav', $profile ); ?>

	<ul class="lp-profile-nav-tabs list-unstyled ms-n2 mb-4">

		<?php
		/**
		 * @var LP_Profile_Tab $profile_tab
		 */
		foreach ( $profile->get_tabs()->tabs() as $tab_key => $profile_tab ) {
			if ( ! is_object( $profile_tab ) || ! $profile_tab || $profile_tab->is_hidden() || ! $profile_tab->user_can_view() ) {
				continue;
			}

			$slug        = $profile->get_slug( $profile_tab, $tab_key );
			$link        = $profile->get_tab_link( $tab_key, true );
			$tab_classes = array( esc_attr( $tab_key ), 'nav-item' );

			$sections = $profile_tab->sections();

			if ( $profile->is_current_tab( $tab_key ) && ! ( $sections && sizeof( $sections ) > 1 ) ) {
				$tab_classes[] = 'active';
			}

			if ( $sections && sizeof( $sections ) > 1 ) {
				$tab_classes[] = 'has-child';
				$tab_classes[] = 'navbar-header';
				$tab_classes[] = 'mt-4';
			}
			?>

			<?php if ( $sections && sizeof( $sections ) > 1 ) : ?>

			<li class="<?php echo esc_attr( implode( ' ', $tab_classes ) ); ?>">
				<?php echo apply_filters( 'learn_press_profile_' . $tab_key . '_tab_title', $profile_tab['title'], $tab_key ); ?>
			</li>
			
			<?php else : ?>

			<li class="<?php echo implode( ' ', $tab_classes ); ?>">
				<a href="<?php echo esc_url( $link ); ?>" data-slug="<?php echo esc_attr( $link ); ?>" class="nav-link">
					<?php
					if ( ! empty( $profile_tab['icon'] ) ) {
						echo wp_kses( $profile_tab['icon'], [ 'i' => [ 'class' => true ] ] );
					}
					?>
					<?php echo apply_filters( 'learn_press_profile_' . $tab_key . '_tab_title', $profile_tab['title'], $tab_key ); ?>
				</a>
			</li>

			<?php endif; ?>

			<?php if ( $sections && sizeof( $sections ) > 1 ) { ?>
					<?php
					foreach ( $sections as $section_key => $section_data ) {

						$classes = array( esc_attr( 'section-' . $section_key ), 'nav-item' );
						if ( $profile->is_current_section( $section_key, $section_key ) ) {
							$classes[] = 'active';
						}

						$section_slug = $profile->get_slug( $section_data, $section_key );
						$section_link = $profile->get_tab_link( $tab_key, $section_slug );
						?>

						<li class="<?php echo implode( ' ', $classes ); ?>">
							<a class="nav-link" href="<?php echo esc_url( $section_link ); ?>">
								<?php 
								if ( ! empty( $section_data['icon'] ) ) {
									echo wp_kses( $section_data['icon'], [ 'i' => [ 'class' => true ] ] );
								}
								?>
								<?php echo esc_html( $section_data['title'] ); ?>
							</a>
						</li>

					<?php } ?>
			<?php } ?>
		<?php } ?>

	</ul>

	<?php do_action( 'learn-press/after-profile-nav', $profile ); ?>

</div>
