<?php
/**
 * Template for displaying progress of single course.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$course_data       = $user->get_course_data( $course->get_id() );
$course_results    = $course_data->calculate_course_results();
$passing_condition = $course->get_passing_condition();
$quiz_false        = 0;

if ( ! empty( $course_results['items'] ) ) {
	$quiz_false = $course_results['items']['quiz']['completed'] - $course_results['items']['quiz']['passed'];
}
?>

<ul class="course-results-progress list-group list-group-flush geeks-user-time">
	<li class="items-progress list-group-item bg-transparent d-flex align-items-center px-0">
		<h5 class="mb-0 me-2 items-progress__heading">
			<?php esc_html_e( 'Lessons completed:', 'geeks' ); ?>
		</h5>
		<span class="number"><?php printf( '%1$d/%2$d', $course_results['items']['lesson']['completed'], $course_results['items']['lesson']['total'] ); ?></span>
	</li>

	<li class="items-progress list-group-item bg-transparent d-flex align-items-center px-0">
		<h5 class="mb-0 me-2 items-progress__heading">
			<?php esc_html_e( 'Quizzes finished:', 'geeks' ); ?>
		</h5>
		<span class="number" title="<?php esc_attr( sprintf( esc_html__( 'Failed %1$d, Passed %2$d', 'geeks' ), $quiz_false, $course_results['items']['quiz']['passed'] ) ); ?>"><?php printf( esc_html__( '%1$d/%2$d', 'geeks' ), $course_results['items']['quiz']['completed'], $course_results['items']['quiz']['total'] ); ?></span>
	</li>

	<?php do_action( 'learn-press/user-item-progress' ); ?>

	<li class="course-progress list-group-item bg-transparent border-bottom-0 d-flex align-items-center flex-wrap m-0 justify-content-between flex-row geeks-course-progress px-0 pb-0">
		<h5 class="mb-0 me-2 items-progress__heading">
			<?php esc_html_e( 'Course progress:', 'geeks' ); ?>
		</h5>

		<div class="lp-course-status">
			<span class="number"><?php echo round( $course_results['result'], 2 ); ?><span class="percentage-sign">%</span></span>
		</div>

		<div class="learn-press-progress lp-course-progress <?php echo esc_attr($course_data->is_passed() ? ' passed' : ''); ?>" data-value="<?php echo esc_attr( $course_results['result'] ); ?>" data-passing-condition="<?php echo esc_attr( $passing_condition ); ?>" title="<?php echo esc_attr( learn_press_translate_course_result_required( $course ) ); ?>">
			<div class="progress-bg lp-progress-bar">
				<div class="progress-active lp-progress-value" style="left: <?php echo esc_attr( $course_results['result'] ); ?>%;">
				</div>
			</div>
			<div class="lp-passing-conditional" data-content="<?php printf( esc_html__( 'Passing condition: %s%%', 'geeks' ), $passing_condition ); ?>" style="left: <?php echo esc_attr( $passing_condition ); ?>%;">
			</div>
		</div>
	</li>

</ul>
