<?php
/**
 * The loop template file.
 *
 * Included on pages like index.php, archive.php and search.php to display a loop of posts
 * Learn more: https://codex.wordpress.org/The_Loop
 *
 * @package geeks
 */
$layout              = geeks_get_blog_layout();
$has_sidebar         = geeks_blog_has_sidebar();
$show_masonry        = geeks_posts_masonry_enabled();
$is_sticky_fullwidth = geeks_is_sticky_fullwidth();

if ( $has_sidebar ) {
	$content_classes = 'col-lg-6 col-md-12 col-12';
	$main_class      = 'col-lg-8 col-md-7 col-12';
	$sidebar_class   = 'col-lg-4 col-md-5 col-12 mt-6 mt-md-0';

	if( 'left-sidebar' === $layout ) {
		$main_class    .= ' order-md-2';
		$sidebar_class .= ' order-md-1';
	}
} else {
	$content_classes = 'grid-item col-xl-4 col-lg-4 col-md-6 col-12';
}

?>
<div class="loop-content pb-12">
	<?php do_action( 'geeks_loop_before' ); ?>
	<div class="container">
		
		<?php if ( $has_sidebar ) : ?>
		<div class="row">
			<div class="<?php echo esc_attr( $main_class ); ?>">
		<?php endif; ?>
		
		<?php do_action( 'geeks_loop_content_before' ); ?>
		
		<div class="row" data-masonry='{"percentPosition": true }'>
			<?php
			$index = 0;
			while ( have_posts() ) :
				the_post();

				if ( 0 === $index && is_sticky() && is_home() && ! is_paged() && ! $has_sidebar && $is_sticky_fullwidth ) :
					?>
				<article id="post-<?php the_ID(); ?>" <?php post_class( array( 'col-xl-12', 'col-lg-12', 'col-md-12', 'col-12' ) ); ?>>
					<?php get_template_part( 'content', 'sticky' ); ?>
				</article>

				</div>

				<div class="row" data-masonry='{"percentPosition": true }'>

				<?php else: ?>

				<article id="post-<?php the_ID(); ?>" <?php post_class( $content_classes ); ?>>
				<?php
				/**
				 * Include the Post-Format-specific template for the content.
				 * If you want to override this in a child theme, then include a file
				 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
				 */
				get_template_part( 'content', get_post_format() );

				?>
				</article>
				<?php 
				endif;
			
			$index++;

			endwhile;
			?>
		</div><!-- /.row -->
		
		<?php
			/**
			 * Functions hooked in to geeks_paging_nav action
			 *
			 * @hooked geeks_paging_nav - 10
			 */
		do_action( 'geeks_loop_content_after' );
		?>

		<?php if ( $has_sidebar ) : ?>
			</div><!-- .col-lg-8 -->
			<div class="<?php echo esc_attr( $sidebar_class ); ?>">
				<?php get_sidebar(); ?>
			</div>
		</div><!-- .row -->
		<?php endif; ?>

	</div><!-- /.container -->
	<?php do_action( 'geeks_loop_after' ); ?>
</div><!-- /.loop-content -->
