<?php
/**
 * Display Curriculum module for the lead course.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

$modal_id = 'course-module-' . $module_id;

?>
<div class="card mb-4">
	<!-- Card body -->
	<div class="card-body p-6">
		<div class="curriculum-module__header d-md-flex mb-4">
			<?php if ( isset( $module_thumbnail ) && $module_thumbnail ) : ?>
			<div class="curriculum-module__thumbnail mb-3 mb-md-0 me-md-4">
				<!-- Img -->
				<img src="<?php echo esc_url( $module_thumbnail ); ?>" alt="<?php echo esc_attr( $module_title ); ?>" class=" bg-primary icon-shape icon-xxl rounded-circle">
			</div>
			<?php endif; ?>
			<!-- Content -->
			<div class="curriculum-module__header-content">
				<h2 class="fw-bold mb-1"><?php echo esc_html( $module_title ); ?>
					<?php if ( $module_is_free ) : ?>
					<span class="badge bg-warning ms-2"><?php echo esc_html__( 'Free', 'geeks' ); ?></span><?php endif; ?></h2>
				<?php if ( ! empty( $module_meta ) ) : ?>
				<p class="text-uppercase fs-6 fw-semi-bold mb-0">
					<?php
					foreach ( $module_meta as $meta ) :
						$meta_class = isset( $meta['class'] ) ? $meta['class'] : '';
						$meta_class = trim( $meta_class . ' me-3' );
						?>
					<span class="<?php echo esc_attr( $meta_class ); ?>"><?php echo esc_html( $meta['text'] ); ?></span>
					<?php endforeach; ?>
				</p>
				<?php endif; ?>
			</div>
		</div>
		<?php if ( ! empty( $module_excerpt ) ) : ?>
		<div class="curriculum-module__short-desc mb-4 fs-4 mb-0-last-child"><?php echo wp_kses_post( $module_excerpt ); ?></div>
		<?php endif; ?>
		<?php if ( $module_lessons->have_posts() ) : ?>
		<a href="<?php echo esc_url( $course_url ); ?>" class="btn-link stretched-link" data-bs-toggle="modal" data-bs-target="#<?php echo esc_attr( $modal_id ); ?>"><?php echo esc_html__( 'View Chapter Details', 'geeks' ); ?> <i class="fe fe-plus"></i></a>
		<?php endif; ?>
	</div>
</div>
<div class="modal fade" id="<?php echo esc_attr( $modal_id ); ?>" tabindex="-1" style="display: none;" aria-hidden="true">
	<div class="modal-dialog modal-dialog-centered modal-lg">
		<div class="modal-content">
			<div class="modal-header py-4 align-items-lg-center">
				<div class="d-lg-flex">
					<?php if ( isset( $module_thumbnail ) && $module_thumbnail ) : ?>
					<div class="me-lg-4 mb-3 mb-lg-0">
						<img src="<?php echo esc_url( $module_thumbnail ); ?>" alt="<?php echo esc_attr( $module_title ); ?>" class=" bg-primary icon-shape icon-xxl rounded-circle">
					</div>
					<?php endif; ?>
					<div>
						<h2 class="fw-bold mb-1"><?php echo esc_html( $module_title ); ?>
							<?php if ( $module_is_free ) : ?>
							<span class="badge bg-warning ms-2"><?php echo esc_html__( 'Free', 'geeks' ); ?></span><?php endif; ?></h2>
						<?php if ( ! empty( $module_meta ) ) : ?>
						<p class="text-uppercase fs-6 fw-semi-bold mb-0">
							<?php
							foreach ( $module_meta as $meta ) :
								$meta_class = isset( $meta['class'] ) ? $meta['class'] : '';
								$meta_class = trim( $meta_class . ' me-3' );
								?>
							<span class="<?php echo esc_attr( $meta_class ); ?>"><?php echo esc_html( $meta['text'] ); ?></span>
							<?php endforeach; ?>
						</p>
						<?php endif; ?>
					</div>
				</div>
				<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
			</div>
			<div class="modal-body">
				<h3><?php echo esc_html__( 'In this module you’ll learn:', 'geeks' ); ?></h3>
				<?php if ( ! empty( $module_excerpt ) ) : ?>
				<div class="mb-3 fs-4"><?php echo wp_kses_post( $module_excerpt ); ?></div>
				<?php endif; ?>
				<ul class="list-group list-group-flush">
					<!-- List group item -->
					<?php
					while ( $module_lessons->have_posts() ) :
						$module_lessons->the_post();
						global $post;

						$play_time    = geeks_tutor_get_lesson_play_time();
						$lesson_icon  = geeks_tutor_get_lesson_icon( $post->post_type );
						$lesson_icon .= ' fs-4';
						?>
					<li class="list-group-item ps-0">
						<a href="<?php echo esc_url( $course_url ); ?>" class="d-flex justify-content-between align-items-center text-inherit text-decoration-none">
							<div class="text-truncate">
								<span class="icon-shape bg-light text-primary icon-sm rounded-circle me-2"><i class="<?php echo esc_attr( $lesson_icon ); ?>"></i></span>
								<span><?php the_title(); ?></span>
							</div>
							<?php if ( $play_time && '0s' !== $play_time ) : ?>
							<div class="text-truncate">
								<span><?php echo esc_html( $play_time ); ?></span>
							</div>
							<?php endif; ?>
						</a>
					</li>
						<?php
					endwhile;
					$module_lessons->reset_postdata();
					?>
				</ul>
			</div>
		</div>
	</div>
</div>
