<?php
/**
 * Display Course General Info Fields.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

?><div class="tutor-course-builder-section tutor-course-builder-info tutor-course-builder-general-info card mb-3">
    <div class="tutor-course-builder-section-title card-header border-bottom px-4 py-3">
        <h4 class="mb-0"><?php esc_html_e( 'Course Info', 'geeks' ); ?></h4>
    </div>

    <div class="tutor-course-builder-section-content card-body">

        <div class="mb-3">
            <label for="courseTitle" class="form-label"><?php esc_html_e( 'Course Title', 'geeks' ); ?></label>
            <input id="courseTitle" class="form-control" type="text" name="title" value="<?php echo get_the_title(); ?>" placeholder="<?php esc_attr_e( 'ex. Learn photoshop CS6 from scratch', 'geeks' ); ?>">
        </div>

        <div class="mb-3">
            <label class="form-label"><?php esc_html_e( 'Courses category', 'geeks' ); ?></label>
            <div class="create-course__tutor-categories">
                <?php echo tutor_course_categories_dropdown( $course_id, array( 'classes' => 'tutor_select2' ) ); ?>
            </div>
            <small><?php esc_html_e( 'Help people find your courses by choosing categories that represent your course.', 'geeks' ); ?></small>
        </div>

        <div class="mb-3">
            <label class="form-label"><?php esc_html_e( 'Courses tag', 'geeks' ); ?></label>
            <div class="create-course__tutor-tags">
                <?php echo tutor_course_tags_dropdown( $course_id, array( 'classes' => 'tutor_select2' ) ); ?>
            </div>
            <small><?php esc_html_e( 'Help people find your courses by choosing tag that represent your course.', 'geeks' ); ?></small>
        </div>

        <div class="mb-3">
            <label class="form-label"><?php esc_html_e( 'Course Description', 'geeks' ); ?></label><?php

            $editor_settings = array(
                'media_buttons' => false,
                'quicktags'     => false,
                'editor_height' => 150,
                'textarea_name' => 'content'
            );

            wp_editor( $post->post_content, 'course_description', $editor_settings );

            ?><small><?php esc_html_e( 'A brief summary of your courses.', 'geeks' ); ?></small>
        </div>

        <?php do_action( 'tutor/frontend_course_edit/after/description', $post ); ?>
        

        <?php
        $monetize_by = tutils()->get_option('monetize_by');
        if ( $monetize_by === 'wc' || $monetize_by === 'edd' ) :
            $course_price = tutor_utils()->get_raw_course_price(get_the_ID());
            $currency_symbol = tutor_utils()->currency_symbol();

            $_tutor_course_price_type = tutils()->price_type();
        ?>
            <div class="mb-3">
                <label class="form-label"><?php esc_html_e( 'Course Price', 'geeks' ); ?></label>
                <div class="row align-items-center">
                    <div class="col-12 col-md-auto mb-3 mb-md-0">
                        <div class="form-check d-flex align-items-center">
                            <input id="tutor_course_price_type_paid" class="form-check-input me-2" type="radio" name="tutor_course_price_type" value="paid" <?php checked( $_tutor_course_price_type, 'paid' ); ?>>
                            <label class="form-check-label" for="tutor_course_price_type_paid">
                                <div class="input-group">
                                    <span class="input-group-text"><?php echo esc_html( $currency_symbol ); ?></span>
                                    <input type="text" class="w-auto form-control" name="course_price" value="<?php echo esc_attr( $course_price->regular_price ); ?>" placeholder="<?php esc_attr_e( 'Set course price', 'geeks' ); ?>">
                                </div>
                            </label>
                        </div>
                        
                    </div>
                    <div class="col-12 col-md-auto">
                        <div class="form-check">
                            <input id="tutor_course_price_type_free" type="radio" name="tutor_course_price_type" class="form-check-input" value="free" <?php $_tutor_course_price_type ? checked( $_tutor_course_price_type, 'free' ) : checked( 'true', 'true' ); ?>>
                            <label class="form-check-label" for="tutor_course_price_type_paid"><?php esc_html_e( 'Free', 'geeks' ); ?></label>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <div class="mb-3">
            <label class="form-label"><?php esc_html_e( 'Course Thumbnail', 'geeks' ); ?></label>
            <div class="tutor-input-group tutor-mb-15">
                <?php
                tutor_load_template_from_custom_path(
                    tutor()->path . '/views/fragments/thumbnail-uploader.php',
                    array(
                        'media_id'    => get_post_thumbnail_id($course_id),
                        'input_name'  => 'tutor_course_thumbnail_id',
                        'placeholder' => tutor()->url . '/assets/images/thumbnail-placeholder.svg',
                        'borderless'  => true,
                        'background'  => '#E3E6EB',
                        'border'      => '#E3E6EB',
                    ),
                    false
                );
                ?>
            </div>

        </div>

    </div>
</div>