<?php
/**
 * Template for displaying Announcements
 *
 * @package Tutor\Templates
 * @subpackage Dashboard
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.7.9
 */

use TUTOR\Input;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$per_page = 10;
$paged    = max( 1, Input::get( 'current_page', 1, Input::TYPE_INT ) );

$order_filter  = Input::get( 'order', 'DESC' );
$search_filter = Input::get( 'search', '' );

// Announcement's parent.
$course_id   = Input::get( 'course-id', '' );
$date_filter = Input::get( 'date', '' );

$year  = date( 'Y', strtotime( $date_filter ) );
$month = date( 'm', strtotime( $date_filter ) );
$day   = date( 'd', strtotime( $date_filter ) );

$args = array(
	'post_type'      => 'tutor_announcements',
	'post_status'    => 'publish',
	's'              => sanitize_text_field( $search_filter ),
	'post_parent'    => sanitize_text_field( $course_id ),
	'posts_per_page' => sanitize_text_field( $per_page ),
	'paged'          => sanitize_text_field( $paged ),
	'orderBy'        => 'ID',
	'order'          => sanitize_text_field( $order_filter ),

);
if ( ! empty( $date_filter ) ) {
	$args['date_query'] = array(
		array(
			'year'  => $year,
			'month' => $month,
			'day'   => $day,
		),
	);
}
if ( ! current_user_can( 'administrator' ) ) {
	$args['author'] = get_current_user_id();
}
$the_query = new WP_Query( $args );

// get courses
$courses    = ( current_user_can( 'administrator' ) ) ? tutils()->get_courses() : tutils()->get_courses_by_instructor();
$image_base = tutor()->url . '/assets/images/';
?>

<div class="tutor-dashboard-content-inner tutor-frontend-dashboard-withdrawal mb-4">
	<div class="card mb-4">
		<div class="card-body">
			<h4 class="mb-0"><?php echo esc_html__( 'Announcement', 'geeks' ); ?></h4>
		</div>
	</div>
	<!--notice-->
	<div class="card">
		<div class="withdraw-page-current-balance new-announcement-wrap card-body">
			<div class="d-lg-flex justify-content-between align-items-center">
				<div class="balance-info new-announcement-content d-md-flex align-items-center">

					<div class="tutor-announcement-big-icon icon-shape icon-xxl rounded-circle bg-light-primary text-center mr-2 mb-3 mb-md-0">
						<i class="fs-3 tutor-icon-bullhorn text-dark-primary"></i>
					</div>
					<div class="ms-md-4">
						<small><?php esc_html_e( 'Create Announcement', 'geeks' ); ?></small>
						<p class="mb-0 h4">
							<strong>
								<?php esc_html_e( 'Notify all students of your course', 'geeks' ); ?>
							</strong>
						</p>
					</div>
				</div>
				<div class="mt-3 mt-lg-0 new-announcement-button">
					<button type="button" class="btn btn-primary tutor-btn tutor-announcement-add-new" data-bs5-toggle="modal" data-bs5-target="#createAnnouncement" data-tutor-modal-target="tutor_announcement_new">
						<?php esc_html_e( 'Add New Announcement', 'geeks' ); ?>
					</button>
				</div>
			</div>
		</div>
	</div>
	<!--notice end-->

</div>

<!--sorting-->
<div class="card shadow-none">
	<div class="card-header">
		<div class="tutor-dashboard-announcement-sorting-wrap row align-items-center geeks-announcement-sorting-wrap">
			<div class="tutor-form-group col-lg-5 col-md-6 pr-md-0 mb-2 mb-lg-0">
				<label class="form-label d-block">
					<?php esc_html_e( 'Courses', 'geeks' ); ?>
				</label>
				<select class="tutor-report-category tutor-announcement-course-sorting ignore-nice-select border rounded w-100">
				   
					<option value=""><?php esc_html_e( 'All', 'geeks' ); ?></option>
				
					<?php if ( $courses ) : ?>
						<?php foreach ( $courses as $course ) : ?> 
							<option value="<?php echo esc_attr( $course->ID ); ?>" <?php selected( $course_id, $course->ID, 'selected' ); ?>>
								<?php echo esc_html( $course->post_title ); ?>
							</option>
						<?php endforeach; ?>
					<?php else : ?>
						<option value=""><?php esc_html_e( 'No course found', 'geeks' ); ?></option>
					<?php endif; ?>
				</select>
			</div>

			<div class="tutor-form-group col-lg-3 col-md-6 pr-md-0 mb-2 mb-2 mb-lg-0">
				<label class="form-label d-block"><?php esc_html_e( 'Sort By', 'geeks' ); ?></label>
				<select class="tutor-announcement-order-sorting ignore-nice-select border rounded w-100">
					<option <?php selected( $order_filter, 'ASC' ); ?>><?php esc_html_e( 'ASC', 'geeks' ); ?></option>
					<option <?php selected( $order_filter, 'DESC' ); ?>><?php esc_html_e( 'DESC', 'geeks' ); ?></option>
				</select>
			</div>

			<div class="tutor-form-group tutor-announcement-datepicker col-lg-4 col-md-6 pr-md-0 mb-2 mb-2 mb-lg-0">
				<label class="form-label"><?php esc_html_e( 'Date', 'geeks' ); ?></label>
				 <div class="input-group">
					<input type="text" class="form-control text-dark flatpickr tutor-announcement-date-sorting" id="tutor-announcement-datepicker" value="<?php echo esc_attr( $date_filter ); ?>" autocomplete="off" placeholder="<?php echo date( 'Y-m-d' ); ?>"/>

					<span class="input-group-text text-muted"><i class="fe fe-calendar"></i></span>
				</div>
			</div>
		</div>
	</div>
	<!--sorting end-->
</div>

	
<?php
	$announcements = $the_query->have_posts() ? $the_query->posts : array();

	tutor_load_template_from_custom_path(
		tutor()->path . '/views/fragments/announcement-list.php',
		array(
			'announcements' => is_array( $announcements ) ? $announcements : array(),
			'the_query'     => $the_query,
			'paged'         => $paged,
		)
	);
	?>
	

