<?php
/**
 * Frontend course create template
 *
 * @package Tutor\Templates
 * @subpackage Dashboard
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $post;
use TUTOR\Input;

get_header();

do_action( 'tutor_load_template_before', 'dashboard.create-course', null );

$course_id = Input::get( 'course_ID', 0, Input::TYPE_INT );
$post      = get_post( $course_id );//phpcs:ignore
if ( ! $course_id || tutor()->course_post_type != get_post_type( $post) ) {
	return;
}
setup_postdata( $post );
$can_publish_course = (bool) tutor_utils()->get_option('instructor_can_publish_course') || current_user_can('administrator');
?>
<?php
if (!tutor_utils()->is_instructor(get_current_user_id(), true) || !tutor_utils()->can_user_edit_course(get_current_user_id(), $course_id)) {
	$args = array(
		'headline'    => esc_html__('Permission Denied', 'geeks'),
		'message'     => esc_html__('You don\'t have the right to edit this course', 'geeks'),
		'description' => esc_html__('Please make sure you are logged in to correct account', 'geeks'),
		'button'      => array(
			'url'  => get_permalink($course_id),
			'text' => esc_html__('View Course', 'geeks'),
		),
	);

	//tutor_load_template('permission-denied', $args);
	tutor_load_template_from_custom_path(__DIR__.'/permission-denied.php');

	return;
}

do_action('tutor/dashboard_course_builder_before');

$title = apply_filters( 'geeks_tutor_create_course_title', esc_html__( 'Add New Course', 'geeks' ) );
$desc  = apply_filters( 'geeks_tutor_create_course_desc', esc_html__( 'Just fill the form and create your courses.', 'geeks' ) );

?>	
<form action="" id="tutor-frontend-course-builder" method="post" enctype="multipart/form-data">
	<?php 
		wp_nonce_field(tutor()->nonce_action, tutor()->nonce);
		if ( $post->post_status === 'draft' ) { 
	?>
		<input name="original_publish" type="hidden" id="original_publish" value="Publish">
	<?php } ?>

	<div class="py-4 py-lg-6 bg-primary">
		<div class="container">
			<div class="row">
				<div class="offset-lg-1 col-lg-10 col-md-12 col-12">
					<div class="d-lg-flex align-items-center justify-content-between">
						<!-- Content -->
						<div class="mb-4 mb-lg-0">
							<?php if ( $title ) : ?>
								<h1 class="text-white mb-1"><?php echo esc_html( $title ); ?></h1>
							<?php endif; ?>

							<?php if ( $desc ) : ?>
								<p class="mb-0 text-white lead"><?php echo esc_html( $desc ); ?></p>
							<?php endif; ?>
						</div>
						<div>
							<a href="<?php echo tutor_utils()->tutor_dashboard_url(); ?>" class="btn btn-white"><?php esc_html_e( 'Back to Course', 'geeks' ); ?></a>
							
							<?php if ( 'draft' === $post->post_status || 'auto-draft' === $post->post_status ) : ?>
							<a href="#" type="button" id="tutor-course-save-draft" class="d-inline-block btn shadow-none btn-success tutor-btn tutor-mr-20" name="course_submit_btn" value="save_course_as_draft">
								<i class="tutor-icon-save-line tutor-mr-8" area-hidden="true"></i>
								<?php esc_html_e('Save', 'geeks'); ?>
							</a>
						<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>

	<div class="pb-12">
		<div class="container">
			<div id="courseForm" class="bs-stepper create-course">
				<div class="row">
					<div class="offset-lg-1 col-lg-10 col-md-12 col-12">
						<input type="hidden" value="tutor_add_course_builder" name="tutor_action" />
						<input type="hidden" name="course_ID" id="course_ID" value="<?php echo get_the_ID(); ?>">
						<input type="hidden" name="post_ID" id="post_ID" value="<?php echo get_the_ID(); ?>">

						<div class="tutor-frontend-course-builder-section p-0 bg-transparent">
							<div class="bs-stepper-header shadow-sm overflow-auto" role="tablist">
								<div class="step" data-target="#course-general-info">
									<button type="button" class="step-trigger" role="tab" id="course-general-info-tigger" aria-controls="course-general-info">
										<span class="bs-stepper-circle"><?php echo esc_html( '1' ); ?></span>
										<span class="bs-stepper-label"><?php esc_html_e( 'Course Info', 'geeks' ); ?></span>
									</button>
								</div>
							</div>

							<?php
								$user_id = get_current_user_id();
								$expires = get_user_meta( $user_id, 'tutor_frontend_course_message_expires', true );
								$message = get_user_meta( $user_id, 'tutor_frontend_course_action_message', true );

								if ($message && $expires && $expires > time()) {
								$show_modal = $message['show_modal'];
								$message    = $message['message'];

									if (!$show_modal) {
									?>
										<div class="alert alert-info mt-4">
											<?php echo wp_kses_post( $message ); ?>
										</div>
									<?php } else { ?>
										<!-- @todo: move to toast -->
										<div id="modal-course-save-feedback" class="tutor-modal tutor-is-active">
											<span class="tutor-modal-overlay"></span>
											<div class="tutor-modal-window tutor-modal-window-md">
												<div class="tutor-modal-content tutor-modal-content-white">
													<button class="tutor-iconic-btn tutor-modal-close-o" data-tutor-modal-close>
														<span class="tutor-icon-times" area-hidden="true"></span>
													</button>

													<div class="tutor-modal-body tutor-text-center">
														<div class="tutor-py-48">
															<img class="tutor-d-inline-block" src="<?php echo tutor()->url; ?>assets/images/icon-cup.svg" />
															<div class="tutor-fs-3 tutor-fw-medium tutor-color-black tutor-mb-12"><?php _e('Thank You!', 'geeks'); ?></div>
															<div class="tutor-fs-6 tutor-color-muted"><?php echo $message; ?></div>
														</div>
													</div>
												</div>
											</div>
										</div>
										<script>
											const alertBox = document.getElementById('modal-course-save-feedback');
											setTimeout(() => {
												if (alertBox) alertBox.classList.remove('tutor-is-active');
											}, 5000)
										</script>
									<?php
								}
							}

								if ( $message || $expires ) {
									delete_user_meta( $user_id, 'tutor_frontend_course_message_expires' );
									delete_user_meta( $user_id, 'tutor_frontend_course_action_message' );
								}
							?>

							<div class="bs-stepper-content tutor-course-builder-section-content mt-5 d-flex flex-column">
								<div id="course-general-info" role="tabpanel" class="bs-stepper-pane fade" aria-labelledby="course-general-info-tigger"><?php
									
									$general_info_content_args = array(
										'post'      => $post,
										'course_id' => $course_id,
									);
									
									geeks_get_template( 'create-course/general-info-content.php', $general_info_content_args );

								?></div>
								
								<?php do_action( 'tutor/dashboard_course_builder_form_field_after', $post ); ?>
							</div>

							<div class="accordion mb-3" id="course_upload_tips">
								<div class="accordion-item">
									<h2 class="accordion-header" id="course_tips">
										<button class="accordion-button collapsed fw-bold" type="button" data-bs-toggle="collapse" data-bs-target="#course_tips_item" aria-expanded="false" aria-controls="course_tips_item"><i class="tutor-icon-light-bulb me-2"></i><?php esc_html_e( 'Course Upload Tips', 'geeks' ); ?></button>
									</h2>
									<div id="course_tips_item" class="accordion-collapse collapse" aria-labelledby="course_tips" data-bs-parent="#course_upload_tips">
										<div class="accordion-body">
										<ol class="list-group list-group-numbered">
											<li class="list-group-item"><?php esc_html_e( 'Set the Course Price option or make it free.', 'geeks' ); ?></li>
											<li class="list-group-item"><?php esc_html_e( 'Standard size for the course thumbnail is 700x430.', 'geeks' ); ?></li>
											<li class="list-group-item"><?php esc_html_e( 'Video section controls the course overview video.', 'geeks' ); ?></li>
											<li class="list-group-item"><?php esc_html_e( 'Course Builder is where you create & organize a course.', 'geeks' ); ?></li>
											<li class="list-group-item"><?php esc_html_e( 'Add Topics in the Course Builder section to create lessons, quizzes, and assignments.', 'geeks' ); ?></li>
											<li class="list-group-item"><?php esc_html_e( 'Prerequisites refers to the fundamental courses to complete before taking this particular course.', 'geeks' ); ?></li>
											<li class="list-group-item"><?php esc_html_e( 'Information from the Additional Data section shows up on the course single page.', 'geeks' ); ?></li>
										</ol>
										</div>
									</div>
								</div>
							</div>
							
							<div class="text-end">
								<a href="<?php the_permalink($course_id); ?>" class="btn btn-primary" target="_blank"><?php esc_html_e( 'Preview', 'geeks' ); ?></a>
								<?php if ( $can_publish_course ) : ?>
									<button class="tutor-btn btn btn-danger tutor-static-loader" type="submit" name="course_submit_btn" value="publish_course"><?php esc_html_e( 'Publish Course', 'geeks' ); ?></button>
								<?php else: ?>
									<button class="btn btn-danger" type="submit" name="course_submit_btn" value="submit_for_review"><?php esc_html_e( 'Submit for Review', 'geeks' ); ?></button>
								<?php endif; ?>
							</div>
						</div>	

					</div>
				</div>
			</div>
		</div>
	</div>

</form><?php

do_action('tutor/dashboard_course_builder_after');

do_action( 'tutor_load_template_after', 'dashboard.create-course', null );

get_footer();