<?php
/**
 * Frontend Dashboard Template
 *
 * @package Tutor\Templates
 * @subpackage Dashboard
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

use Tutor\Models\CourseModel;
use Tutor\Models\WithdrawModel;

if ( tutor_utils()->get_option( 'enable_profile_completion' ) ) {
	$profile_completion = tutor_utils()->user_profile_completion();
	$is_instructor      = tutor_utils()->is_instructor(null, true);
	$total_count        = count( $profile_completion );
	$incomplete_count   = count(
		array_filter(
			$profile_completion,
			function( $data ) {
				return ! $data['is_set'];
			}
		)
	);
	$complete_count     = $total_count - $incomplete_count;

	if ( $is_instructor ) {
		if ( isset( $total_count ) && isset( $incomplete_count ) && $incomplete_count <= $total_count ) {
			?>
			<div class="card mb-4">
				<div class="profile-completion card-body">
					<div class="tutor-bs-row row tutor-bs-align-items-center">
						<div class="tutor-bs-col-lg-7 col-lg-7 profile-completion-content <?php echo tutor_utils()->is_instructor() ? 'tutor-profile-completion-content-admin' : ''; ?>">
							<div class="list-item-title tutor-text-medium-h6 tutor-color-text-primary">
								<?php esc_html_e( 'Complete Your Profile', 'geeks' ); ?>
							</div>
							
							<div class="tutor-row tutor-align-center tutor-mt-12">
								<div class="tutor-col">
									<div class="tutor-row tutor-gx-1">
										<?php for ( $i = 1; $i <= $total_count; $i++ ) : ?>
											<div class="tutor-col">
												<div class="tutor-progress-bar" style="--tutor-progress-value: <?php echo $i > $complete_count ? 0 : 100; ?>%; height: 8px;"><div class="tutor-progress-value" area-hidden="true"></div></div>
											</div>
										<?php endfor; ?>
									</div>
								</div>

								<div class="tutor-col-auto">
									<span class="tutor-round-box tutor-my-n20">
										<i class="tutor-icon-trophy" area-hidden="true"></i>
									</span>
								</div>
							</div>
							<div class="list-item-title tutor-fs-6 tutor-mt-20">
								<?php
									$profile_complete_text = "Please complete profile";
									if($complete_count > ( $total_count / 2 ) && $complete_count < $total_count) {
										$profile_complete_text = 'You are almost done';
									} else if($complete_count === $total_count) {
										$profile_complete_text = 'Thanks for completing your profile';
									}
									$profile_complete_status = esc_html_e($profile_complete_text, 'geeks');

								?>
								<span class="tutor-color-muted"><?php $profile_complete_status ?></span>:&nbsp;
								<span class="tutor-color-black">
									<?php echo $complete_count . '/' . $total_count; ?>
								</span>
							</div>
						</div>
						<div class="tutor-col-lg-1 col-lg-1 tutor-text-center tutor-my-24 tutor-my-lg-n24">
							<div class="tutor-vr tutor-d-none tutor-d-lg-inline-flex"></div>
							<div class="tutor-hr tutor-d-flex tutor-d-lg-none"></div>
						</div>

						<div class="tutor-col-lg-4 col-lg-4 tutor-d-flex tutor-flex-column tutor-justify-center">
							<?php
							$i = 0;
							$monetize_by = tutils()->get_option( 'monetize_by' );
							foreach ( $profile_completion as $key => $data ) {
								if ( '_tutor_withdraw_method_data' === $key ) {
									if ( 'free' === $monetize_by ) {
										continue;
									}
								}
								$is_set = $data['is_set']; // Whether the step is done or not
								?>
									<div class="tutor-d-flex tutor-align-center<?php echo $i < (count($profile_completion) - 1) ? ' tutor-mb-8' : ''; ?>">
										<?php if ( $is_set ) : ?>
											<span class="tutor-icon-circle-mark-line text-success tutor-mr-8"></span>
										<?php else : ?>
											<span class="tutor-icon-circle-times-line text-warning tutor-mr-8"></span>
										<?php endif; ?>

										<span class="<?php echo $is_set ? 'text-secondary' : 'text-muted'; ?>">
											 <a class="tutor-btn tutor-btn-ghost tutor-has-underline" href="<?php echo esc_url( $data['url'] ); ?>">
	                                            <?php echo esc_html( $data['text'] ); ?>
	                                        </a>
										</span>
									</div>
									<?php
									$i++;
							}
							?>
						</div>
					</div>
				</div>
			</div>
			<?php
		}
	} else {
		if ( ! $profile_completion['_tutor_profile_photo']['is_set'] ) {
			$alert_message = sprintf(
				'<div class="tutor-alert tutor-primary">
			<div class="tutor-alert-text">
				<span class="tutor-alert-icon tutor-icon-34 tutor-icon-circle-outline-info-filled tutor-mr-10"></span>
				<span>
					%s
				</span>
			</div>
			<div class="tutor-alert-btns">
				<div class="alert-btn-group">
					<a href="%s" class="tutor-btn tutor-btn-sm">'.__('Click Here', 'geeks').'</a>
				</div>
			</div>
		</div>',
				$profile_completion['_tutor_profile_photo']['text'],
				tutor_utils()->tutor_dashboard_url( 'settings' )
			);

			echo wp_kses_post( $alert_message );
			// echo '<div class="tutor-alert tutor-warning">
			// <div class="tutor-alert-text">
			// <span class="tutor-alert-icon tutor-icon-34 tutor-icon-circle-outline-info-filled tutor-mr-10"></span>
			// <span>
			// {$profile_completion["_tutor_profile_photo"]["label_html"]}
			// </span>
			// </div>
			// <div class="tutor-alert-btns">
			// <span class="tutor-alert-close tutor-icon-28 tutor-color-black-40 tutor-icon-cross-filled"></span>
			// </div>
			// </div>';

		}
	}
}
?>
<div class="tutor-dashboard-content-inner">

	<?php
	$user_id		   = get_current_user_id();
	$enrolled_course   = tutor_utils()->get_enrolled_courses_by_user();
	$completed_courses = tutor_utils()->get_completed_courses_ids_by_user();
	$total_students    = tutor_utils()->get_total_students_by_instructor( $user_id );
	$my_courses        = tutor_utils()->get_courses_by_instructor( $user_id, CourseModel::STATUS_PUBLISH );
	$earning_sum       = WithdrawModel::get_withdraw_summary( $user_id );
	$active_courses	   = tutor_utils()->get_active_courses_by_user( $user_id );

	$enrolled_course_count                          = $enrolled_course ? $enrolled_course->post_count : 0;
	$completed_course_count                         = count( $completed_courses );
	$active_course_count		= is_object( $active_courses ) && $active_courses->have_posts() ? $active_courses->post_count : 0;

	?>

	<div class="tutor-dashboard-info-cards row row-cols-lg-3 row-cols-md-1 row-cols-1">
		<div class="col">
			<div class="tutor-dashboard-info-card card mb-4">
				<p class="mb-0 p-4">
					<span class="fs-6 text-uppercase fw-semi-bold"><?php echo esc_html__( 'Enrolled Courses', 'geeks' ); ?></span>
					<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo esc_html( $enrolled_course_count ); ?></span>
				</p>
			</div>
		</div>
		<div class="col">
			<div class="tutor-dashboard-info-card card mb-4">
				<p class="mb-0 p-4">
					<span class="fs-6 text-uppercase fw-semi-bold"><?php echo esc_html__( 'Active Courses', 'geeks' ); ?></span>
					<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo esc_html( $active_course_count ); ?></span>
				</p>
			</div>
		</div>
		<div class="col">
			<div class="tutor-dashboard-info-card card mb-4">
				<p class="mb-0 p-4">
					<span class="fs-6 text-uppercase fw-semi-bold"><?php echo esc_html__( 'Completed Courses', 'geeks' ); ?></span>
					<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo esc_html( $completed_course_count ); ?></span>
				</p>
			</div>
		</div>

		<?php if ( current_user_can( tutor()->instructor_role ) ) : ?>
		<div class="col">
			<div class="tutor-dashboard-info-card card mb-4">
				<p class="mb-0 p-4">
					<span class="fs-6 text-uppercase fw-semi-bold"><?php echo esc_html__( 'Total Students', 'geeks' ); ?></span>
					<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo esc_html( $total_students ); ?></span>
				</p>
			</div>
		</div>
		<div class="col">
			<div class="tutor-dashboard-info-card card mb-4">
				<p class="mb-0 p-4">
					<span class="fs-6 text-uppercase fw-semi-bold"><?php echo esc_html__( 'Total Courses', 'geeks' ); ?></span>
					<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo esc_html( count( $my_courses ) ); ?></span>
				</p>
			</div>
		</div>
		<div class="col">
			<div class="tutor-dashboard-info-card card mb-4">
				<p class="mb-0 p-4">
					<span class="fs-6 text-uppercase fw-semi-bold"><?php echo esc_html__( 'Total Earnings', 'geeks' ); ?></span>
					<span class="tutor-dashboard-info-val mt-4 fw-bold mb-1 d-flex align-items-center h1 lh-1 d-block"><?php echo wp_kses_post( tutor_utils()->tutor_price( $earning_sum->total_income ) ); ?></span>
				</p>
			</div>
		</div>
		<?php endif; ?>
	</div>

	<?php
	$instructor_course = tutor_utils()->get_courses_for_instructors( get_current_user_id() );
	if ( count( $instructor_course ) ) {
		?>
		<div class="tutor-dashboard-info-table-wrap card mb-4">
			<div class="card-header border-bottom-0">
				<h3 class="h4 mb-0"><?php echo esc_html__( 'Most Popular Courses', 'geeks' ); ?></h3>
			</div>
			<div class="table-responsive border-0">
				<table class="tutor-dashboard-info-table table mb-0 text-nowrap">
					<thead>
						<tr>
							<th scope="col" class="border-0"><?php echo esc_html__( 'Course Name', 'geeks' ); ?></th>
							<th scope="col" class="border-0"><?php echo esc_html__( 'Enrolled', 'geeks' ); ?></th>
							<th scope="col" class="border-0"><?php echo esc_html__( 'Status', 'geeks' ); ?></th>
						</tr>
					</thead>
					<tbody>
					<?php
					$instructor_course = tutor_utils()->get_courses_for_instructors( get_current_user_id() );
					foreach ( $instructor_course as $course ) {
						$enrolled        = tutor_utils()->count_enrolled_users_by_course( $course->ID );
						$course_status   = ( 'publish' === $course->post_status ) ? esc_html__( 'Published', 'geeks' ) : $course->post_status;
						$placeholder_img     = tutor()->url . 'assets/images/placeholder.svg';

						?>
						<tr>
							<td class="align-middle border-top-0">
								<a href="<?php echo esc_url( get_the_permalink( $course->ID ) ); ?>" target="_blank">
									<div class="d-lg-flex align-items-center">
											<?php
											if ( has_post_thumbnail( $course->ID ) ) {
												echo wp_kses_post( get_the_post_thumbnail( $course->ID, 'post-thumbnail', array( 'class' => 'mw-none rounded img-4by3-lg' ) ) );
											} else {
												?>
												<img src="<?php echo esc_url( $placeholder_img ); ?>" class="mw-none rounded img-4by3-lg">
												<?php
											}
											?>

										<h5 class="mb-0 ms-lg-3 mt-2 mt-lg-0 text-primary-hover text-wrap"><?php echo esc_html( $course->post_title ); ?></h5>
									</div>
								</a>
							</td>
							<td class="align-middle border-top-0"><?php echo esc_html( number_format_i18n( $enrolled ) ); ?></td>
							<td class="align-middle border-top-0">
								<small class="label-course-status label-course-<?php echo esc_attr( $course->post_status ); ?>"> <?php echo esc_html( $course_status ); ?></small>
							</td>
						</tr>
						<?php
					}
					?>
					</tbody>
				</table>
			</div>
		</div>
	<?php } ?>

</div>
