<?php
/**
 * Question Answer
 *
 * @package Tutor\Templates
 * @subpackage Dashboard\Question_Answer
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.0.0
 */

use TUTOR\Input;

$question_id = Input::get( 'question_id', 0, Input::TYPE_INT );
$question    = tutils()->get_qa_question( $question_id );
$answers     = tutils()->get_qa_answer_by_question( $question_id );
$profile_url = tutils()->profile_url( $question->user_id );

?>
<div class="card">
	<div class="card-header">
		<h3 class="mb-0"><?php echo esc_html__( 'Answer', 'geeks' ); ?></h3>
	</div>

	<div class="tutor-queston-and-answer-wrap card-body">
		<div class="tutor_question_answer_wrap">
			<div class="tutor_original_question">
				<div class="tutor-question-wrap">
					<div class="question-top-meta d-flex align-items-center mb-3">
						<div class="tutor-question-avater">
							<a href="<?php echo esc_url( $profile_url ); ?>"> 
								<?php
								echo wp_kses(
									tutils()->get_tutor_avatar( $question->user_id ),
									tutor_utils()->allowed_avatar_tags()
								);
								?>
							</a>


						</div>

						<div class="review-meta mb-0 ms-3">
							<h4 class="mb-0"><a class="d-block text-inherit" href="<?php echo esc_url( $profile_url ); ?>"><?php echo esc_html( $question->display_name ); ?></a></h4>
							<span class="tutor-text-mute text-muted fs-6">
							<?php echo esc_html( wp_sprintf( __( '%s ago', 'geeks' ), human_time_diff( strtotime( $question->comment_date_gmt ) ) ) ); ?>
							</span>
						</div>
					</div>

					<div class="tutor_question_area bg-light p-4 rounded-3 mb-0-last-child mb-4">
						<p><strong><?php echo esc_html( $question->question_title ); ?> </strong></p>
						<?php echo wp_kses_post( wpautop( stripslashes( $question->comment_content ) ) ); ?>
					</div>
				</div>
			</div>

			<div class="tutor_admin_answers_list_wrap ms-4 ms-md-6">
				<?php
				if ( is_array( $answers ) && count( $answers ) ) {
					foreach ( $answers as $answer ) {
						$answer_profile = tutils()->profile_url( $answer->user_id );
						$answer_classes = 'tutor_individual_answer';
						if ( $question->user_id === $answer->user_id ) {
							$answer_classes = 'tutor-bg-white mb-4';
						} else {
							$answer_classes = 'tutor-bg-light mb-4';
						}
						?>
							<div class="<?php echo esc_attr( $answer_classes ); ?>">
								<div class="tutor-question-wrap">
									<div class="question-top-meta d-flex align-items-center mb-3">
										<div class="tutor-question-avater">
											
											<a href="<?php echo esc_url( $answer_profile ); ?>"> 
												<?php
												echo wp_kses(
													tutils()->get_tutor_avatar( $answer->user_id ),
													tutor_utils()->allowed_avatar_tags()
												);
												?>
											</a>
										</div>
										<div class="review-meta mb-0 ms-3">
											<h4 class="mb-0"><a class="d-block text-inherit" href="<?php echo esc_url( $answer_profile ); ?>"><?php echo esc_html( $answer->display_name ); ?></a></h4>
											<span class="tutor-text-mute text-muted fs-6">
												<?php echo esc_html( wp_sprintf( __( '%s ago', 'geeks' ), human_time_diff( strtotime( $answer->comment_date_gmt ) ) ) ); ?>
											</span>
										</div>
									</div>

									<div class="tutor_question_area bg-light-success shadow-sm rounded-3 p-4 mb-0-last-child">
									<?php echo wp_kses_post( wpautop( stripslashes( $answer->comment_content ) ) ); ?>
									</div>
								</div>
							</div>
							<?php
					}
				}
				?>
				<div class="tutor-add-question-wrap">
					<form action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>" id="tutor_admin_answer_form" method="post">
						<?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); ?>
						<input type="hidden" value="tutor_place_answer" name="action"/>
						<input type="hidden" value="<?php echo esc_attr( $question_id ); ?>" name="question_id"/>
						<div class="tutor-form-group">
							<?php
							$editor_settings = array(
								'teeny'         => true,
								'media_buttons' => false,
								'quicktags'     => false,
								'editor_height' => 180,
							);
							wp_editor( null, 'answer', $editor_settings );
							?>
						</div>
						<div class="tutor-form-group mt-3">
							<button type="submit" class="btn btn-primary tutor-button tutor-button-primary" name="tutor_question_search_btn"><?php echo esc_html__( 'Reply', 'geeks' ); ?> </button>
						</div>
					</form>
				</div>
			</div>
		</div>
	</div>
</div>
