<?php
/**
 * Profile
 *
 * @package Tutor\Templates
 * @subpackage Dashboard\Settings
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.6.2
 */

$user = wp_get_current_user();

// Prepare profile pic.
$profile_placeholder = tutor()->url . 'assets/images/profile-photo.png';
$profile_photo_src   = $profile_placeholder;
$profile_photo_id    = get_user_meta( $user->ID, '_tutor_profile_photo', true );
if ( $profile_photo_id ) {
	$url                                 = wp_get_attachment_image_url( $profile_photo_id, 'full' );
	! empty( $url ) ? $profile_photo_src = $url : 0;
}

// Prepare cover photo.
$cover_placeholder = tutor()->url . 'assets/images/cover-photo.jpg';
$cover_photo_src   = $cover_placeholder;
$cover_photo_id    = get_user_meta( $user->ID, '_tutor_cover_photo', true );
if ( $cover_photo_id ) {
	$url                               = wp_get_attachment_image_url( $cover_photo_id, 'full' );
	! empty( $url ) ? $cover_photo_src = $url : 0;
}

// Prepare display name.
$public_display                     = array();
$public_display['display_nickname'] = $user->nickname;
$public_display['display_username'] = $user->user_login;

if ( ! empty( $user->first_name ) ) {
	$public_display['display_firstname'] = $user->first_name;
}

if ( ! empty( $user->last_name ) ) {
	$public_display['display_lastname'] = $user->last_name;
}

if ( ! empty( $user->first_name ) && ! empty( $user->last_name ) ) {
	$public_display['display_firstlast'] = $user->first_name . ' ' . $user->last_name;
	$public_display['display_lastfirst'] = $user->last_name . ' ' . $user->first_name;
}

if ( ! in_array( $user->display_name, $public_display ) ) { // Only add this if it isn't duplicated elsewhere
	$public_display = array( 'display_displayname' => $user->display_name ) + $public_display;
}

$public_display = array_map( 'trim', $public_display );
$public_display = array_unique( $public_display );
$max_filesize   = floatval( ini_get( 'upload_max_filesize' ) ) * ( 1024 * 1024 );

?>

<div class="tutor-dashboard-content-inner card">

	<div class="card-header">
		<h3 class="mb-0"><?php esc_html_e( 'Profile Details', 'geeks' ); ?></h3>
		<p class="mb-0"><?php esc_html_e( 'You have full control to manage your own account setting.', 'geeks' ); ?></p>
	</div>

	<div class="card-body">

		<?php do_action( 'tutor_profile_edit_form_before' ); ?>

		<div id="tutor_profile_cover_photo_editor" class="pop-up-opened5 d-lg-flex align-items-center justify-content-between">
			<input id="tutor_photo_dialogue_box" class="d-none" type="file" accept=".png,.jpg,.jpeg"/>
			<input type="hidden" class="upload_max_filesize" value="<?php echo esc_attr( $max_filesize ); ?>">

			<div class="d-md-flex align-items-center mb-4 mb-lg-0">
				<div id="tutor_profile_area" class="avatar-xl rounded-circle bg-cover" data-fallback="<?php echo esc_attr( $profile_placeholder ); ?>" style="background-image:url(<?php echo esc_url( $profile_photo_src ); ?>)">
				</div>

				<div class="mt-3 mt-md-0 ms-md-3">
					<h4 class="mb-0"><?php echo esc_html__( 'Your avatar', 'geeks' );?></h4>
					<p class="mb-0">
						<?php echo esc_html__( 'PNG or JPG no bigger than 800px wide and tall.', 'geeks' );?>
					</p>	
				</div>
			</div>

			<div id="tutor_pp_option">
				
				<span class="tutor_pp_uploader btn btn-outline-white btn-sm">
					<?php esc_html_e( 'Update', 'geeks' ); ?>
				</span>

				<span class="tutor_pp_deleter btn btn-outline-danger btn-sm">
					<?php esc_html_e( 'Delete', 'geeks' ); ?>
				</span>

				<div></div>
			</div>
		</div>


		<hr class="my-5">

		<h4 class="mb-0"><?php esc_html_e( 'Personal Details', 'geeks' ); ?></h4>
		<p class="mb-4"><?php esc_html_e( 'Edit your personal information.', 'geeks' ); ?></p>

		<form action="" method="post" enctype="multipart/form-data">
			<?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); ?>
			<input type="hidden" value="tutor_profile_edit" name="tutor_action" />

			<?php
			$error_list = apply_filters( 'tutor_profile_edit_validation_errors', array() );
			if ( is_array( $error_list ) && count( $error_list ) ) {
				echo '<div class="tutor-alert-warning alert alert-warning tutor-mb-10"><ul class="tutor-required-fields">';
				foreach ( $error_list as $error_key => $error_value ) {
					echo '<li>' . esc_html( $error_value ) . '</li>';
				}
				echo '</ul></div>';
			}
			?>

			<?php do_action( 'tutor_profile_edit_input_before' ); ?>

			<div class="row">

				<div class="mb-3 col-12 col-md-6">
					<label class="form-label"><?php esc_html_e( 'First Name', 'geeks' ); ?></label>
					<input class="form-control" type="text" name="first_name" value="<?php echo esc_attr( $user->first_name ); ?>" placeholder="<?php esc_attr_e( 'First Name', 'geeks' ); ?>">
				</div>

				<div class="mb-3 col-12 col-md-6">
					<label class="form-label"><?php esc_html_e( 'Last Name', 'geeks' ); ?></label>
					<input class="form-control" type="text" name="last_name" value="<?php echo esc_attr( $user->last_name ); ?>" placeholder="<?php esc_attr_e( 'Last Name', 'geeks' ); ?>">
				</div>

				<div class="mb-3 col-12 col-md-6">
					<label class="form-label"><?php esc_html_e( 'User Name', 'geeks' ); ?></label>
					<input class="form-control" type="text" disabled="disabled" value="<?php echo esc_attr( $user->user_login ); ?>">
				</div>

				<div class="mb-3 col-12 col-md-6">
					<label class="form-label"><?php esc_html_e( 'Phone Number', 'geeks' ); ?></label>					
					<input class="form-control" type="tel" pattern="[0-9]{3}-[0-9]{2}-[0-9]{3}" name="phone_number" value="<?php echo esc_html( filter_var( get_user_meta( $user->ID, 'phone_number', true ), FILTER_SANITIZE_NUMBER_INT ) ); ?>" placeholder="<?php esc_attr_e( 'Phone Number', 'geeks' ); ?>">

				</div>

				<div class="mb-3 col-12">
					<label class="form-label"><?php esc_html_e( 'Skill/Occupation', 'geeks' ); ?></label>
					<input class="form-control" type="text" name="tutor_profile_job_title" value="<?php echo esc_attr( get_user_meta( $user->ID, '_tutor_profile_job_title', true ) ); ?>" placeholder="<?php esc_attr_e( 'UX Designer', 'geeks' ); ?>">
				</div>

				<div class="mb-3 col-12">
					<label class="form-label"><?php esc_html_e( 'Bio', 'geeks' ); ?></label>
					<?php
					$profile_bio = get_user_meta( $user->ID, '_tutor_profile_bio', true );
					wp_editor( $profile_bio, 'tutor_profile_bio', tutor_utils()->get_profile_bio_editor_config() );
					?>

				</div>

				<div class="mb-3 col-12 col-md-6">
					<label class="form-label" for="display_name"><?php esc_html_e( 'Display name publicly as', 'geeks' ); ?></label>
					<select class="form-control" name="display_name" id="display_name">
						<?php
							foreach ( $public_display as $_id => $item ) {
								?>
										<option <?php selected( $user->display_name, $item ); ?>><?php echo esc_html( $item ); ?></option>
									<?php
							}
						?>
					</select>
					<p class="mb-0 text-muted"><small><?php echo esc_html__( 'The display name is shown in all public fields, such as the author name, instructor name, student name, and name that will be printed on the certificate.', 'geeks' ); ?></small></p>
				</div>
			</div><!-- .row -->

			<hr class="my-5">

			<h4 class="mb-0"><?php esc_html_e( 'Social Profiles', 'geeks' ); ?></h4>
			<p class="mb-4"><?php esc_html_e( 'Add your social profile links in below social accounts.', 'geeks' ); ?></p>

			<?php do_action( 'tutor_profile_edit_before_social_media', $user ); ?>

			<div class="row">
			<?php
			$tutor_user_social_icons = tutor_utils()->tutor_user_social_icons();
			foreach ( $tutor_user_social_icons as $key => $social_icon ) {
				?>
				<div class="mb-3 col-12">
					<label class="form-label" for="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $social_icon['label'] ); ?></label>
					<input class="form-control" type="text" id="<?php echo esc_attr( $key ); ?>" name="<?php echo esc_attr( $key ); ?>" value="<?php echo get_user_meta( $user->ID, $key, true ); ?>" placeholder="<?php echo esc_html( $social_icon['placeholder'] ); ?>">
				</div>
				<?php
			}

			?>
			</div><!-- /.row -->

			<div class="tutor-form-group tutor-profile-form-btn-wrap">
				<button type="submit" class="btn btn-primary tutor-button tutor-profile-settings-save"><?php esc_html_e( 'Update Profile', 'geeks' ); ?></button>
			</div>

			<?php do_action( 'tutor_profile_edit_input_after' ); ?>

		</form>

		<?php do_action( 'tutor_profile_edit_form_after' ); ?>
	</div><!-- /.card-body -->
</div>
