<?php
/**
 * Withdraw settings
 *
 * @package Tutor\Templates
 * @subpackage Dashboard\Settings
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

use Tutor\Models\WithdrawModel;

$col_classes = array(
    1 => 'tutor-bs-col-12',
    2 => 'tutor-bs-col-12 tutor-bs-col-sm-6 tutor-bs-col-md-12 tutor-bs-col-lg-6',
    3 => 'tutor-bs-col-12 tutor-bs-col-lg-4'
);

?>
<div class="tutor-dashboard-setting-withdraw tutor-dashboard-content-inner">
    <div class="card mb-4">
		<div class="card-body">
			
			<h3 class="mb-0"><?php esc_html_e( 'Select a withdraw method', 'geeks' ); ?></h3>
			<p class="mb-0"><?php echo esc_html__( 'Order Dashboard is a quick overview of all current orders.', 'geeks' ); ?></p>
		</div>
	</div>

    <form id="tutor-withdraw-account-set-form" action="" method="post">

        <?php
        $tutor_withdrawal_methods = apply_filters( 'tutor_withdrawal_methods_available', array() );
        
        if ( tutor_utils()->count( $tutor_withdrawal_methods ) ) {
            $saved_account       = WithdrawModel::get_user_withdraw_method();
            $old_method_key      = tutor_utils()->avalue_dot( 'withdraw_method_key', $saved_account );
            $min_withdraw_amount = tutor_utils()->get_option( 'min_withdraw_amount' );
            ?>
            <div class="card mb-4">
				<div class="card-body">
	                <?php
	                $method_count = count( $tutor_withdrawal_methods );
	                foreach ( $tutor_withdrawal_methods as $method_id => $method ) {
	                    ?>
	                    <div class="mb-3 <?php echo esc_attr( $col_classes[ $method_count ] ); ?>" data-withdraw-method="<?php echo esc_attr( $method_id ); ?>">
	                       
	                        <div class="custom-control custom-radio border p-4 rounded-3">
								
								<input class="form-check-input" id="withdraw_method_select_<?php echo esc_attr( $method_id ); ?>" type="radio" name="tutor_selected_withdraw_method" value="<?php echo esc_attr( $method_id ); ?>" <?php checked( $method_id, $old_method_key ) ?>/>

								<label class="form-check-label ps-1" for="withdraw_method_select_<?php echo esc_attr( $method_id ); ?>">
									<h4 class="mb-0"><?php echo esc_html( tutor_utils()->avalue_dot( 'method_name', $method ) );  ?></h4>
									<span class="text-muted"><?php esc_html_e( 'Min withdraw', 'geeks' ); ?> <?php echo wp_kses_post( tutor_utils()->tutor_price( $min_withdraw_amount ) );?></span>
								</label>
							</div>

	                    </div>

	                    <?php
	                }
	                ?>
	            </div>
	        </div>

            <input type="hidden" value="tutor_save_withdraw_account" name="action"/>
            <?php 
                wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); 
                do_action( 'tutor_withdraw_set_account_form_before' );
                
                foreach ( $tutor_withdrawal_methods as $method_id => $method ) {
                    $form_fields = tutor_utils()->avalue_dot( 'form_fields', $method );

                    $method_values = get_user_meta( get_current_user_id(), '_tutor_withdraw_method_data_'.$method_id, true );
                    $method_values = maybe_unserialize( $method_values );
                    !is_array($method_values) ? $method_values=array() : 0;
                    ?>

                    <div data-withdraw-form="<?php echo esc_attr( $method_id ); ?>" class="withdraw-method-form" style="<?php echo esc_attr( $old_method_key != $method_id ? 'display: none;' : '' ); ?>">
                    	<div class="card">
                    		<div class="card-body">
                    			<div class="row">
			                        <?php 
			                        do_action( "tutor_withdraw_set_account_{$method_id}_before" );
			                        
			                        $field_count = tutor_utils()->count( $form_fields );
			                        if ( $field_count ) {
			                            foreach ( $form_fields as $field_name => $field ) {
			                                ?>
			                                <div class="mb-3 <?php echo esc_attr( $field_count ) > 1 ? 'col-md-12 col-lg-6' : 'col-12'; ?> ">
			                                    <?php
			                                    if ( ! empty( $field['label'] ) ) {
			                                        echo wp_kses_post( "<label class='form-label' for='field_{$method_id}_$field_name'>{$field['label']}</label>" );
			                                    }

			                                    $passing_data = apply_filters( 'tutor_withdraw_account_field_type_data', array(
			                                        'method_id' => $method_id,
			                                        'method' => $method,
			                                        'field_name' => $field_name,
			                                        'field' => $field,
			                                        'old_value' => null,
			                                    ) );
			                                    
			                                    $old_value = tutor_utils()->avalue_dot( $field_name . ".value", $saved_account );
			                                    if ( $old_value ) {
			                                        $passing_data['old_value'] = $old_value;
			                                    } else if(isset($method_values[$field_name],$method_values[$field_name]['value'])) {
			                                        $passing_data['old_value'] = $method_values[$field_name]['value'];
			                                        $old_value = $passing_data['old_value'];
			                                    }
			                                    
			                                    if ( in_array( $field['type'], array( 'text', 'number', 'email' ) ) ) {
			                                        ?>
			                                            <input class="form-control tutor-mt-5" type="<?php echo esc_attr( $field['type'] ); ?>" name="withdraw_method_field[<?php echo esc_attr( $method_id ) ?>][<?php echo esc_attr( $field_name ) ?>]" value="<?php echo esc_attr( $old_value ); ?>" >
			                                        <?php
			                                    } else if ( $field['type']=='textarea' ) {
			                                        ?>
			                                            <textarea class="form-control tutor-mt-5" name="withdraw_method_field[<?php echo esc_attr( $method_id ) ?>][<?php echo esc_attr( $field_name ) ?>]">
			                                                <?php echo wp_kses_post( $old_value ); ?>
			                                            </textarea>
			                                        <?php
			                                    }

			                                    if ( ! empty( $field['desc'] ) ) {
			                                        echo wp_kses_post("<p class='withdraw-field-desc tutor-color-text-subsued'>{$field['desc']}</p>");
			                                    }
			                                    ?>
			                                </div>
			                                <?php
			                            }
			                        }
			                        ?>

			                        <?php do_action( "tutor_withdraw_set_account_{$method_id}_after" ); ?>

			                        <div class="withdraw-account-save-btn-wrap mt-1">
			                            <button type="submit" class="tutor_set_withdraw_account_btn btn btn-primary" name="withdraw_btn_submit">
			                                <?php esc_html_e( 'Save Withdrawal Account', 'geeks' ); ?>
			                            </button>
			                        </div>
			                    </div>
		                    </div>
		                </div>
                    </div>
                    <?php
                }
                
                do_action( 'tutor_withdraw_set_account_form_after' ); 
        } else {
			?>
			<div class="tutor-row tutor-mb-32">
				<p>
					<?php echo __( 'There\'s no Withdrawal method selected yet! To select a Withdraw method, please contact the Site Admin.', 'geeks' ); ?>
				</p>
			</div>
			<?php
		}
        ?>
    </form>
</div>
