<?php
/**
 * Withdraw Page
 *
 * @package Tutor\Templates
 * @subpackage Dashboard
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @version 1.4.3
 */

use TUTOR\Input;
use Tutor\Models\WithdrawModel;

//phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
$per_page     = tutor_utils()->get_option( 'statement_show_per_page', 20 );
$current_page = max( 1, Input::get( 'current_page', 1, Input::TYPE_INT ) );
$offset       = ( $current_page - 1 ) * $per_page;

$earning_sum                   = tutor_utils()->get_earning_sum();
$min_withdraw                  = tutor_utils()->get_option( 'min_withdraw_amount' );
$formatted_min_withdraw_amount = tutor_utils()->tutor_price( $min_withdraw );

$saved_account        = WithdrawModel::get_user_withdraw_method();
$withdraw_method_name = tutor_utils()->avalue_dot( 'withdraw_method_name', $saved_account );

$user_id               = get_current_user_id();
$withdraw_status	   = array( WithdrawModel::STATUS_PENDING, WithdrawModel::STATUS_APPROVED, WithdrawModel::STATUS_REJECTED );
$all_histories		   = WithdrawModel::get_withdrawals_history( $user_id, array( 'status' => $withdraw_status ), $offset, $per_page );
$image_base   = tutor()->url . '/assets/images/';

$method_icons = array(
	'bank_transfer_withdraw' => $image_base . 'icon-bank.svg',
	'echeck_withdraw'        => $image_base . 'icon-echeck.svg',
	'paypal_withdraw'        => $image_base . 'icon-paypal.svg',
);

$status_message = array(
	'rejected' => esc_html__( 'Please contact the site administrator for more information.', 'geeks' ),
	'pending'  => esc_html__( 'Withdrawal request is pending for approval, please hold tight.', 'geeks' ),
);

$currency_symbol = '';
if ( function_exists( 'get_woocommerce_currency_symbol' ) ) {
	$currency_symbol = get_woocommerce_currency_symbol();
} elseif ( function_exists( 'edd_currency_symbol' ) ) {
	$currency_symbol = edd_currency_symbol();
}

$summary_data                     = WithdrawModel::get_withdraw_summary( $user_id );
$available_for_withdraw           = $summary_data->available_for_withdraw - $summary_data->total_pending;
$is_balance_sufficient            = $available_for_withdraw >= $min_withdraw;
$available_for_withdraw_formatted = tutor_utils()->tutor_price( $available_for_withdraw );
$current_balance_formated         = tutor_utils()->tutor_price( $summary_data->current_balance );
?>

<div class="tutor-dashboard-content-inner tutor-frontend-dashboard-withdrawal">
	<div class="card mb-4">
		<div class="card-body">
			<h4 class="mb-0"><?php echo esc_html__( 'Withdrawal', 'geeks' ); ?></h4>
		</div>
	</div>

	<div class="card mb-2">
		<div class="withdraw-page-current-balance card-body d-lg-flex align-items-center justify-content-between">
			<div class="balance-info d-md-flex align-items-center">
					<div class="tutor-col-lg-auto tutor-mb-16 tutor-mb-lg-0">
						<div class="tutor-round-box tutor-p-8">
							<i class="tutor-icon-wallet" area-hidden="true"></i>
						</div>
					</div>
					<?php //phpcs:disable WordPress.WP.I18n.MissingTranslatorsComment ?>
					<div class="mt-3 mt-md-0 ms-md-4">
					<small><?php esc_html_e( 'Current Balance', 'geeks' ); ?></small>
					<p class="mb-0 h4">
						<?php
						if ( $is_balance_sufficient ) {
							echo wp_kses_post( sprintf( esc_html__( 'You have %1$s %2$s %3$s ready to withdraw now', 'geeks' ), "<strong class='available_balance'>", $available_for_withdraw_formatted, '</strong>' ) );

						} else {
							echo wp_kses_post(sprintf( esc_html__( 'You have %1$s %2$s %3$s and this is insufficient balance to withdraw', 'geeks' ), "<strong class='available_balance'>", $available_for_withdraw_formatted, '</strong>' ) );

						}
						?>
					</p>
					<?php if ( $summary_data->total_pending > 0 ) : ?>
					<div class="tutor-badge-label label-warning	 tutor-mt-4" style="display: inline-flex; gap: 3px"><?php echo wp_kses_post( sprintf( esc_html__( 'Total Pending Withdrawal %s', 'geeks' ), tutor_utils()->tutor_price( $summary_data->total_pending ) ) ); ?></div>
					<?php endif; ?>
					</div>
			</div>
			<div class="make-withdraw mt-3 mt-lg-0">
				<?php if ( $is_balance_sufficient && $withdraw_method_name ) : ?>
					<button class="tutor-btn btn btn-primary" data-tutor-modal-target="tutor-earning-withdraw-modal">
				<?php esc_html_e( 'Withdrawal Request', 'geeks' ); ?>
				</button>
				<?php endif; ?>
			</div>
		</div>
	</div>

	<div class="current-withdraw-account-wrap withdrawal-preference d-md-flex align-items-center inline-image-text mb-4">
		<img src="<?php echo esc_url( $image_base ); ?>info-icon-question.svg" />
		<span class="ms-1 fs-6">
			<?php
			if ( ! empty( $withdraw_method_name ) ) {
				$withdraw_method_name = sprintf( esc_html__( 'The preferred payment method is selected as %s. ', 'geeks' ), $withdraw_method_name );
			}
			$my_profile_url = tutor_utils()->get_tutor_dashboard_page_permalink( 'settings/withdraw-settings' );
			echo wp_kses_post( $withdraw_method_name );
			echo wp_kses_post( sprintf( esc_html__( 'You can change your %1$s withdrawal preference %2$s', 'geeks' ), "<a href='{$my_profile_url}'>", '</a>' ) );
			?>
		</span>
	</div>

	<?php
	if ( $is_balance_sufficient && $withdraw_method_name ) {
		?>
		<div id="tutor-earning-withdraw-modal" class="tutor-modal">
			<div class="tutor-modal-overlay"></div>
			<div class="tutor-modal-window">
				<div class="tutor-modal-content tutor-modal-content-white">
					<button class="tutor-iconic-btn tutor-modal-close-o" data-tutor-modal-close>
						<span class="tutor-icon-times" area-hidden="true"></span>
					</button>

					<div class="tutor-modal-body">
						<div class="tutor-py-20 tutor-px-24">
							<div class="tutor-round-box tutor-round-box-lg tutor-mb-16">
								<span class="tutor-icon-wallet" area-hidden="true"></span>
							</div>

							<div class="tutor-fs-4 tutor-fw-medium tutor-color-black tutor-mb-24"><?php esc_html_e( 'Withdrawal Request', 'geeks' ); ?></div>
							<div class="tutor-fs-6 tutor-color-muted"><?php esc_html_e( 'Please check your transaction notification on your connected withdrawal method', 'geeks' ); ?></div>

							<div class="tutor-row tutor-mt-32">
								<div class="tutor-col">
									<div class="tutor-fs-6 tutor-color-secondary tutor-mb-4"><?php esc_html_e( 'Withdrawable Balance', 'geeks' ); ?></div>
									<div class="tutor-fs-6 tutor-fw-bold tutor-color-black"><?php echo wp_kses_post( $available_for_withdraw_formatted ); ?></div>
								</div>

								<div class="tutor-col">
									<div class="tutor-fs-6 tutor-color-secondary tutor-mb-4"><?php esc_html_e( 'Selected Payment Method', 'geeks' ); ?></div>
									<div class="tutor-fs-6 tutor-fw-bold tutor-color-black"><?php esc_html_e( $withdraw_method_name , 'geeks' ); ?></div>
								</div>
							</div>
						</div>

						<div class="tutor-mx-n32 tutor-my-32"><div class="tutor-hr" area-hidden="true"></div></div>

						<form id="tutor-earning-withdraw-form" method="post">
							<div class="tutor-py-20 tutor-px-24">
								<div>
									<?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); ?>
									<input type="hidden" value="tutor_make_an_withdraw" name="action" />
									<?php do_action( 'tutor_withdraw_form_before' ); ?>
									
									<label class="tutor-form-label" for="tutor_withdraw_amount"><?php esc_html_e( 'Amount', 'geeks' ); ?></label>
									<div class="tutor-form-wrap tutor-mb-16">
										<span class="tutor-form-icon"><?php echo esc_attr( $currency_symbol ); ?></span>
										<input type="number" class="tutor-form-control" min="<?php echo esc_attr( $min_withdraw ); ?>" name="tutor_withdraw_amount" id="tutor_withdraw_amount" step=".01" required />
									</div>

									<div class="tutor-form-help tutor-d-flex tutor-align-center">
										<span class="tutor-icon-circle-question-mark tutor-mr-8" area-hidden="true"></span>
										<span><?php echo __( 'Minimum withdraw amount is', 'geeks' ) . ' ' . strip_tags( $formatted_min_withdraw_amount ); ?></span>
									</div>

									<div class="tutor-withdraw-form-response"></div>

									<?php do_action( 'tutor_withdraw_form_after' ); ?>
								</div>

								<div class="tutor-d-flex tutor-mt-48">
									<div>
										<button class="tutor-btn tutor-btn-outline-primary" data-tutor-modal-close>
											<?php _e( 'Cancel', 'geeks' ); ?>
										</button>
									</div>

									<div class="tutor-ml-auto">
										<button type="submit" name="withdraw-form-submit" id="tutor-earning-withdraw-btn" class="tutor-btn tutor-btn-primary tutor-modal-btn-edit tutor-ml-16">
											<?php esc_html_e( 'Submit Request', 'geeks' ); ?>
										</button>
									</div>
								</div>
							</form>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

	
	if ( is_array( $all_histories->results ) && count ( $all_histories->results ) ) {
		?>
		<div class="withdraw-history-table-wrap tutor-tooltip-inside card">
			<div class="withdraw-history-table-title card-header">
				<h4 class="mb-0"> <?php esc_html_e( 'Withdrawal History', 'geeks' ); ?></h4>
			</div>

			<div class="table-responsive border-0">
				<table class="table mb-0 text-nowrap withdrawals-history tutor-table">
					<thead>
						<tr>
							<th class="border-0"><?php esc_html_e( 'Withdrawal Method', 'geeks' ); ?></th>
							<th class="border-0" width="30%"><?php esc_html_e( 'Requested On', 'geeks' ); ?></th>
							<th class="border-0" width="15%"><?php esc_html_e( 'Amount', 'geeks' ); ?></th>
							<th class="border-0" width="15%"><?php esc_html_e( 'Status', 'geeks' ); ?></th>
							<th class="border-0"></th>
						</tr>
					</thead>
					<tbody>
					<?php
					foreach ( $all_histories->results as $withdraw_history ) {
						?>
						<tr>
							<td class="align-middle border-top-0">
								<?php
								$method_data  = maybe_unserialize( $withdraw_history->method_data );
								$method_key   = $method_data['withdraw_method_key'];
								$method_title = '';

								switch ( $method_key ) {
									case 'bank_transfer_withdraw':
										$method_title = $method_data['account_number']['value'];
										$method_title = substr_replace( $method_title, '****', 2, strlen( $method_title ) - 4 );
										break;
									case 'paypal_withdraw':
										$method_title = $method_data['paypal_email']['value'];
										$email_base   = substr( $method_title, 0, strpos( $method_title, '@' ) );
										$method_title = substr_replace( $email_base, '****', 2, strlen( $email_base ) - 3 ) . substr( $method_title, strpos( $method_title, '@' ) );
										break;
								}


								$badge_color = '';
								switch ( $withdraw_history->status ) {
									case 'on-hold':
									case 'pending':
										$badge_color = 'warning';
										break;
									case 'completed':
									case 'processing':
										$badge_color = 'success';
										break;
									case 'cancelled':
									case 'refunded':
									case 'failed':
										$badge_color = 'danger';
										break;
								}
								?>
								<div class="inline-image-text is-inline-block d-flex align-items-center">
									<?php if ( isset( $method_icons[ $method_key ] ) ) : ?>
									<img class="me-2" src="<?php echo esc_url( $method_icons[ $method_key ] ); ?>">
									<?php endif; ?>
									<span>
										<?php
										echo '<span class="withdraw-method-name d-block">', esc_html( tutor_utils()->avalue_dot( 'withdraw_method_name', $method_data ) ), '</span>';
										echo '<small class="text-muted">' . esc_html( $method_title ) . '</small>';
										?>
									</span>
								</div>
							</td>
							<td class="align-middle border-top-0">
								<?php echo wp_kses_post( date_i18n( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), strtotime( $withdraw_history->created_at ) ) ); ?>
							</td>
							<td class="align-middle border-top-0">
								<?php echo wp_kses_post( tutor_utils()->tutor_price( $withdraw_history->amount ) ); ?>
							</td>
							<td class="align-middle border-top-0">
								<span class="inline-image-text is-inline-block">
									<span class="tutor-status-text status-<?php echo esc_attr( $withdraw_history->status ); ?> badge bg-<?php echo esc_attr( $badge_color ); ?>">
										<?php echo esc_html( ucfirst( $withdraw_history->status ) ); ?>
									</span>
								</span>
							</td>
							<td class="align-middle border-top-0">
								<?php
								if ( 'approved' !== $withdraw_history->status && isset( $status_message[ $withdraw_history->status ] ) ) {
									?>
									<span class="tutor-status-text-container">
										<span class="tool-tip-container" data-bs-toggle="tooltip" data-placement="left" title="<?php echo esc_attr( $status_message[ $withdraw_history->status ] ); ?>">
											<img src="<?php echo esc_url( $image_base ); ?>info-icon.svg" />
											<span class="tooltip tip-left" role="tooltip">
												<?php echo esc_html( $status_message[ $withdraw_history->status ] ); ?>
											</span>
										</span>
									</span>
									<?php
								}
								?>
							</td>
						</tr>
						<?php
					}
					?>
					</tbody>
				</table>
			</div>
		</div>
		<?php
	} else {
		tutor_utils()->tutor_empty_state( tutor_utils()->not_found_text() );
	}
	?>
	
		
</div>
	
<div class="tutor-mt-25">
	<?php 
		if($all_histories->count >= $per_page) {
			$pagination_data = array(
				'total_items' => $all_histories->count,
				'per_page'    => $per_page,
				'paged'       => $current_page,
			);

			tutor_load_template_from_custom_path(
				tutor()->path . 'templates/dashboard/elements/pagination.php',
				$pagination_data
			);
		}
	?>
</div>