<?php
/**
 * Template for assignment content.
 *
 * @package Tutor\Templates
 * @subpackage Single\Assignment
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.4.3
 */

use TUTOR\Input;
use \TUTOR_ASSIGNMENTS\Assignments;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
global $post;
global $wpdb;
global $next_id;
global $assignment_submitted_id;
$is_submitted  = false;
$is_submitting = tutor_utils()->is_assignment_submitting( get_the_ID() );

// Get the comment.
$post_id              = get_the_ID(); //phpcs:ignore
$user_id              = get_current_user_id();
$user_data            = get_userdata( $user_id );
$assignment_comment   = tutor_utils()->get_single_comment_user_post_id( $post_id, $user_id );
$submitted_assignment = tutor_utils()->is_assignment_submitted( get_the_ID() );

if ( false != $assignment_comment ) {
    $submitted                                = $assignment_comment->comment_approved;
    'submitted' == $submitted ? $is_submitted = true : '';
}

// Get the ID of this content and the corresponding course.
$course_content_id = get_the_ID();
$course_id         = tutor_utils()->get_course_id_by_subcontent( $course_content_id );

// Get total content count.
$course_stats = tutor_utils()->get_course_completed_percent( $course_id, 0, true );

/**
 * Convert assignment time
 *
 * @todo move to utils
 *
 * @param integer $seconds seconds.
 * @return string
 */
function tutor_assignment_convert_seconds( $seconds ) {
    $dt1 = new DateTime( '@0' );
    $dt2 = new DateTime( "@$seconds" );
    return $dt1->diff( $dt2 )->format( '%a Days, %h Hours' );
}
$next_prev_content_id = tutor_utils()->get_course_prev_next_contents_by_id( $post_id );
$content              = get_the_content();
$s_content            = $content;
$allow_to_upload      = (int) tutor_utils()->get_assignment_option( $post_id, 'upload_files_limit' );
?>

<?php do_action('tutor_assignment/single/before/content'); ?>

<div class="tutor-single-page-top-bar card mb-4 mt-5">
	<div class="card-body p-3">
		<div class="d-md-flex align-items-center justify-content-between flex-wrap">
			<div class="d-flex align-items-center tutor-topbar-item tutor-hide-sidebar-bar">
				<a href="#" class="me-2 text-inherit tutor-lesson-sidebar-hide-bar tutor-course-topics-sidebar-toggler" tutor-course-topics-sidebar-toggler><i class="fe fe-chevron-left"></i> </a>
				<?php $course_id = tutor_utils()->get_course_id_by('assignment', get_the_ID()); ?>
				<h2 class="course-title mb-0 h4">
                    <a class="text-inherit" href="<?php echo get_the_permalink( $course_id ); ?>"><?php echo get_the_title( $course_id ); ?></a>
                </h2>
			</div>

			<div class="tutor-topbar-right-item d-flex align-items-center">
		        <div class="tutor-topbar-assignment-details d-flex align-items-center">
		            <?php
		                do_action( 'tutor_course/single/enrolled/before/lead_info/progress_bar' );
		            ?>
		            <div class="text-regular-caption me-2">
		                <span class="tutor-progress-content text-dark d-none d-xl-inline-block">
		                    <?php esc_html_e( 'Your Progress:', 'geeks' ); ?>
		                </span>
		                <span class="text-bold-caption">
		                    <?php echo esc_html( $course_stats['completed_count'] ); ?>
		                </span> 
		                <?php esc_html_e( 'of ', 'geeks' ); ?>
		                <span class="text-bold-caption">
		                    <?php echo esc_html( $course_stats['total_count'] ); ?>
		                </span>
		                (<?php echo esc_html( $course_stats['completed_percent'] . '%' ); ?>)
		            </div>
		            <?php
		                do_action( 'tutor_course/single/enrolled/after/lead_info/progress_bar' );
		            ?>
		        </div>
		        <div class="tutor-topbar-cross-icon flex-center ms-1 ms-xl-2">
		            <?php $course_id = tutor_utils()->get_course_id_by( 'lesson', get_the_ID() ); ?>
		            <a href="<?php echo esc_url( get_the_permalink( $course_id ) ); ?>">
		                <i class="fe fe-x"></i>
		            </a>
		        </div>
		    </div>
		</div>
	</div>
</div>

<div class="tutor-mobile-top-navigation d-none tutor-bs-d-block tutor-bs-d-sm-none tutor-my-20 tutor-mx-10">
    <div class="tutor-mobile-top-nav d-grid">
        <a href="<?php echo esc_url( get_the_permalink( isset( $previous_id ) ? $previous_id : '' ) ); ?>">
            <span class="tutor-top-nav-icon tutor-icon-previous-line design-lightgrey"></span>
        </a>
        <div class="tutor-top-nav-title tutor-text-regular-body text-dark">
            <?php
                the_title();
            ?>
        </div>
    </div>
</div>

<h3 class="h3 mb-4 pt-1 text-truncate-line-2"><?php echo get_the_title(); ?></h3>

<div class="tutor-lesson-content-area card">
	
	<div class="card-body">

	<div class="tutor-assignment-information">
		<?php
		$time_duration = tutor_utils()->get_assignment_option(
            get_the_ID(),
            'time_duration',
            array(
                'time'  => '',
                'value' => 0,
            )
        );

        $total_mark        = tutor_utils()->get_assignment_option( get_the_ID(), 'total_mark' );
        $pass_mark         = tutor_utils()->get_assignment_option( get_the_ID(), 'pass_mark' );
        $file_upload_limit = tutor_utils()->get_assignment_option( get_the_ID(), 'upload_file_size_limit' );

		global $post;
        $assignment_created_time = strtotime( $post->post_date_gmt );
        $time_duration_in_sec    = 0;
        if ( isset( $time_duration['value'] ) and isset( $time_duration['time'] ) ) {
            switch ( $time_duration['time'] ) {
                case 'hours':
                    $time_duration_in_sec = 3600;
                    break;
                case 'days':
                    $time_duration_in_sec = 86400;
                    break;
                case 'weeks':
                    $time_duration_in_sec = 7 * 86400;
                    break;
                default:
                    $time_duration_in_sec = 0;
                    break;
            }
        }

        $time_duration_in_sec = $time_duration_in_sec * (int) $time_duration['value'];
        $remaining_time       = $assignment_created_time + $time_duration_in_sec;
        $now                  = time();
        $remaining            = $now - $remaining_time;

		?>
		<?php if ( ! $submitted_assignment ) { ?>
		<ul class="list-unstyled">
			<li class="mb-2">
				<?php esc_html_e('Time Duration : ', 'geeks') ?>
				<strong><?php echo $time_duration["value"] ? $time_duration["value"] . ' ' . $time_duration["time"] : esc_html__('No limit', 'geeks'); ?></strong>
			</li>
			<?php
			/*
				*time_duration[value]==0 means no limit
				*if have unlimited time then no msg should
				*appear 
		        */

			if ( $time_duration['value'] != 0 ) {
                if ( $now > $remaining_time and $is_submitted == false ) { ?>
                    <li class="mb-2">
						<?php esc_html_e('Deadline : ', 'geeks') ?>
						<strong><?php esc_html_e('Expired', 'geeks'); ?></strong>
					</li>
					<?php
                } else { ?>
                    <li class="mb-2">
                        <?php esc_html_e('Deadline : ', 'geeks') ?>
                        <strong><?php echo esc_html( tutor_assignment_convert_seconds( $remaining ) ); ?></strong>
                    </li>
                    <?php
                }
            } else {
                esc_html_e( 'N\\A', 'geeks' );
            }
			?>

			<li class="mb-2">
				<?php esc_html_e('Total Points : ', 'geeks') ?>
				<strong><?php echo esc_html( $total_mark ); ?></strong>
			</li>
			<li class="mb-2">
				<?php esc_html_e('Minimum Pass Points : ', 'geeks') ?>
				<strong><?php echo esc_html( $pass_mark ); ?></strong>
			</li>
		</ul>
		<?php } ?>
	</div>

	<hr />
	<?php
	/*
	*time_duration[value]==0 means no limit
	*if have unlimited time then no msg should
	*appear 
	*/
	if ($time_duration['value'] != 0) :
		if ($now > $remaining_time and $is_submitted == false) : ?>
			<div class="tutor-asignment-expire tutor-alert-danger tutor-alert alert alert-danger" style="margin:36px 0 46px">

				<?php esc_html_e('You have missed the submission deadline. Please contact the instructor for more information.', 'geeks'); ?>

			</div>
	<?php
		endif;
	endif;
	?>
	<?php if ( ! $is_submitting && ! $submitted_assignment && get_the_content() ) { ?>
		<div class="tutor-assignment-content">
			<h3 class="h4"><?php esc_html_e('Description', 'geeks'); ?></h2>

			<?php the_content(); ?>
		</div>
	 <?php } ?>

	<?php
	$assignment_attachments = maybe_unserialize(get_post_meta(get_the_ID(), '_tutor_assignment_attachments', true));
	if (tutor_utils()->count($assignment_attachments)) {
	?>
		<div class="tutor-assignment-attachments">
			<h2><?php esc_html_e('Attachments', 'geeks'); ?></h2>
			<?php if ( is_array( $assignment_attachments ) && count( $assignment_attachments ) ) : ?>
            <?php
            foreach ( $assignment_attachments as $attachment_id ) :
                $attachment_name = get_post_meta( $attachment_id, '_wp_attached_file', true );
                $attachment_name = substr( $attachment_name, strrpos( $attachment_name, '/' ) + 1 );
                $file_size       = tutor_utils()->get_attachment_file_size( $attachment_id );
                ?>
                <div class="tutor-instructor-card tutor-bs-col-sm-5 tutor-py-15 tutor-mr-10 mb-4 border mw-50">
                    <div class="tutor-icard-content p-0">
                        <div class="text-regular-body color-text-title">
                        <a href="<?php echo esc_url( wp_get_attachment_url( $attachment_id ) ); ?>" target="_blank">
                            <?php echo esc_html( $attachment_name ); ?>
                        </a>
                        </div>
                        <div class="text-regular-small">
                            <?php esc_html_e( 'Size: ', 'geeks' ); ?>
                            <?php echo esc_html( $file_size ? $file_size . 'KB' : '' ); ?>
                        </div>
                    </div>
                    <div class="tutor-avatar tutor-is-xs flex-center">
                        <a href="<?php echo esc_url( wp_get_attachment_url( $attachment_id ) ); ?>" target="_blank">
                            <span class="tutor-icon-download"></span>
                        </a>
                    </div>
                </div>                  
            <?php endforeach; ?>
        <?php endif; ?>
		</div>
	<?php
	}

	if ( ( $is_submitting || isset( $_GET['update-assignment'] ) ) && ( $remaining_time > $now || $time_duration['value'] == 0 ) ) {
            ?>

            <div class="tutor-assignment-submission tutor-assignment-border-bottom tutor-pb-50 tutor-pb-sm-70">
                <form action="" method="post" id="tutor_assignment_submit_form" enctype="multipart/form-data">
                    <?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce, false ); ?>
                    <input type="hidden" value="tutor_assignment_submit" name="tutor_action" />
                    <input type="hidden" value="<?php echo strtok( tutor()->current_url, '?' ); ?>" name="_wp_http_referer" />

                    <input type="hidden" name="assignment_id" value="<?php echo get_the_ID(); ?>">

                    <?php $allowed_upload_files = (int) tutor_utils()->get_assignment_option( get_the_ID(), 'upload_files_limit' ); ?>
                    <div class="tutor-assignment-body has-show-more">
                        <div class="tutor-to-title tutor-text-medium-h6 tutor-color-text-primary">
                            <?php esc_html_e( 'Assignment Submission', 'geeks' ); ?>
                        </div>
                        <div class="text-regular-caption tutor-color-text-subsued tutor-pt-15 tutor-pt-sm-30">
                            <?php esc_html_e( 'Assignment answer form', 'geeks' ); ?>
                        </div>
                        <div class="tutor-assignment-text-area tutor-pt-20">
                            <!-- <textarea  name="assignment_answer" class="tutor-form-control"></textarea> -->
                            <?php
                                $assignment_comment_id = isset( $_GET['update-assignment'] ) ? sanitize_text_field( $_GET['update-assignment'] ) : 0;
                                $content               = $assignment_comment_id ? get_comment( $assignment_comment_id ) : '';
                                $args                  = tutor_utils()->text_editor_config();
                                $args['tinymce']       = array(
                                    'toolbar1' => 'formatselect,bold,italic,underline,forecolor,bullist,numlist,alignleft,aligncenter,alignright,alignjustify,undo,redo',
                                );
                                $args['editor_height'] = '140';
                                $editor_args           = array(
                                    'content' => isset( $content->comment_content ) ? $content->comment_content : '',
                                    'args'    => $args,
                                );
                                $text_editor_template  = tutor()->path . 'templates/global/tutor-text-editor.php';
                                tutor_load_template_from_custom_path( $text_editor_template, $editor_args );
                                ?>
                        </div>

                        <?php if ( $allowed_upload_files ) { ?>
                            <div class="mt-4 px-4 tutor-assignment-attachment bg-light tutor-mt-30 tutor-py-20 tutor-px-15 tutor-py-sm-30 tutor-px-sm-30">
                                <div class="text-regular-caption tutor-color-text-subsued">
                                
                                    <?php
                                        $attachment_text  = _x( 'Attach assignment files (Max: ', 'Assignment attachment', 'geeks' );
                                        $attachment_text .= $allow_to_upload . _x( ' file)', 'Assignment attachment', 'geeks' );
                                        echo esc_html( $attachment_text );
                                    ?>
                                </div>
                                <div class="tutor-attachment-files tutor-mt-12 d-flex align-items-center">
                                    <div class="tutor-assignment-upload-btn tutor-mt-10 tutor-mt-md-0">
                                        <form>
                                            <label for="tutor-assignment-file-upload">
                                                <input type="file" id="tutor-assignment-file-upload" name="attached_assignment_files[]" multiple>
                                                <a class="tutor-btn tutor-btn-primary tutor-btn-md">
                                                    <?php esc_html_e( 'Choose file', 'geeks' ); ?>
                                                </a>
                                            </label>
                                            <input type="hidden" name="tutor_assignment_upload_limit" value="<?php echo esc_attr( $file_upload_limit * 1000000 );?>">

                                        </form>
                                    </div>
                                    <div class="tutor-input-type-size">
                                        <p class="text-regular-small tutor-color-text-subsued">
                                            <?php esc_html_e( 'File Support: ', 'geeks' ); ?>
                                            <span class="tutor-color-text-primary">
                                                <?php esc_html_e( 'Any standard Image, Document, Presentation, Sheet, PDF or Text file is allowed', 'geeks' ); ?>
                                            </span>
                                        </p>
                                        <p class="text-regular-small tutor-color-text-subsued tutor-mt-7">
                                            <?php esc_html_e( 'Total File Size: Max', 'geeks' ); ?> 
                                            <span class="tutor-color-text-primary">
                                                <?php echo esc_html( $file_upload_limit ); ?>
                                                <?php esc_html_e( 'MB', 'geeks' ); ?>
                                            </span>
                                        </p>
                                    </div>
                                </div>
                                <!-- uploaded attachment by students -->
                                <div class="tutor-bs-container bg-white border mw-50 m-0 tutor-pt-15 tutor-update-assignment-attachments">
                                    <div class="tutor-bs-row tutor-bs-gy-3" id="tutor-student-assignment-edit-file-preview">
                                    <?php
                                        $submitted_attachments = get_comment_meta( $assignment_comment_id, 'uploaded_attachments' );
                                    if ( is_array( $submitted_attachments ) && count( $submitted_attachments ) ) :
                                        foreach ( $submitted_attachments as $attach ) :
                                            $attachments = json_decode( $attach );
                                            ?>
                                            <?php foreach ( $attachments as $attachment ) : ?>
                                                <div class="tutor-instructor-card tutor-bs-col-sm-5 tutor-py-15 tutor-mr-15">
                                                    <div class="tutor-icard-content">
                                                        <div class="text-regular-body tutor-color-text-title">
                                                            <?php echo esc_html( $attachment->name ); ?>
                                                        </div>
                                                        <div class="text-regular-small">Size: 230KB;</div>
                                                    </div>
                                                    <div class="tutor-attachment-file-close tutor-avatar tutor-is-xs flex-center">
                                                        <a href="<?php echo esc_url( $attachment->url ); ?>" data-id="<?php echo esc_attr( $assignment_comment_id ); ?>" data-name="<?php echo esc_attr( $attachment->name ); ?>" target="_blank">
                                                            <span class="tutor-icon-cross-filled color-design-brand"></span>
                                                        </a>
                                                    </div>
                                                </div>
                                            <?php endforeach; ?>
                                        <?php endforeach; ?>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <!-- uploaded attachment by students end -->
                            </div>

                        <?php } ?>
                        <div class="tutor-assignment-submit-btn tutor-mt-60">
                            <button type="submit" class="btn btn-primary tutor-btn-primary tutor-btn-lg tutor-static-loader" id="tutor_assignment_submit_btn">
                                <?php esc_html_e( 'Submit Assignment', 'geeks' ); ?>
                            </button>
                        </div>
                    </div>
                </form>
            </div> <!-- assignment-submission -->
            <hr>
            <?php if( $s_content ): ?>
            <div class="tutor-assignment-description-details tutor-assignment-border-bottom tutor-pb-30 tutor-pb-sm-45">
                <div class="<?php echo esc_attr( strlen( $s_content ) > 500 ? 'tutor-ad-body has-show-more' : '' ); ?>" id="content-section">
                    <div class="text-medium-h6 tutor-color-text-primary">
                        <?php esc_html_e( 'Description', 'geeks' ); ?>
                    </div>
                    <div class="text-regular-body tutor-color-text-subsued tutor-pt-12" id="short-text">
                        <?php
                        if ( strlen( $s_content ) > 500 ) {
                            echo wp_kses_post( substr_replace( $s_content, '...', 500 ) );
                        } else {
                            echo wp_kses_post( $s_content );
                        }
                        ?>
                        <span id="dots"></span>
                    </div>
                    <?php if ( strlen( $s_content ) > 500 ) : ?>
                        <div class="text-regular-body tutor-color-text-subsued tutor-pt-12" id="full-text">
                            <?php
                                echo wp_kses_post( $s_content );
                            ?>
                        </div>
                        <div class="tutor-show-more-btn tutor-pt-12">
                            <button class="tutor-btn tutor-btn-icon tutor-btn-disable-outline tutor-btn-ghost tutor-no-hover tutor-btn-lg" id="showBtn">
                                <span class="btn-icon tutor-icon-plus-filled tutor-color-design-brand" id="no-icon"></span>
                                <span class="tutor-color-text-primary"><?php esc_html_e( 'Show More', 'geeks' ); ?></span>
                            </button>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
            <?php endif; ?>
            <?php if ( $next_prev_content_id->next_id ) : ?>
            <div class="tutor-assignment-footer d-flex justify-content-end tutor-pt-30 tutor-pt-sm-45">
                <a href="<?php echo esc_url( get_permalink( $next_prev_content_id->next_id ) ); ?>" class="tutor-btn tutor-btn-disable-outline bg-transparent border-0 p-0 tutor-no-hover tutor-btn-lg tutor-mt-md-0 tutor-mt-10">
                    <?php esc_html_e( 'Skip To Next', 'geeks' ); ?>
                </a>
            </div>
            <?php endif; ?>
            <?php
        } else {

            /**
             * If assignment submitted
             */
            if ( $submitted_assignment ) {
                $is_reviewed_by_instructor = get_comment_meta( $submitted_assignment->comment_ID, 'evaluate_time', true );


                    $assignment_id = $submitted_assignment->comment_post_ID;
                    $submit_id     = $submitted_assignment->comment_ID;

                    $max_mark   = tutor_utils()->get_assignment_option( $submitted_assignment->comment_post_ID, 'total_mark' );
                    $pass_mark  = tutor_utils()->get_assignment_option( $submitted_assignment->comment_post_ID, 'pass_mark' );
                    $given_mark = get_comment_meta( $submitted_assignment->comment_ID, 'assignment_mark', true );
                ?>
                    <div class="tutor-assignment-result-table tutor-mt-30 tutor-mb-40">
                        <div class="tutor-ui-table-wrapper table-responsive border-0">
                            <table class="tutor-dashboard-info-table table mb-0 text-nowrap my-quiz-attempts">
                                <thead>
                                    <tr>
                                        <th scope="col" class="border-0">
                                        <span class="text-regular-small tutor-color-text-subsued">
                                            <?php esc_html_e( 'Date', 'geeks' ); ?>
                                        </span>
                                        </th>
                                        <th scope="col" class="border-0">
                                        <span class="text-regular-small tutor-color-text-subsued">
                                            <?php esc_html_e( 'Total Marks', 'geeks' ); ?>
                                        </span>
                                        </th>
                                        <th scope="col" class="border-0">
                                        <span class="text-regular-small tutor-color-text-subsued">
                                            <?php esc_html_e( 'Pass Marks', 'geeks' ); ?>
                                        </span>
                                        </th>
                                        <th scope="col" class="border-0">
                                        <span class="text-regular-small tutor-color-text-subsued">
                                            <?php esc_html_e( 'Earned Marks', 'geeks' ); ?>
                                        </span>
                                        </th>
                                        <th scope="col" class="border-0">
                                        <span class="text-regular-small tutor-color-text-subsued">
                                            <?php esc_html_e( 'Result', 'geeks' ); ?>   
                                        </span>
                                        </th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <tr>
                                        <td data-th="Date" class="date align-middle border-top-0">
                                            <div class="td-statement-info">
                                                <span class="text-medium-small tutor-color-text-primary">
                                                    <?php esc_html_e( date( 'F j Y g:i a', strtotime( $submitted_assignment->comment_date ) ), 'geeks' ); ?>
                                                </span>
                                            </div>
                                        </td>
                                        <td data-th="Total Marks" class="total-marks align-middle border-top-0">
                                            <span class="text-medium-caption tutor-color-text-primary">
                                                <?php esc_html_e( $max_mark, 'geeks' ); ?>
                                            </span>
                                        </td>
                                        <td data-th="Pass Marks" class="pass-marks align-middle border-top-0">
                                            <span class="text-medium-caption tutor-color-text-primary">
                                                <?php esc_html_e( $pass_mark, 'geeks' ); ?>
                                            </span>
                                        </td>
                                        <td data-th="Earned Marks" class="earned-marks">
                                            <span class="text-medium-caption tutor-color-text-primary">
                                                <?php esc_html_e( $given_mark, 'geeks' ); ?>
                                            </span>
                                        </td>
                                        <td data-th="Result" class="result align-middle border-top-0">
                                            <?php
                                            if ( $is_reviewed_by_instructor ) {
                                                if ( $given_mark >= $pass_mark ) {
                                                    ?>
                                                <span class="tutor-badge-label label-success">
                                                    <?php esc_html_e( 'Passed', 'geeks' ); ?>
                                                </span>
                                                    <?php
                                                } else {
                                                    ?>
                                                <span class="tutor-badge-label label-warning">
                                                    <?php esc_html_e( 'Failed', 'geeks' ); ?>
                                                </span>
                                                    <?php
                                                }
                                            }
                                            ?>
                                            <?php
                                            if ( ! $is_reviewed_by_instructor ) {
                                                ?>
                                            <span class="tutor-badge-label label-danger">
                                                <?php esc_html_e( 'Pending', 'geeks' ); ?>
                                            </span>
                                            <?php } ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div> <!-- assignment-result-table -->


                <?php
                if ( $is_reviewed_by_instructor ) {
                    ?>
                <div class="tutor-instructor-note tutor-my-30 tutor-py-20 tutor-px-25 tutor-py-sm-30 tutor-px-sm-35">
                    <div class="tutor-in-title tutor-text-medium-h6 tutor-color-text-primary">
                    <?php esc_html_e( 'Instructor Note', 'geeks' ); ?>
                    </div>
                    <div class="tutor-in-body tutor-text-regular-body tutor-color-text-subsued tutor-pt-10 tutor-pt-sm-18">
                    <?php echo nl2br( get_comment_meta( $submitted_assignment->comment_ID, 'instructor_note', true ) ); ?>
                    </div>
                </div>
                <?php } ?>

                <?php
                    /**
                     * If user not submitted assignment and assignment expired
                     * then show expire message
                     *
                     * @since v2.0.0
                     */
                if ( ! $is_submitted && 0 != $time_duration['value'] && ( $now > $remaining_time ) ) :
                    ?>
                        <div class="tutor-mb-40">
                        <?php
                        $alert_template = tutor()->path . 'templates/global/alert.php';
                        if ( file_exists( $alert_template ) ) {
                            tutor_load_template_from_custom_path(
                                $alert_template,
                                array(
                                    'alert_class' => 'tutor-alert tutor-danger alert',
                                    'message'     => esc_html__( 'You have missed the submission deadline. Please contact the instructor for more information.', 'geeks' ),
                                    'icon'        => ' tutor-icon-cross-circle-outline-filled',
                                )
                            );
                        }
                        ?>
                        </div>
                    <?php endif; ?>

                <div class="tutor-assignment-details tutor-assignment-border-bottom tutor-pb-50 tutor-pb-sm-70">
                    <div class="border p-4 tutor-ar-body tutor-pt-25 tutor-pb-40 tutor-px-15 tutor-px-md-30">
                        <div class="tutor-ar-header d-flex justify-content-between align-items-center">
                            <div class="tutor-ar-title tutor-text-medium-h6 tutor-color-text-primary">
                                <?php esc_html_e( 'Your Assignment', 'geeks' ); ?>
                            </div>
                            <?php
                                $evaluated = Assignments::is_evaluated( $post_id );
                            if ( ! $evaluated && ( $remaining_time > $now || $time_duration['value'] == 0 ) ) :
                                ?>
                                <div class="tutor-ar-btn">
                                <a href="<?php echo esc_url( add_query_arg( 'update-assignment', $submitted_assignment->comment_ID ) ); ?>" class="tutor-btn tutor-btn-tertiary tutor-is-outline tutor-btn-sm">
                                <?php esc_html_e( 'Edit', 'geeks' ); ?>
                                </a>
                                </div>
                            <?php endif; ?>
                        </div>
                        <div class="text-regular-body tutor-color-text-subsued tutor-pt-18">
                            <?php echo nl2br( stripslashes( $submitted_assignment->comment_content ) ); ?>
                        </div>
                        <?php
                            $attached_files = get_comment_meta( $submitted_assignment->comment_ID, 'uploaded_attachments', true );
                        if ( $attached_files ) {
                            $attached_files = json_decode( $attached_files, true );

                            if ( tutor_utils()->count( $attached_files ) ) {
                                ?>
                                    <div class="tutor-attachment-files submited-files d-flex tutor-mt-20 tutor-mt-sm-40">
                                    <?php
                                        $upload_dir     = wp_get_upload_dir();
                                        $upload_baseurl = trailingslashit( tutor_utils()->array_get( 'baseurl', $upload_dir ) );

                                    foreach ( $attached_files as $attached_file ) {
                                        ?>
                                                <div class="tutor-instructor-card border">
                                                    <div class="tutor-icard-content p-0">
                                                        <div class="text-regular-body tutor-color-text-title">
                                                    <?php echo tutor_utils()->array_get( 'name', $attached_file ); ?>
                                                        </div>
                                                        <div class="text-regular-small">Size: <?php echo tutor_utils()->array_get( 'size', $attached_file ); ?></div>
                                                    </div>
                                                    <div class="tutor-attachment-file-close tutor-avatar tutor-is-xs flex-center">
                                                        <a href="<?php echo esc_url( $upload_baseurl . tutor_utils()->array_get( 'uploaded_path', $attached_file ) ); ?>" target="_blank">
                                                            <span class="tutor-icon-download tutor-color-design-brand"></span>
                                                        </a>
                                                    </div>
                                                </div>
                                            <?php
                                    }
                                    ?>
                                    </div>
                                    <?php
                            }
                        }
                        ?>
                    </div>
                </div>

                <?php if( $s_content ): ?>
                <div class="tutor-assignment-description-details tutor-assignment-border-bottom tutor-pb-30 tutor-pb-sm-45">
                    <div class="tutor-pt-40 tutor-pt-sm-60 <?php echo esc_attr( strlen( $s_content ) > 500 ? 'tutor-ad-body has-show-more' : '' ); ?>" id="content-section">
                        <div class="text-medium-h6 tutor-color-text-primary">
                            <?php esc_html_e( 'Description', 'geeks' ); ?>
                        </div>
                        <div class="text-regular-body tutor-color-text-subsued tutor-pt-12" id="short-text">
                            <?php
                            if ( strlen( $s_content ) > 500 ) {
                                echo wp_kses_post( substr_replace( $s_content, '...', 500 ) );
                            } else {
                                echo wp_kses_post( $s_content );
                            }
                            ?>
                            <span id="dots"></span>
                        </div>
                        <?php if ( strlen( $s_content ) > 500 ) : ?>
                            <div class="text-regular-body tutor-color-text-subsued tutor-pt-12" id="full-text">
                                <?php
                                    echo wp_kses_post( $s_content );
                                ?>
                            </div>
                            <div class="tutor-show-more-btn tutor-pt-12">
                                <button class="tutor-btn tutor-btn-icon tutor-btn-disable-outline tutor-btn-ghost tutor-no-hover tutor-btn-lg" id="showBtn">
                                    <span class="btn-icon tutor-icon-plus-filled tutor-color-design-brand" id="no-icon"></span>
                                    <span class="tutor-color-text-primary"><?php esc_html_e( 'Show More', 'geeks' ); ?></span>
                                </button>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
                <?php endif; ?>

                <?php if ( $next_prev_content_id->next_id ) : ?>
                <div class="tutor-assignment-footer tutor-pt-30 tutor-pt-sm-45">
                    <a class="tutor-btn tutor-btn-primary tutor-btn-lg tutor-static-loader" href="<?php echo esc_url( get_the_permalink( $next_prev_content_id->next_id ) ); ?>">
                        <?php esc_html_e( 'Continue Lesson', 'geeks' ); ?>
                    </a>
                </div>
                <?php endif; ?>
                <?php
            } else {
                ?>
                <div class="tutor-assignment-footer mt-4 mt-md-6">
                    <div class="tutor-assignment-footer-btn tutor-btn-group d-md-flex justify-content-between">
                        <form action="" method="post" id="tutor_assignment_start_form">
                        <?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); ?>
                        <input type="hidden" value="tutor_assignment_start_submit" name="tutor_action" />
                        <input type="hidden" name="assignment_id" value="<?php echo get_the_ID(); ?>">
                            <button type="submit" class="tutor-btn tutor-btn-primary 
                            <?php
                            if ( $time_duration['value'] != 0 ) {
                                if ( $now > $remaining_time ) {
                                    echo 'tutor-btn-disable tutor-no-hover '; }
                            }
                            ?>
                             tutor-btn-md" id="tutor_assignment_start_btn" 
                <?php
                if ( $time_duration['value'] != 0 ) {
                    if ( $now > $remaining_time ) {
                        echo 'disabled'; }
                }
                ?>
>
                                <?php esc_html_e( 'Start Assignment Submit', 'geeks' ); ?>
                            </button>
                        </form>

                            <?php if ( $next_prev_content_id->next_id ) : ?>
                            <a href="<?php echo esc_url( get_permalink( $next_prev_content_id->next_id ) ); ?>" class="tutor-btn tutor-btn-disable-outline tutor-no-hover tutor-btn-md tutor-mt-md-0 tutor-mt-10">
                            <?php esc_html_e( 'Skip To Next', 'geeks' ); ?>
                        </a>
                        <?php endif; ?>
                    </div>
                </div>
                <?php
            }
        }
        ?>

	
</div>

</div>
<?php tutor_next_previous_pagination(); ?>

<?php do_action('tutor_assignment/single/after/content'); ?>