<?php
/**
 * Display Topics and Lesson lists for learn
 *
 * @package Tutor\Templates
 * @subpackage Single\Lesson
 * @author Themeum <support@themeum.com>
 * @link https://themeum.com
 * @since 1.0.0
 */

use TUTOR\Input;
use Tutor\Models\QuizModel;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $post;
$current_post = $post;

$post_id = get_the_ID();

if ( ! empty( Input::post( 'lesson_id' ) ) ) {
	$post_id = Input::post( 'lesson_id' );
}

$currentPost = $post;
$_is_preview = get_post_meta( $post_id, '_is_preview', true );
$course_id   = 0;
if ( $post->post_type === 'tutor_quiz' ) {
	$course    = tutor_utils()->get_course_by_quiz( get_the_ID() );
	$course_id = $course->ID;
} elseif ( $post->post_type === 'tutor_assignments' ) {
	$course_id = tutor_utils()->get_course_id_by( 'assignment', $post->ID );
} elseif ( $post->post_type === 'tutor_zoom_meeting' ) {
	$course_id = get_post_meta( $post->ID, '_tutor_zm_for_course', true );
} else {
	$course_id = tutor_utils()->get_course_id_by( 'lesson', $post->ID );
}
$user_id                      = get_current_user_id();
$enable_qa_for_this_course    = get_post_meta( $course_id, '_tutor_enable_qa', true ) == 'yes';
$enable_q_and_a_on_course     = tutor_utils()->get_option( 'enable_q_and_a_on_course' ) && $enable_qa_for_this_course;
$is_enrolled                  = tutor_utils()->is_enrolled( $course_id );
$is_instructor_of_this_course = tutor_utils()->has_user_course_content_access($user_id, $course_id);
$is_user_admin                = current_user_can( 'administrator' );
?>

<?php do_action( 'tutor_lesson/single/before/lesson_sidebar' ); ?>

	<div class="course-curriculum tutor-sidebar-tabs-wrap">
		<div class="curriculum-scrollable">

			<div class="tutor-sidebar-tabs-content">

				<ul id="tutor-lesson-sidebar-tab-content" class="tutor-lesson-sidebar-tab-item active list-unstyled list-group list-group-flush course-list5">
					<?php
					$topics = tutor_utils()->get_topics( $course_id );
					if ( $topics->have_posts() ) {
						?>
						<li class="list-group-item">
							<h4 class="mb-0"><?php echo esc_html__( 'Table of Contents', 'geeks' ); ?></h4>
						</li>
						<?php
						while ( $topics->have_posts() ) {
							$topics->the_post();
							$topic_id      = get_the_ID();
							$topic_summery = get_the_content();
							$total_contents = tutor_utils()->count_completed_contents_by_topic($topic_id);
							$lessons = tutor_utils()->get_course_contents_by_topic(get_the_ID(), -1);
							$is_topic_active = !empty(array_filter($lessons->posts, function ($content) use ($currentPost) {
								return $content->ID == $currentPost->ID;
							}));
							$btn_class     = 'tutor-single-lesson-topic-toggle p-0 w-100 border-0 bg-transparent btn d-flex align-items-center text-start';
							if ( ! empty( $topic_summery ) ) {
								$btn_class .= ' has-summery';
							}
							?>

							<li class="list-group-item tutor-topics-in-single-lesson tutor-topics-<?php echo esc_attr( $topic_id ); ?>">
								<button type="button" class="tutor-accordion-item-header tutor-topics-title <?php echo esc_attr( $btn_class ); ?><?php echo $is_topic_active ? ' is-active' : ''; ?>" tutor-course-single-topic-toggler>
									<span class="h4 me-auto mb-0 d-flex align-items-center justify-content-center text-primary-hover">
										<?php
										the_title();
										if ( $topic_summery ) {
											?>
											<div class="tutor-topics-summery mb-0 text-muted fs-6 mt-1 fw-normal sr-only">
												<?php echo wp_kses_post( $topic_summery ); ?>
											</div>
											<?php
										}
										?>
									</span>

									<span class="ml-4 collapse-arrow tutor-single-lesson-topic-toggle6">
										<i class="fe fe-chevron-down font-size-md"></i>
									</span>
								</button>
								<div class="tutor-accordion-item-body pt-4 pb-2" style="<?php echo $is_topic_active ? ' display: block;' : 'display: none;'; ?>">

									<?php
									do_action( 'tutor/lesson_list/before/topic', $topic_id );

									$lessons = tutor_utils()->get_course_contents_by_topic( get_the_ID(), -1 );
									if ( $lessons->have_posts() ) {
										while ( $lessons->have_posts() ) {
											$lessons->the_post();
											$is_public_course 	= \TUTOR\Course_List::is_public($course_id);

											$show_permalink = !$_is_preview || $is_enrolled || get_post_meta($post->ID, '_is_preview', true) || $is_public_course || $is_instructor_of_this_course;
											$show_permalink = apply_filters( 'tutor_course/single/content/show_permalink', $show_permalink, get_the_ID() );

											$lock_icon = ! $show_permalink;
											$show_permalink = null === $show_permalink ? true : $show_permalink;

											$video = tutor_utils()->get_video_info();

											$play_time = false;
											if ( $video ) {
												$play_time = $video->playtime;
											}

											$lesson_icon_1           = geeks_tutor_get_lesson_icon( $post->post_type );


											$lesson_class = 'mb-2 d-flex justify-content-between align-items-center text-decoration-none';
											$lesson_icon  = ( $play_time && $show_permalink ) ? 'mdi mdi-play' : 'fe fe-lock';

											if ( 'tutor_quiz' === $post->post_type ) {
												$lesson_icon = 'mdi mdi-puzzle-outline';
											}

											if ( 'tutor_assignments' === $post->post_type ) {
												$lesson_icon = 'mdi mdi-clipboard-text-outline';
											}

											if ( 'tutor_zoom_meeting' === $post->post_type ) {
												$lesson_icon = 'fe fe-zoom-in';
											}

											$is_course_purchasable   = tutor_utils()->is_course_purchasable( $course_id );
											$is_course_public        = get_post_meta( $course_id, '_tutor_is_public_course', true );
											$single_lesson_item_link = 'tutor-single-lesson-items ' . $lesson_class;
											if ( get_the_ID() === $current_post->ID ) {
												$single_lesson_item_link .= ' active';
											} else {
												$single_lesson_item_link .= ' text-inherit';
											}

											if( $show_permalink ) {
												$single_lesson_item_link .= '';
											} else {
												$single_lesson_item_link .= ' disableClick';
											}

											$is_completed_lesson          = tutor_utils()->is_completed_lesson();

											?>
											<div class="tutor-lessons-under-topic">
												<a href="<?php echo $show_permalink ? the_permalink() : '#'; ?>" class="<?php echo esc_attr( $single_lesson_item_link ); ?>">
													<div class="text-truncate">
														<span class="icon-shape bg-light icon-sm rounded-circle me-2 <?php echo $show_permalink ? 'text-primary' : 'text-muted'; ?>"><i class="fs-4 <?php echo esc_attr( $lesson_icon ); ?>"></i></span>
														<span><?php the_title(); ?></span>
													</div>

													<span class="tutor-lesson-right-icons d-flex align-items-center">
														<?php
														do_action( 'tutor/lesson_list/right_icon_area', $post );

														if ( 'tutor_quiz' === $post->post_type ) {
															$quiz       = $post;
															$time_limit    = (int) tutor_utils()->get_quiz_option( $quiz->ID, 'time_limit.time_value' );
															$last_attempt  = ( new QuizModel() )->get_first_or_last_attempt( $quiz->ID );
															$attempt_ended = is_object( $last_attempt ) && 'attempt_ended' === ( $last_attempt->attempt_status ) ? true : false;

															if ( $time_limit ) {
																	$time_type  = tutor_utils()->get_quiz_option( $quiz->ID, 'time_limit.time_type' );
																?>
																<div class="text-truncate">
																	<?php echo wp_kses_post( "<span class='quiz-time-limit'>{$time_limit} {$time_type}</span>" ); ?>	
																</div>
																<?php
															}
														}

														if ( $play_time ) :
																?>
																<div class="text-truncate">
																	<span><?php echo esc_html( geeks_get_duration_humanized( $play_time ) ); ?></span>
																</div>
														<?php endif; ?>
														<?php $lesson_complete_icon = $is_completed_lesson ? 'checked' : '';

														if ( $post->post_type === 'tutor_quiz' ) {
															if ( ! $lock_icon ) : ?>
																<input type="checkbox" class="ms-2 tutor-form-check-input tutor-form-check-circle" disabled="disabled" readonly="readonly" <?php echo esc_attr( $attempt_ended ? 'checked="checked"' : '' ); ?> />
															<?php else : ?>
																<i class="tutor-icon-lock-line tutor-fs-7 tutor-color-muted tutor-mr-4" area-hidden="true"></i>
															<?php endif; 
														} elseif ( $post->post_type === 'tutor_assignments'  ) {
															if ( $show_permalink ) : 
																do_action( 'tutor/assignment/right_icon_area', $post, $lock_icon );
															 else : ?>
																<i class="tutor-icon-lock-line tutor-fs-7 tutor-color-muted tutor-mr-4" area-hidden="true"></i>
															<?php endif; 
														} elseif ( $post->post_type === 'tutor_zoom_meeting'  ) {
															if ( $show_permalink ) : 
																do_action( 'tutor/zoom/right_icon_area', $post->ID, $lock_icon ); 
															else : ?>
																<i class="tutor-icon-lock-line tutor-fs-7 tutor-color-muted tutor-mr-4" area-hidden="true"></i>
															<?php endif; 
														} elseif ( $post->post_type === 'tutor-google-meet'  ) {
															if ( $show_permalink ) : 
																do_action( 'tutor/google_meet/right_icon_area', $post->ID, false );
															 else : ?>
																<i class="tutor-icon-lock-line tutor-fs-7 tutor-color-muted tutor-mr-4" area-hidden="true"></i>
															<?php endif; 
														} else {
															if ( ! $lock_icon ) {
																echo "<input $lesson_complete_icon type='checkbox' class='ms-2 tutor-form-check-input tutor-form-check-circle' disabled readonly />";
															} else {
																echo '<i class="tutor-icon-lock-line tutor-fs-7 tutor-color-muted tutor-mr-4" area-hidden="true"></i>';
															}
														}
													
														?>
													</span>
												</a>
											</div>
											<?php

										}
										$lessons->reset_postdata();
									}
									?>

									<?php do_action( 'tutor/lesson_list/after/topic', $topic_id ); ?>
								</div>		
							</li>

							<?php
						}
						$topics->reset_postdata();
						wp_reset_postdata();
					}
					?>
				</ul>

			</div>
		</div>

	</div>

<?php do_action( 'tutor_lesson/single/after/lesson_sidebar' ); ?>
