<?php
/**
 * @package TutorLMS/Templates
 * @version 1.4.3
 */

global $post;
global $next_id;
$course_content_id  = get_the_ID();
$course_id          = tutor_utils()->get_course_id_by_subcontent($course_content_id);

$content_id         = tutor_utils()->get_post_id($course_content_id);
$contents           = tutor_utils()->get_course_prev_next_contents_by_id($content_id);
$previous_id        = $contents->previous_id;
$next_id            = $contents->next_id;
$currentPost        = $post;
$quiz_id            = get_the_ID();
$is_started_quiz    = tutor_utils()->is_started_quiz();
$course             = tutor_utils()->get_course_by_quiz(get_the_ID());
$previous_attempts  = tutor_utils()->quiz_attempts();
$attempted_count    = is_array($previous_attempts) ? count($previous_attempts) : 0;

$feedback_mode      = tutor_utils()->get_quiz_option( $quiz_id, 'feedback_mode', 0 );
$attempts_allowed   = $feedback_mode!='retry' ? 1 : tutor_utils()->get_quiz_option(get_the_ID(), 'attempts_allowed', 0);
$passing_grade      = tutor_utils()->get_quiz_option(get_the_ID(), 'passing_grade', 0);
$attempt_remaining  = (int) $attempts_allowed - (int) $attempted_count;

do_action('tutor_quiz/single/before/top');
?>
<?php if (!$is_started_quiz && $attempted_count == 0): ?>
<div class="tutor-quiz-header">
	<span class="tutor-quiz-badge badge bg-info mb-2 sr-only"><?php esc_html_e( 'Quiz', 'geeks' ); ?></span>
	<div class="d-flex align-items-center justify-content-between mb-4 pt-1">
		<?php $excerpt = get_the_excerpt(); ?>
		
		<div>
			<h3 class="h3 mb-0 me-2 me-md-0 text-truncate-line-2"><?php echo get_the_title(); ?></h3>
		</div> 

		<?php if ( ! empty( $excerpt ) ) : ?>
			<span class="dropdown">
				<a href="#" class="mr-2 text-muted" id="dropdownInfo" data-bs-toggle="dropdown" aria-expanded="false">
				  <i class="fe fe-help-circle"></i>
				</a>

				<span class="dropdown-menu dropdown-menu-lg p-3 dropdown-menu-right" aria-labelledby="dropdownInfo">
					<?php echo esc_html( wp_strip_all_tags( $excerpt ) ); ?>        
				</span>
			</span>
		<?php endif; ?>
	</div>

	<div class="card mb-4">
		<div class="card-header">
			<h3 class="mb-0 h4">
				<?php esc_html_e( 'Course', 'geeks' ); ?> :
				<a href="<?php echo get_the_permalink( $course->ID ); ?>"><?php echo get_the_title( $course->ID ); ?></a>
			</h3>
		</div>

		<div class="card-body pt-3">
			<table class="tutor-quiz-meta list-unstyled mb-0 mb-0-last-child table table-borderless d-flex text-nowrap">

				<?php
				$total_questions = tutor_utils()->total_questions_for_student_by_quiz( get_the_ID() );

				if ( $total_questions ) {
					?>
					<tr>
					   <th class="ps-0 py-2"><?php esc_html_e( 'Questions', 'geeks' ); ?> :</th>
					   <td class="py-2"><?php echo esc_html( $total_questions ); ?></td>
					</tr>
					<?php
				}

				$time_limit = tutor_utils()->get_quiz_option( get_the_ID(), 'time_limit.time_value' );
				if ( $time_limit ) {
					$time_type = tutor_utils()->get_quiz_option( get_the_ID(), 'time_limit.time_type' );
					$available_time_type = array(
                        'seconds'   => $time_limit>1 ? esc_html__( 'Seconds', 'geeks' ) : esc_html__( 'Second', 'geeks' ),
                        'minutes'   => $time_limit>1 ? esc_html__( 'Minutes', 'geeks' ) : esc_html__( 'Minute', 'geeks' ),
                        'hours'     => $time_limit>1 ? esc_html__( 'Hours', 'geeks' ) : esc_html__( 'Hour', 'geeks' ),
                        'days'      => $time_limit>1 ? esc_html__( 'Days', 'geeks' ) : esc_html__( 'Day', 'geeks' ),
                        'weeks'     => $time_limit>1 ? esc_html__( 'Weeks', 'geeks' ) : esc_html__( 'Week', 'geeks' ),
                    );
					?>
					<tr>
						<th class="ps-0 py-2"><?php esc_html_e( 'Time', 'geeks' ); ?> :</th>
						<td class="py-2">
							<?php echo $time_limit.' '.sprintf( esc_html__( '%s', 'geeks' ), isset( $available_time_type[$time_type] ) ? $available_time_type[$time_type] : $time_type ); ?>
						</td>
					</tr>
					<?php
				}

				?>
				<tr>
					<th class="ps-0 py-2"><?php esc_html_e( 'Total Attempted', 'geeks' ); ?> :</th>
					<td class="py-2">
						<?php echo $attempted_count . '/' . ($attempts_allowed == 0 ? '&#8734;' : $attempts_allowed); ?>
					</td>
				</tr>

				 <?php
	                // Show Passign grade
	                if($passing_grade){
	                    ?>
	                    <tr>
	                        <th class="ps-0 py-2"><?php esc_html_e('Passing Grade', 'geeks'); ?></th>
	                        <td class="py-2">(<?php echo $passing_grade . '%'; ?>)</td>
	                    </tr>
	                    <?php 
	                } 
	            ?>

			</table>

			<?php
            if ($attempt_remaining > 0 || $attempts_allowed == 0) {
                do_action('tuotr_quiz/start_form/before', $quiz_id);
                $skip_url = get_the_permalink($next_id ? $next_id : $course_id);
                ?>
                <div class="tutor-quiz-btn-grp">
                	<div class="d-flex align-items-center mt-2">
	                    <form id="tutor-start-quiz" method="post">
	                        <?php wp_nonce_field( tutor()->nonce_action, tutor()->nonce ); ?>

	                        <input type="hidden" value="<?php echo esc_attr( $quiz_id ); ?>" name="quiz_id"/>
	                        <input type="hidden" value="tutor_start_quiz" name="tutor_action"/>

	                        <button type="submit" class="me-3 btn btn-primary tutor-btn-primary tutor-btn-md start-quiz-btn" name="start_quiz_btn" value="start_quiz">
	                            <?php esc_html_e( 'Start Quiz', 'geeks' ); ?>
	                        </button>
	                    </form>

	                    <button class="tutor-btn bg-transparent border-0 p-0 tutor-btn-disable-outline tutor-no-hover tutor-btn-md skip-quiz-btn" data-tutor-modal-target="tutor-quiz-skip-to-next">
	                        <?php esc_html_e( 'Skip Quiz', 'geeks' ); ?>
	                    </button>
	                </div>

                     <?php
						tutor_load_template( 'modal.confirm', array(
							'id' => 'tutor-quiz-skip-to-next',
							'title' => esc_html__('Do You Want to Skip This Quiz?', 'geeks'),
							'content' => esc_html__('Are you sure you want to skip this quiz? Please confirm your choice.', 'geeks'),
							'yes' => array(
								'text' => esc_html__('Yes, Skip This', 'geeks'),
								'attr' => array( 'onclick="window.location=\''. $skip_url .'\';"' )
							),
						));
					?>
                </div>
                <?php 
            } 
        ?>
		</div>
	</div>
</div>
<?php endif; ?>

<?php do_action( 'tutor_quiz/single/after/top' ); ?>
