<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.9.0
 */

defined( 'ABSPATH' ) || exit;
$image_size = apply_filters( 'geeks_cart_thumbnail_size', 'woocommerce_thumbnail' );

?>
<div class="py-6">
	<?php do_action( 'woocommerce_before_cart' ); ?>

	<div class="row">
		<div class="col-xl-8 col-lg-8 col-md-12 col-12">
			<form class="woocommerce-cart-form mb-4" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
				<?php do_action( 'woocommerce_before_cart_table' ); ?>

				<div class="card mb-4">
					<div class="card-header border-bottom-0">
						<h2 class="h3 mb-0"><?php echo esc_html__( 'Cart Summary', 'geeks' ); ?></h2>
					</div>

					<div class="table-responsive border-0 overflow-y-hidden">
						<table class="shop_table shop_table_responsive cart woocommerce-cart-form__contents table mb-0 text-nowrap" cellspacing="0">
							<thead>
								<tr>
									<th scope="col" class="product-name border-0"><?php esc_html_e( 'Product', 'geeks' ); ?></th>
									<th scope="col" class="product-price border-0"><?php esc_html_e( 'Price', 'geeks' ); ?></th>
									<th scope="col" class="product-quantity border-0"><?php esc_html_e( 'Quantity', 'geeks' ); ?></th>
									<th scope="col" class="product-subtotal border-0"><?php esc_html_e( 'Subtotal', 'geeks' ); ?></th>
									<th scope="col" class="product-remove border-0">&nbsp;</th>

								</tr>
							</thead>

							<tbody>
								<?php do_action( 'woocommerce_before_cart_contents' ); ?>

								<?php
								foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
									$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
									$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

									if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
										$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
										?>
										<tr class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

											<td class="product-name border-top-0 align-middle" data-title="<?php esc_attr_e( 'Product', 'geeks' ); ?>">
												<div class="d-lg-flex align-items-center">
													<div class="image-block">
														<?php
														$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image( $image_size, array( 'class' => 'mw-none rounded img-4by3-md' ) ), $cart_item, $cart_item_key );

														if ( ! $product_permalink ) {
															echo wp_kses_post( $thumbnail ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
														} else {
															printf( '<a href="%s" class="d-block">%s</a>', esc_url( $product_permalink ), $thumbnail ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
														}
														?>
													</div>

													<div class="ms-lg-3 mt-2 mt-lg-0 product-body text-wrap">
														<?php
														if ( ! $product_permalink ) {
															echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;' );
														} else {
															echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a class="text-inherit mb-1 h5" href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ) );
														}

														do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

														// Meta data.
														echo wc_get_formatted_cart_item_data( $cart_item ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

														// Backorder notification.
														if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
															echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'geeks' ) . '</p>', $product_id ) );
														}
														?>
													</div>
												</div>
											</td>

											<td class="product-price align-middle border-top-0" data-title="<?php esc_attr_e( 'Price', 'geeks' ); ?>">
												<?php
													echo apply_filters( 'geeks_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
												?>
											</td>

											<td class="product-quantity align-middle border-top-0" data-title="<?php esc_attr_e( 'Quantity', 'geeks' ); ?>">
											<?php
											if ( $_product->is_sold_individually() ) {
												$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
											} else {
												$product_quantity = woocommerce_quantity_input(
													array(
														'input_name'   => "cart[{$cart_item_key}][qty]",
														'input_value'  => $cart_item['quantity'],
														'max_value'    => $_product->get_max_purchase_quantity(),
														'min_value'    => '0',
														'product_name' => $_product->get_name(),
													),
													$_product,
													false
												);
											}
											?>
											<div style="width: 5rem;">
												<?php
												echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
												?>
											</div>
											</td>

											<td class="product-subtotal align-middle border-top-0" data-title="<?php esc_attr_e( 'Subtotal', 'geeks' ); ?>">
												<?php
													echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
												?>
											</td>

											<td class="product-remove align-middle border-top-0">
												<?php
													echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
														'woocommerce_cart_item_remove_link',
														sprintf(
															'<a href="%s" class="remove text-inherit" aria-label="%s" data-product_id="%s" data-product_sku="%s"><i class="fe fe-trash-2 fs-6"></i></a>',
															esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
															esc_html__( 'Remove this item', 'geeks' ),
															esc_attr( $product_id ),
															esc_attr( $_product->get_sku() )
														),
														$cart_item_key
													);
												?>
											</td>
										</tr>
										<?php
									}
								}
								?>
							</tbody>
						</table>
					</div>
				</div>

				<?php do_action( 'woocommerce_cart_contents' ); ?>	

				<div class="card">
					<div class="card-body">
						<div class="row">
							<?php if ( wc_coupons_enabled() ) : ?>
								<div class="col-md-6">
									<div class="geeks-coupon-form mr-4 input-group">
										<input type="text" name="coupon_code" id="coupon_code" class="form-control" placeholder="<?php esc_attr_e( 'Coupon code', 'geeks' ); ?>">
										<button type="submit" class="btn btn-secondary<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="apply_coupon"><?php esc_html_e( 'Apply coupon', 'geeks' ); ?></button>
										<?php do_action( 'woocommerce_cart_coupon' ); ?>
									</div>
								</div>
							<?php endif; ?>
							<?php
							if ( wc_coupons_enabled() ) {
								$col_class = 'col-md-6';
							} else {
								$col_class = 'col-md-12';
							}
							?>
							<div class="geeks-update-cart mt-4 mt-md-0 text-md-end <?php echo esc_attr( $col_class ); ?>">
								<button type="submit" class="btn btn-outline-primary btn-block<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="update_cart" value="<?php esc_attr_e( 'Update cart', 'geeks' ); ?>">
									<i class="fe fe-refresh-cw font-size-base me-1"></i>
									<?php esc_html_e( 'Update cart', 'geeks' ); ?>
								</button>
							</div>

							<?php do_action( 'woocommerce_cart_actions' ); ?>

							<?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
						</div>
					</div>
				</div>

				<?php do_action( 'woocommerce_after_cart_contents' ); ?>

				<?php do_action( 'woocommerce_after_cart_table' ); ?>
			</form>
		</div>

		<div class="col-lg-4 col-md-12 col-12">
			<div class="card  border-0 mb-3">
				<?php do_action( 'woocommerce_before_cart_collaterals' ); ?>

				<div class="cart-collaterals">
					<?php
						/**
						 * Cart collaterals hook.
						 *
						 * @hooked woocommerce_cross_sell_display
						 * @hooked woocommerce_cart_totals - 10
						 */
						do_action( 'woocommerce_cart_collaterals' );
					?>
				</div>
			</div>
		</div>
	</div>
	<?php do_action( 'woocommerce_after_cart' ); ?>
</div>
