<?php
/**
 * Thankyou page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/thankyou.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 8.1.0
 *
 * @var WC_Order $order
 */

defined( 'ABSPATH' ) || exit;
?>

<div class="woocommerce-order container py-10">
	<div class="row justify-content-center">
		<div class="col-lg-8 col-md-12 col-12">

	<?php
	if ( $order ) :

		do_action( 'woocommerce_before_thankyou', $order->get_id() );
		?>

		<?php if ( $order->has_status( 'failed' ) ) : ?>

			<div class="text-center py-6">
				<h1 class="display-3 fw-bold"><?php echo esc_html__( 'We are sorry!', 'geeks' ); ?></h1>
				<p class="px-8 lead woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed"><?php esc_html_e( 'Unfortunately your order cannot be processed as the originating bank/merchant has declined your transaction. Please attempt your purchase again.', 'geeks' ); ?></p>

				<p class="woocommerce-notice woocommerce-notice--error woocommerce-thankyou-order-failed-actions">
					<a href="<?php echo esc_url( $order->get_checkout_payment_url() ); ?>" class="btn btn-primary button pay"><?php esc_html_e( 'Pay', 'geeks' ); ?></a>
					<?php if ( is_user_logged_in() ) : ?>
						<a href="<?php echo esc_url( wc_get_page_permalink( 'myaccount' ) ); ?>" class="btn btn-secondary button pay"><?php esc_html_e( 'My account', 'geeks' ); ?></a>
					<?php endif; ?>
				</p>

			</div>

		<?php else : ?>
			<!-- text center -->
			<div class="text-center py-6">
				<h1 class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received display-3 fw-bold"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', esc_html__( 'Thank you.', 'geeks' ), $order ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></h1>
				<p class="lead px-8"><?php echo esc_html__( 'Your order has been received.', 'geeks' ); ?>
				<?php if ( geeks_is_tutor_activated() ):?>
					<p class="lead"><?php echo esc_html__('Go to ', 'geeks');?><a class="tutor-button" href="<?php echo esc_url(tutor_utils()->tutor_dashboard_url()) ?>"><?php esc_html_e('Dashboard', 'geeks'); ?></a></p>
				<?php endif; ?>
			</div>

			<table class="woocommerce-order-overview woocommerce-thankyou-order-details order_details table card table-borderless mb-4 py-3">

				<tr class="woocommerce-order-overview__order order">
					<th class="py-2"><?php esc_html_e( 'Order number:', 'geeks' ); ?></th>
					<td class="py-2"><?php echo wp_kses_post( $order->get_order_number() ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></td>
				</tr>

				<tr class="woocommerce-order-overview__date date">
					<th class="py-2"><?php esc_html_e( 'Date:', 'geeks' ); ?></th>
					<td class="py-2"><?php echo wc_format_datetime( $order->get_date_created() ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></td>
				</tr>

				<?php if ( is_user_logged_in() && $order->get_user_id() === get_current_user_id() && $order->get_billing_email() ) : ?>
					<tr class="woocommerce-order-overview__email email">
						<th class="py-2"><?php esc_html_e( 'Email:', 'geeks' ); ?></th>
						<td class="py-2"><?php echo wp_kses_post( $order->get_billing_email() ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></td>
					</tr>
				<?php endif; ?>

				<tr class="woocommerce-order-overview__total total">
					<th class="py-2"><?php esc_html_e( 'Total:', 'geeks' ); ?></th>
					<td class="py-2"><?php echo wp_kses_post( $order->get_formatted_order_total() ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></td>
				</tr>

				<?php if ( $order->get_payment_method_title() ) : ?>
					<tr class="woocommerce-order-overview__payment-method method">
						<th class="py-2"><?php esc_html_e( 'Payment method:', 'geeks' ); ?></th>
						<td class="py-2"><?php echo wp_kses_post( $order->get_payment_method_title() ); ?></td>
					</tr>
				<?php endif; ?>

			</table>


		<?php endif; ?>


		<div class="card">
			<div class="card-body">
				<?php do_action( 'woocommerce_thankyou_' . $order->get_payment_method(), $order->get_id() ); ?>
				<?php do_action( 'woocommerce_thankyou', $order->get_id() ); ?>
			</div>
		</div>	


	<?php else : ?>

		<p class="woocommerce-notice woocommerce-notice--success woocommerce-thankyou-order-received"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', esc_html__( 'Thank you. Your order has been received.', 'geeks' ), null ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>

	<?php endif; ?>

</div>
</div>
</div>
