<?php
/**
 * Login form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     7.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( is_user_logged_in() ) {
	return;
}
$is_registration_enabled = false;

if ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) {
	$is_registration_enabled = true;
}

$user_account_link = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
do_action( 'woocommerce_before_customer_login_form' );

?>
<div class="mb-4 signup-info">
	<?php geeks_profile_form_branding(); ?>
	<h3 class="mb-1 fw-bold h1"><?php echo esc_html_x( 'Sign in', 'login-heading', 'geeks' ); ?></h3>
	<?php if ( $is_registration_enabled ) : ?>
		<span><?php esc_html_e( 'Don\'t have an account?', 'geeks' ); ?>
			<a id="register-tab" class="ms-1" href="#" role="button" data-view="#modal-signup-view"><?php esc_html_e( 'Sign up', 'geeks' ); ?></a>
		</span>
	<?php endif; ?>
</div>

<form class="woocommerce-form woocommerce-form-login login" method="post" 
<?php
if ( $hidden ) :
	?>
	style="display:none;"<?php endif; ?>>

	<?php do_action( 'woocommerce_login_form_start' ); ?>

	<?php
	if ( $message ) :
		echo wp_kses_post( wpautop( wptexturize( $message ) ) );
	endif;
	?>

	<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
		<label class="form-label" for="username"><?php esc_html_e( 'Username or email', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
		<input type="text" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="username" id="username" autocomplete="username" placeholder="<?php esc_attr_e( 'Email or username', 'geeks' ); ?>" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php // @codingStandardsIgnoreLine ?>
	</p>

	<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
		<label class="form-label" for="password"><?php esc_html_e( 'Password', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
		<input class="woocommerce-Input woocommerce-Input--text input-text form-control" type="password" name="password" id="password" placeholder="<?php esc_attr_e( 'Password', 'geeks' ); ?>" autocomplete="current-password" />
	</p>

	<?php do_action( 'woocommerce_login_form' ); ?>

	<div class="d-lg-flex justify-content-between align-items-center mb-4">
		<p class="form-check m-0">
			<input type="checkbox" id="rememberme" class="woocommerce-form__input woocommerce-form__input-checkbox form-check-input" name="rememberme"/>
			<label class="form-check-label woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme" for="rememberme"><?php esc_html_e( 'Remember me', 'geeks' ); ?></label>
		</p>

		<p class="m-0 woocommerce-LostPassword lost_password"><a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'geeks' ); ?></a></p>
	</div>

	<div class="d-grid">
		<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
		<button type="submit" class="btn btn-primary woocommerce-button button woocommerce-form-login__submit<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="login" value="<?php esc_attr_e( 'Sign in', 'geeks' ); ?>"><?php esc_html_e( 'Sign in', 'geeks' ); ?></button>
	</div>

	<?php do_action( 'woocommerce_login_form_end' ); ?>

</form>

<?php do_action( 'woocommerce_after_customer_login_form' ); ?>
