<?php
/**
 * Login Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.0.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

$is_registration_enabled = false;

if ( 'yes' === get_option( 'woocommerce_enable_myaccount_registration' ) ) {
	$is_registration_enabled = true;
}
?>
<div class="d-flex flex-column container">
	<div class="row align-items-center justify-content-center g-0 min-vh-100">
		<div class="col-lg-5 col-md-8 py-8 py-xl-0">
			<?php do_action( 'woocommerce_before_customer_login_form' ); ?>

			<div id="view-login" class="view card shadow show" data-view-default>
				<div class="woocommerce-form-login woocommerce-form card-body p-6">
					<div class="mb-4">
						<?php geeks_profile_form_branding(); ?>
						<h3 class="mb-1 fw-bold h1"><?php echo esc_html_x( 'Sign in', 'login-heading', 'geeks' ); ?></h3>
						<?php if ( $is_registration_enabled ) : ?>
							<span><?php esc_html_e( 'Don\'t have an account?', 'geeks' ); ?><a href="#view-register" data-view="#view-register" class="ms-1"><?php esc_html_e( 'Sign up', 'geeks' ); ?></a></span>
						<?php endif; ?>
					</div>

					<form name="woocommerce-form woocommerce-form-login login" method="post">

						<?php do_action( 'woocommerce_login_form_start' ); ?>

						<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
							<label class="form-label" for="username"><?php esc_html_e( 'Username or email', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
							<input type="text" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="username" id="username" autocomplete="username" placeholder="<?php esc_attr_e( 'Email or username', 'geeks' ); ?>" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php //phpcs:ignore ?>
						</p>

						<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
							<label class="form-label" for="password"><?php esc_html_e( 'Password', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
							<input class="woocommerce-Input woocommerce-Input--text input-text form-control" type="password" name="password" id="password" placeholder="<?php esc_attr_e( 'Password', 'geeks' ); ?>" autocomplete="current-password" />
						</p>

						<?php do_action( 'woocommerce_login_form' ); ?>

						<div class="d-lg-flex justify-content-between align-items-center mb-4">
							<p class="form-check m-0">
								<input type="checkbox" id="rememberme" class="woocommerce-form__input woocommerce-form__input-checkbox form-check-input" name="rememberme"/>
								<label class="form-check-label woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme" for="rememberme"><?php esc_html_e( 'Remember me', 'geeks' ); ?></label>
							</p>

							<p class="m-0 woocommerce-LostPassword lost_password"><a href="<?php echo esc_url( wp_lostpassword_url() ); ?>" data-view="#view-lost-password"><?php esc_html_e( 'Lost your password?', 'geeks' ); ?></a></p>

						</div>

						<div class="d-grid">
							<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
							<button type="submit" class="btn btn-primary woocommerce-button button woocommerce-form-login__submit<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="login" value="<?php esc_attr_e( 'Sign in', 'geeks' ); ?>"><?php esc_html_e( 'Sign in', 'geeks' ); ?></button>
						</div>

					</form>


					<?php do_action( 'woocommerce_login_form_end' ); ?>

				</div><!-- /.card-body -->
			</div><!-- /.card -->

			<?php if ( $is_registration_enabled ) { ?>

				<div id="view-register" class="view card shadow">
					<div class="card-body p-6 learn-press-form-register learn-press-form">
						<div class="mb-4">
							<?php geeks_profile_form_branding(); ?>
							<h3 class="h1 mb-1 fw-bold"><?php echo esc_html_x( 'Register', 'register-heading', 'geeks' ); ?></h3>
							<span><?php esc_html_e( 'Already have an account?', 'geeks' ); ?><a href="#view-login" data-view="#view-login" class="ms-1"><?php esc_html_e( 'Sign in', 'geeks' ); ?></a></span>	
						</div>


						<form method="post" class="woocommerce-form woocommerce-form-register register" <?php do_action( 'woocommerce_register_form_tag' ); ?> >

							<?php do_action( 'woocommerce_register_form_start' ); ?>

							<?php if ( 'no' === get_option( 'woocommerce_registration_generate_username' ) ) : ?>

								<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
									<label class="form-label" for="reg_username"><?php esc_html_e( 'Username', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
									<input type="text" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="username" id="reg_username" placeholder="<?php esc_attr_e( 'Username', 'geeks' ); ?>" autocomplete="username" value="<?php echo ( ! empty( $_POST['username'] ) ) ? esc_attr( wp_unslash( $_POST['username'] ) ) : ''; ?>" /><?php //phpcs:ignore ?>
								</p>

							<?php endif; ?>

							<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
								<label class="form-label" for="reg_email"><?php esc_html_e( 'Email address', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
								<input type="email" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="email" id="reg_email" placeholder="<?php esc_attr_e( 'Email', 'geeks' ); ?>" autocomplete="email" value="<?php echo ( ! empty( $_POST['email'] ) ) ? esc_attr( wp_unslash( $_POST['email'] ) ) : ''; ?>" /><?php //phpcs:ignore ?>
							</p>

							<?php if ( 'no' === get_option( 'woocommerce_registration_generate_password' ) ) : ?>

								<p class="woocommerce-form-row woocommerce-form-row--wide form-row form-row-wide">
									<label class="form-label" for="reg_password"><?php esc_html_e( 'Password', 'geeks' ); ?>&nbsp;<span class="required">*</span></label>
									<input type="password" class="woocommerce-Input woocommerce-Input--text input-text form-control" name="password" id="reg_password" placeholder="<?php esc_attr_e( 'Password', 'geeks' ); ?>" autocomplete="new-password" />
								</p>

							<?php else : ?>

								<p><?php esc_html_e( 'A password will be sent to your email address.', 'geeks' ); ?></p>

							<?php endif; ?>

							<?php do_action( 'woocommerce_register_form' ); ?>
							<div>
								<div class="woocommerce-form-row form-row d-grid">
									<?php wp_nonce_field( 'woocommerce-register', 'woocommerce-register-nonce' ); ?>
									<button type="submit" class="btn btn-primary woocommerce-Button woocommerce-button button woocommerce-form-register__submit<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="register" value="<?php esc_attr_e( 'Register', 'geeks' ); ?>"><?php esc_html_e( 'Register', 'geeks' ); ?></button>
								</div>
							</div>
							<?php do_action( 'woocommerce_register_form_end' ); ?>

						</form>
					</div>
				</div>
				<?php

			}
			?>
		</div>
	</div>
</div>

<?php do_action( 'woocommerce_after_customer_login_form' ); ?>
