<?php
/**
 * Payment methods
 *
 * Shows customer payment methods on the account page.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/payment-methods.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 8.9.0
 */

defined( 'ABSPATH' ) || exit;

$saved_methods = wc_get_customer_saved_methods_list( get_current_user_id() );
$has_methods   = (bool) $saved_methods;
$types         = wc_get_account_payment_methods_types();

do_action( 'woocommerce_before_account_payment_methods', $has_methods ); ?>

<?php if ( $has_methods ) : ?>

	<ul class="woocommerce-MyAccount-paymentMethods list-group list-group-flush border-bottom mb-4">

		<?php foreach ( $saved_methods as $type => $methods ) : // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited ?>
			<?php
			$index = 0;
			foreach ( $methods as $method ) :
				?>
				<li class="
				<?php
				if ( 0 === $index ) :
					?>
					pb-3 pt-0
					<?php
else :
	?>
					py-3<?php endif; ?> list-group-item px-0 payment-method<?php echo ! empty( $method['is_default'] ) ? ' default-payment-method' : ''; ?>">
					<div class="position-relative">
						<?php foreach ( wc_get_account_payment_methods_columns() as $column_id => $column_name ) : ?>
							<?php
							if ( has_action( 'woocommerce_account_payment_methods_column_' . $column_id ) ) {
								do_action( 'woocommerce_account_payment_methods_column_' . $column_id, $method );
							} elseif ( 'method' === $column_id ) {
								if ( ! empty( $method['method']['last4'] ) ) {
									?>
									<h5 class="mb-0 pe-3 woocommerce-PaymentMethod woocommerce-PaymentMethod--<?php echo esc_attr( $column_id ); ?> payment-method-<?php echo esc_attr( $column_id ); ?>" data-title="<?php echo esc_attr( $column_name ); ?>">
										<?php
										/* translators: 1: credit card type 2: last 4 digits */
										echo sprintf( esc_html__( '%1$s ending in %2$s', 'geeks' ), esc_html( wc_get_credit_card_type_label( $method['method']['brand'] ) ), esc_html( $method['method']['last4'] ) );
										?>
									</h5>
									<?php
								} else {
									?>
									<h5 class="mb-0 pe-3 woocommerce-PaymentMethod woocommerce-PaymentMethod--<?php echo esc_attr( $column_id ); ?> payment-method-<?php echo esc_attr( $column_id ); ?>" data-title="<?php echo esc_attr( $column_name ); ?>">
										<?php
										echo esc_html( wc_get_credit_card_type_label( $method['method']['brand'] ) );
										?>
									</h5>
									<?php
								}
							} elseif ( 'expires' === $column_id ) {
								?>
								<p class="mb-0 fs-6 woocommerce-PaymentMethod woocommerce-PaymentMethod--<?php echo esc_attr( $column_id ); ?> payment-method-<?php echo esc_attr( $column_id ); ?>" data-title="<?php echo esc_attr( $column_name ); ?>">
									<?php echo esc_html__( 'Expires in ', 'geeks' ); ?><?php echo esc_html( $method['expires'] ); ?>
								</p>
								<?php
							} elseif ( 'actions' === $column_id ) {
								?>
								<span class="dropdown dropstart position-absolute top-0 end-0">
									<a class="text-muted text-decoration-none" href="#" role="button" id="paymentDropdown1" data-bs-toggle="dropdown" data-bs-offset="-20,20" aria-expanded="false">
										<i class="fe fe-more-vertical"></i>
									</a>
									<span class="dropdown-menu" aria-labelledby="paymentDropdown1">
										<span class="dropdown-header">Setting </span>
										<?php

										foreach ( $method['actions'] as $key => $action ) { // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited
											$icon = '';

											if ( 'Make default' === $action['name'] ) {
												$icon = 'fe fe-credit-card';
											} elseif ( 'Delete' === $action['name'] ) {
												$icon = 'fe fe-trash';

											}
											echo '<a href="' . esc_url( $action['url'] ) . '" class="dropdown-item button ' . sanitize_html_class( $key ) . '"><i class="dropdown-item-icon ' . esc_attr( $icon ) . '"></i>' . esc_html( $action['name'] ) . '</a>';

										}
										?>
									</span>
								</span>
								<?php
							}
							?>
							<?php endforeach; ?>
						</div>
					</li>
					<?php
					$index++;
				endforeach;
			endforeach;
		?>
		</ul>

<?php else : ?>

	<p class="woocommerce-Message woocommerce-Message--info woocommerce-info"><?php esc_html_e( 'No saved methods found.', 'geeks' ); ?></p>

<?php endif; ?>

<?php do_action( 'woocommerce_after_account_payment_methods', $has_methods ); ?>

<?php if ( WC()->payment_gateways->get_available_payment_gateways() ) : ?>
<a class="button btn btn-outline-primary" href="<?php echo esc_url( wc_get_endpoint_url( 'add-payment-method' ) ); ?>"><?php esc_html_e( 'Add Payment Method', 'geeks' ); ?></a>
<?php endif; ?>
