<?php
/**
 * Single Product Meta
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/meta.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $product;

$sku = $product->get_sku();
if ( empty( $sku ) ) {
	$sku = esc_html__( 'N/A', 'geeks' );
}

?>
<div class="product_meta card mb-4">
	<div class="card-header">
		<h4 class="mb-0"><?php echo esc_html( apply_filters( 'geeks_wc_product_meta_title', esc_html__( 'What’s included', 'geeks' ) ) ); ?></h4>
	</div>

	<ul class="product_meta--list list-group list-group-flush">

		<?php do_action( 'woocommerce_product_meta_start' ); ?>

		<?php if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>

			<li class="list-group-item bg-transparent sku_wrapper"><span class="fw-medium me-2"><?php esc_html_e( 'SKU: ', 'geeks' ); ?></span><span class="sku"><?php echo esc_html( $sku ); ?></span></li>

		<?php endif; ?>

		<?php echo wc_get_product_category_list( $product->get_id(), ', ', '<li class="list-group-item bg-transparent posted_in"><span class="fw-medium me-2">' . _n( 'Category: ', 'Categories: ', count( $product->get_category_ids() ), 'geeks' ) . '</span>', '</li>' ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

		<?php echo wc_get_product_tag_list( $product->get_id(), ', ', '<li class="list-group-item bg-transparent tagged_as"><span class="fw-medium me-2">' . _n( 'Tag:', 'Tags:', count( $product->get_tag_ids() ), 'geeks' ) . ' </span>', '</li>' ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>

		<?php do_action( 'woocommerce_product_meta_end' ); ?>
	</ul>

</div>
